/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for Apollo2 AMAPH1KK-KBR EVB Rev 1.0 eval board
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"
#include "Apollo.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define LED0  (17u)
#define LED1  (14u)
#define LED2  (15u)
#define LED3  (30u)
#define LED4  (10u)

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  GPIO->PADKEY = 0x73;                 // Unlock writes to the GPIO and PAD configuration registers
  //
  // LED 0
  //
  GPIO->PADREGE_b.PAD17FNCSEL = 0x03;  // Set function to GPIO
  GPIO->CFGC_b.GPIO17INCFG    = 0x00;  // Disable In
  GPIO->CFGC_b.GPIO17OUTCFG   = 0x01;  // Set Push Pull
  //
  // LED 1
  //
  GPIO->PADREGD_b.PAD14FNCSEL = 0x03;  // Set function to GPIO
  GPIO->CFGB_b.GPIO14INCFG    = 0x00;  // Disable In
  GPIO->CFGB_b.GPIO14OUTCFG   = 0x01;  // Set Push Pull
  //
  // LED 2
  //
  GPIO->PADREGD_b.PAD15FNCSEL = 0x03;  // Set function to GPIO
  GPIO->CFGB_b.GPIO15INCFG    = 0x00;  // Disable In
  GPIO->CFGB_b.GPIO15OUTCFG   = 0x01;  // Set Push Pull
  //
  // LED 3
  //
  GPIO->PADREGH_b.PAD30FNCSEL = 0x03;  // Set function to GPIO
  GPIO->CFGD_b.GPIO30INCFG    = 0x00;  // Disable In
  GPIO->CFGD_b.GPIO30OUTCFG   = 0x01;  // Set Push Pull
  //
  // LED 4
  //
  GPIO->PADREGC_b.PAD10FNCSEL = 0x03;  // Set function to GPIO
  GPIO->CFGB_b.GPIO10INCFG    = 0x00;  // Disable In
  GPIO->CFGB_b.GPIO10OUTCFG   = 0x01;  // Set Push Pull
  //
  // Set LED to high in order to disable them
  //
  GPIO->WTCA = (0x01u << (LED0));
  GPIO->WTCA = (0x01u << (LED1));
  GPIO->WTCA = (0x01u << (LED2));
  GPIO->WTCA = (0x01u << (LED3));
  GPIO->WTCA = (0x01u << (LED4));
  //
  // Lock PAD configuration registers.
  //
  GPIO->PADKEY = 0;
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    GPIO->WTSA = (0x01u << (LED0));
  } else if (Index == 1) {
    GPIO->WTSA = (0x01u << (LED1));
  } else if (Index == 2) {
    GPIO->WTSA = (0x01u << (LED2));
  } else if (Index == 3) {
    GPIO->WTSA = (0x01u << (LED3));
  } else if (Index == 4) {
    GPIO->WTSA = (0x01u << (LED4));
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    GPIO->WTCA = (0x01u << (LED0));
  } else if (Index == 1) {
    GPIO->WTCA = (0x01u << (LED1));
  } else if (Index == 2) {
    GPIO->WTCA = (0x01u << (LED2));
  } else if (Index == 3) {
    GPIO->WTCA = (0x01u << (LED3));
  } else if (Index == 4) {
    GPIO->WTCA = (0x01u << (LED4));
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    if ((GPIO->WTA >> (LED0)) & 0x01) {
      BSP_ClrLED(Index);
    } else {
      BSP_SetLED(Index);
    }
  } else if (Index == 1) {
    if ((GPIO->WTA >> (LED1)) & 0x01) {
      BSP_ClrLED(Index);
    } else {
      BSP_SetLED(Index);
    }
  } else if (Index == 2) {
    if ((GPIO->WTA >> (LED2)) & 0x01) {
      BSP_ClrLED(Index);
    } else {
      BSP_SetLED(Index);
    }
  } else if (Index == 3) {
    if ((GPIO->WTA >> (LED3)) & 0x01) {
      BSP_ClrLED(Index);
    } else {
      BSP_SetLED(Index);
    }
  } else if (Index == 4) {
    if ((GPIO->WTA >> (LED4)) & 0x01) {
      BSP_ClrLED(Index);
    } else {
      BSP_SetLED(Index);
    }
  }
}

/****** End Of File *************************************************/
