/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
Purpose : BSP for Cypress SK-FM4-176L-S6E2CC eval board
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/

#define LED1_BIT         (10)  // PORT1, Red   - LED4
#define LED2_BIT         (2)   // PORTB, Green - LED4
#define LED3_BIT         (8)   // PORT1, Blue  - LED4

#define GPIO_ADE_ADDR    (*(volatile unsigned int*)(0x4006F500u))

#define PORT1_BASE_ADDR  (0x4006F004u)
#define PORT1_DDR        (*(volatile unsigned short*)(PORT1_BASE_ADDR + 0x200u))
#define PORT1_DOR        (*(volatile unsigned short*)(PORT1_BASE_ADDR + 0x400u))
#define PORTB_BASE_ADDR  (0x4006F02Cu)
#define PORTB_DDR        (*(volatile unsigned short*)(PORTB_BASE_ADDR + 0x200u))
#define PORTB_DOR        (*(volatile unsigned short*)(PORTB_BASE_ADDR + 0x400u))

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  GPIO_ADE_ADDR &= ~((1u <<  LED1_BIT) | (1u << (LED2_BIT + 16)) | (1u <<  LED3_BIT));  // Enable digital signal

  PORT1_DDR     |= (1u << LED1_BIT)   // Set Pins to output
                |  (1u << LED3_BIT);
  PORTB_DDR     |= (1u << LED2_BIT);

  PORT1_DOR     |= (1u << LED1_BIT)   // Set LEDs to off (high is off)
                |  (1u << LED3_BIT);
  PORTB_DOR     |= (1u << LED2_BIT);
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  switch(Index) {
  case 0:
    PORT1_DOR &= ~(1u << LED1_BIT);
    break;
  case 1:
    PORTB_DOR &= ~(1u << LED2_BIT);
    break;
  case 2:
    PORT1_DOR &= ~(1u << LED3_BIT);
    break;
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  switch(Index) {
  case 0:
    PORT1_DOR |= (1u << LED1_BIT);
    break;
  case 1:
    PORTB_DOR |= (1u << LED2_BIT);
    break;
  case 2:
    PORT1_DOR |= (1u << LED3_BIT);
    break;
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  switch(Index) {
  case 0:
    PORT1_DOR ^= (1u << LED1_BIT);
    break;
  case 1:
    PORTB_DOR ^= (1u << LED2_BIT);
    break;
  case 2:
    PORT1_DOR ^= (1u << LED3_BIT);
    break;
  }
}

/*************************** End of file ****************************/
