/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
Purpose : BSP for GigaDevice GD32150R-Eval
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define NUM_LEDS         (4)

#define RCC_BASE_ADDR    (0x40021000u)                                        // Reset and clock control unit base address
#define RCC_AHBCCR       ((volatile unsigned int*)(RCC_BASE_ADDR + 0x14u))    // AHB Clock Control Register

#define GPIOC_BASE_ADDR  (0x48000800u)                                        // GPIOC base address
#define GPIOC_CTRL       ((volatile unsigned int*)(GPIOC_BASE_ADDR + 0x00u))  // GPIOC control
#define GPIOC_DOR        ((volatile unsigned int*)(GPIOC_BASE_ADDR + 0x14u))  // GPIOC data output
#define GPIOC_BOR        ((volatile unsigned int*)(GPIOC_BASE_ADDR + 0x18u))  // GPIOC bit operation
#define GPIOC_BCR        ((volatile unsigned int*)(GPIOC_BASE_ADDR + 0x28u))  // GPIOC bit clear

#define GPIOD_BASE_ADDR  (0x48000C00u)                                        // GPIOD base address
#define GPIOD_CTRL       ((volatile unsigned int*)(GPIOD_BASE_ADDR + 0x00u))  // GPIOD control
#define GPIOD_DOR        ((volatile unsigned int*)(GPIOD_BASE_ADDR + 0x14u))  // GPIOD data output
#define GPIOD_BOR        ((volatile unsigned int*)(GPIOD_BASE_ADDR + 0x18u))  // GPIOD bit operation
#define GPIOD_BCR        ((volatile unsigned int*)(GPIOD_BASE_ADDR + 0x28u))  // GPIOD bit clear

/*********************************************************************
*
*       Typedefs
*
**********************************************************************
*/
typedef struct _LED_INFO {
  int                    PortPin;
  volatile unsigned int* pCtrl;
  volatile unsigned int* pDor;
  volatile unsigned int* pBor;
  volatile unsigned int* pBcr;
} LED_INFO;

/*********************************************************************
*
*       Static data
*
**********************************************************************
*/
static LED_INFO _aLEDInfo[] = {
  { 10, GPIOC_CTRL, GPIOC_DOR, GPIOC_BOR, GPIOC_BCR },
  { 11, GPIOC_CTRL, GPIOC_DOR, GPIOC_BOR, GPIOC_BCR },
  { 12, GPIOC_CTRL, GPIOC_DOR, GPIOC_BOR, GPIOC_BCR },
  {  2, GPIOD_CTRL, GPIOD_DOR, GPIOD_BOR, GPIOD_BCR }
};

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init() {
  int i;

  *RCC_AHBCCR |= 0x180000u;                                       // Enable Port C and Port D clock
  for (i = 0; i < NUM_LEDS; i++) {
    *(_aLEDInfo[i].pCtrl) |= (1u << (_aLEDInfo[i].PortPin * 2));  // Set Pin to output
    *(_aLEDInfo[i].pBcr)   = (1u <<  _aLEDInfo[i].PortPin);       // Clear Pin bit
  }
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index < NUM_LEDS) {
    *(_aLEDInfo[Index].pBor) = (1u << _aLEDInfo[Index].PortPin);
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index < NUM_LEDS) {
    *(_aLEDInfo[Index].pBcr) = (1u << _aLEDInfo[Index].PortPin);
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  int status;

  if (Index < NUM_LEDS) {
    status = (*(_aLEDInfo[Index].pDor) & (1u << _aLEDInfo[Index].PortPin));
    if (status != 0) {
      *(_aLEDInfo[Index].pBcr) = (1u << _aLEDInfo[Index].PortPin);
    } else {
      *(_aLEDInfo[Index].pBor) = (1u << _aLEDInfo[Index].PortPin);
    }
  }
}

/*************************** End of file ****************************/
