/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
Purpose : BSP for GigaDevice GD32190R-Eval
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define NUM_LEDS         (4)

#define RCC_BASE_ADDR    (0x40021000u)                                        // Reset and clock control unit base address
#define RCC_AHBCCR       ((volatile unsigned int*)(RCC_BASE_ADDR + 0x14u))    // AHB Clock Control Register

#define GPIOA_BASE_ADDR  (0x48000000u)                                        // GPIOA Base address
#define GPIOA_CTRL       ((volatile unsigned int*)(GPIOA_BASE_ADDR + 0x00u))  // GPIOA control
#define GPIOA_DOR        ((volatile unsigned int*)(GPIOA_BASE_ADDR + 0x14u))  // GPIOA data output
#define GPIOA_BOR        ((volatile unsigned int*)(GPIOA_BASE_ADDR + 0x18u))  // GPIOA bit operation
#define GPIOA_BCR        ((volatile unsigned int*)(GPIOA_BASE_ADDR + 0x28u))  // GPIOA bit clear

#define GPIOB_BASE_ADDR  (0x48000400u)                                        // GPIOB Base address
#define GPIOB_CTRL       ((volatile unsigned int*)(GPIOB_BASE_ADDR + 0x00u))  // GPIOB control
#define GPIOB_DOR        ((volatile unsigned int*)(GPIOB_BASE_ADDR + 0x14u))  // GPIOB data output
#define GPIOB_BOR        ((volatile unsigned int*)(GPIOB_BASE_ADDR + 0x18u))  // GPIOB bit operation
#define GPIOB_BCR        ((volatile unsigned int*)(GPIOB_BASE_ADDR + 0x28u))  // GPIOB bit clear

/*********************************************************************
*
*       Typedefs
*
**********************************************************************
*/
typedef struct _LED_INFO {
  int                    PortPin;
  volatile unsigned int* pCtrl;
  volatile unsigned int* pDor;
  volatile unsigned int* pBor;
  volatile unsigned int* pBcr;
} LED_INFO;

/*********************************************************************
*
*       Static data
*
**********************************************************************
*/
static LED_INFO _aLEDInfo[] = {
  { 11, GPIOA_CTRL, GPIOA_DOR, GPIOA_BOR, GPIOA_BCR },
  { 12, GPIOA_CTRL, GPIOA_DOR, GPIOA_BOR, GPIOA_BCR },
  {  6, GPIOB_CTRL, GPIOB_DOR, GPIOB_BOR, GPIOB_BCR },
  {  7, GPIOB_CTRL, GPIOB_DOR, GPIOB_BOR, GPIOB_BCR }
};

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init() {
  int i;

  *RCC_AHBCCR |= 0x60000u;                                         // Enable Port A and Port B clock
  for (i = 0; i < NUM_LEDS; i++) {
    *(_aLEDInfo[i].pCtrl) |= (1u << (_aLEDInfo[i].PortPin * 2));  // Set Pin to output
    *(_aLEDInfo[i].pBcr)   = (1u <<  _aLEDInfo[i].PortPin);       // Clear Pin bit
  }
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index < NUM_LEDS) {
    *(_aLEDInfo[Index].pBor) = (1u << _aLEDInfo[Index].PortPin);
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index < NUM_LEDS) {
    *(_aLEDInfo[Index].pBcr) = (1u << _aLEDInfo[Index].PortPin);
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  int status;

  if (Index < NUM_LEDS) {
    status = (*(_aLEDInfo[Index].pDor) & (1u << _aLEDInfo[Index].PortPin));
    if (status != 0) {
      *(_aLEDInfo[Index].pBcr) = (1u << _aLEDInfo[Index].PortPin);
    } else {
      *(_aLEDInfo[Index].pBor) = (1u << _aLEDInfo[Index].PortPin);
    }
  }
}

/*************************** End of file ****************************/
