/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
Purpose : BSP for GigaDevice GD32303E-Eval
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define NUM_LEDS         (4)

#define RCU_BASE_ADDR    (0x40021000u)                                        // Reset and clock unit base address
#define RCU_APB2EN       ((volatile unsigned int*)(RCU_BASE_ADDR + 0x18u))    // APB2 enable register

#define GPIOF_BASE_ADDR  (0x40011C00u)                                        // GPIOF base address
#define GPIOF_CTL0       ((volatile unsigned int*)(GPIOF_BASE_ADDR + 0x00u))  // Port Control register 0
#define GPIOF_BOP        ((volatile unsigned int*)(GPIOF_BASE_ADDR + 0x10u))  // Port bit operate register
#define GPIOF_BC         ((volatile unsigned int*)(GPIOF_BASE_ADDR + 0x14u))  // Port bit clear register
#define GPIOF_OCTL       ((volatile unsigned int*)(GPIOF_BASE_ADDR + 0x0Cu))  // Port output control register

/*********************************************************************
*
*       Typedefs
*
**********************************************************************
*/
typedef struct _LED_INFO {
  int                    PortPin;
  volatile unsigned int* pCtlReg;
  volatile unsigned int* pBopReg;
  volatile unsigned int* pBcReg;
  volatile unsigned int* pOctlReg;
} LED_INFO;

/*********************************************************************
*
*       Static data
*
**********************************************************************
*/
static LED_INFO _aLEDInfo[] = {
  {0, GPIOF_CTL0, GPIOF_BOP, GPIOF_BC, GPIOF_OCTL },    // LED2
  {1, GPIOF_CTL0, GPIOF_BOP, GPIOF_BC, GPIOF_OCTL },    // LED3
  {2, GPIOF_CTL0, GPIOF_BOP, GPIOF_BC, GPIOF_OCTL },    // LED4
  {3, GPIOF_CTL0, GPIOF_BOP, GPIOF_BC, GPIOF_OCTL },    // LED5
};

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init() {
  int i;

  *RCU_APB2EN |= 0x80u;                                             // Enable Port F clock
  for (i = 0; i < NUM_LEDS; i++) {
    *(_aLEDInfo[i].pCtlReg) ^= (5u << (_aLEDInfo[i].PortPin * 4));  // Set Pin to output
    *(_aLEDInfo[i].pBcReg)   = (1u <<  _aLEDInfo[i].PortPin);       // Clear Pin bit
  }
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index < NUM_LEDS) {
    *(_aLEDInfo[Index].pBopReg) = (1u << _aLEDInfo[Index].PortPin);
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index < NUM_LEDS) {
    *(_aLEDInfo[Index].pBcReg) = (1u << _aLEDInfo[Index].PortPin);
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  int status;

  if (Index < NUM_LEDS) {
    status = (*(_aLEDInfo[Index].pOctlReg) & (1u << _aLEDInfo[Index].PortPin));
    if (status != 0) {
      *(_aLEDInfo[Index].pBcReg)  = (1u << _aLEDInfo[Index].PortPin);
    } else {
      *(_aLEDInfo[Index].pBopReg) = (1u << _aLEDInfo[Index].PortPin);
    }
  }
}

/*************************** End of file ****************************/
