/*********************************************************************
*                    SEGGER Microcontroller GmbH                     *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*            (c) 2014 - 2019 SEGGER Microcontroller GmbH             *
*                                                                    *
*           www.segger.com     Support: support@segger.com           *
*                                                                    *
**********************************************************************
*                                                                    *
* All rights reserved.                                               *
*                                                                    *
* Redistribution and use in source and binary forms, with or         *
* without modification, are permitted provided that the following    *
* conditions are met:                                                *
*                                                                    *
* - Redistributions of source code must retain the above copyright   *
*   notice, this list of conditions and the following disclaimer.    *
*                                                                    *
* - Neither the name of SEGGER Microcontroller GmbH                  *
*   nor the names of its contributors may be used to endorse or      *
*   promote products derived from this software without specific     *
*   prior written permission.                                        *
*                                                                    *
* THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND             *
* CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,        *
* INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF           *
* MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE           *
* DISCLAIMED.                                                        *
* IN NO EVENT SHALL SEGGER Microcontroller GmbH BE LIABLE FOR        *
* ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR           *
* CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT  *
* OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;    *
* OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF      *
* LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT          *
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE  *
* USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH   *
* DAMAGE.                                                            *
*                                                                    *
*********************************************************************/

/*****************************************************************************
 *                         Preprocessor Definitions                          *
 *                         ------------------------                          *
 * VECTORS_IN_RAM                                                            *
 *                                                                           *
 *   If defined, an area of RAM will large enough to store the vector table  *
 *   will be reserved.                                                       *
 *                                                                           *
 *****************************************************************************/

  .syntax unified
  .code 16

  .section .init, "ax"
  .align 2

/*****************************************************************************
 * Default Exception Handlers                                                *
 *****************************************************************************/

  .thumb_func
  .weak NMI_Handler
NMI_Handler:
  b .

  .thumb_func
  .weak HardFault_Handler
HardFault_Handler:
  b .

  .thumb_func
  .weak SVC_Handler
SVC_Handler:
  b .

  .thumb_func
  .weak PendSV_Handler
PendSV_Handler:
  b .

  .thumb_func
  .weak SysTick_Handler
SysTick_Handler:
  b .

  .thumb_func
Dummy_Handler:
  b .

#if defined(__OPTIMIZATION_SMALL)

  .weak WWDGT_IRQHandler
  .thumb_set WWDGT_IRQHandler,Dummy_Handler

  .weak LVD_IRQHandler
  .thumb_set LVD_IRQHandler,Dummy_Handler

  .weak Tamper_IRQHandler
  .thumb_set Tamper_IRQHandler,Dummy_Handler

  .weak RTC_IRQHandler
  .thumb_set RTC_IRQHandler,Dummy_Handler

  .weak FMC_IRQHandler
  .thumb_set FMC_IRQHandler,Dummy_Handler

  .weak RCU_CTC_IRQHandler
  .thumb_set RCU_CTC_IRQHandler,Dummy_Handler

  .weak EXTI_Line0_IRQHandler
  .thumb_set EXTI_Line0_IRQHandler,Dummy_Handler

  .weak EXTI_Line1_IRQHandler
  .thumb_set EXTI_Line1_IRQHandler,Dummy_Handler

  .weak EXTI_Line2_IRQHandler
  .thumb_set EXTI_Line2_IRQHandler,Dummy_Handler

  .weak EXTI_Line3_IRQHandler
  .thumb_set EXTI_Line3_IRQHandler,Dummy_Handler

  .weak EXTI_Line4_IRQHandler
  .thumb_set EXTI_Line4_IRQHandler,Dummy_Handler

  .weak DMA0_Channel0_IRQHandler
  .thumb_set DMA0_Channel0_IRQHandler,Dummy_Handler

  .weak DMA0_Channel1_IRQHandler
  .thumb_set DMA0_Channel1_IRQHandler,Dummy_Handler

  .weak DMA0_Channel2_IRQHandler
  .thumb_set DMA0_Channel2_IRQHandler,Dummy_Handler

  .weak DMA0_Channel3_IRQHandler
  .thumb_set DMA0_Channel3_IRQHandler,Dummy_Handler

  .weak DMA0_Channel4_IRQHandler
  .thumb_set DMA0_Channel4_IRQHandler,Dummy_Handler

  .weak DMA0_Channel5_IRQHandler
  .thumb_set DMA0_Channel5_IRQHandler,Dummy_Handler

  .weak DMA0_Channel6_IRQHandler
  .thumb_set DMA0_Channel6_IRQHandler,Dummy_Handler

  .weak ADC0_1_IRQHandler
  .thumb_set ADC0_1_IRQHandler,Dummy_Handler

  .weak CAN0_TX_IRQHandler
  .thumb_set CAN0_TX_IRQHandler,Dummy_Handler

  .weak CAN0_RX0_IRQHandler
  .thumb_set CAN0_RX0_IRQHandler,Dummy_Handler

  .weak CAN0_RX1_IRQHandler
  .thumb_set CAN0_RX1_IRQHandler,Dummy_Handler

  .weak CAN0_EWMC_IRQHandler
  .thumb_set CAN0_EWMC_IRQHandler,Dummy_Handler

  .weak EXTI_line9_5_IRQHandler
  .thumb_set EXTI_line9_5_IRQHandler,Dummy_Handler

  .weak TIMER0_BRK_TIMER8_IRQHandler
  .thumb_set TIMER0_BRK_TIMER8_IRQHandler,Dummy_Handler

  .weak TIMER0_UP_TIMER9_IRQHandler
  .thumb_set TIMER0_UP_TIMER9_IRQHandler,Dummy_Handler

  .weak TIMER0_TRG_CMT_TIMER10_IRQHandler
  .thumb_set TIMER0_TRG_CMT_TIMER10_IRQHandler,Dummy_Handler

  .weak TIMER0_CC_IRQHandler
  .thumb_set TIMER0_CC_IRQHandler,Dummy_Handler

  .weak TIMER1_IRQHandler
  .thumb_set TIMER1_IRQHandler,Dummy_Handler

  .weak TIMER2_IRQHandler
  .thumb_set TIMER2_IRQHandler,Dummy_Handler

  .weak TIMER3_IRQHandler
  .thumb_set TIMER3_IRQHandler,Dummy_Handler

  .weak I2C0_EV_IRQHandler
  .thumb_set I2C0_EV_IRQHandler,Dummy_Handler

  .weak I2C0_ER_IRQHandler
  .thumb_set I2C0_ER_IRQHandler,Dummy_Handler

  .weak I2C1_EV_IRQHandler
  .thumb_set I2C1_EV_IRQHandler,Dummy_Handler

  .weak I2C1_ER_IRQHandler
  .thumb_set I2C1_ER_IRQHandler,Dummy_Handler

  .weak SPI0_IRQHandler
  .thumb_set SPI0_IRQHandler,Dummy_Handler

  .weak SPI1_IRQHandler
  .thumb_set SPI1_IRQHandler,Dummy_Handler

  .weak USART0_IRQHandler
  .thumb_set USART0_IRQHandler,Dummy_Handler

  .weak USART1_IRQHandler
  .thumb_set USART1_IRQHandler,Dummy_Handler

  .weak USART2_IRQHandler
  .thumb_set USART2_IRQHandler,Dummy_Handler

  .weak EXTI_line15_10_IRQHandler
  .thumb_set EXTI_line15_10_IRQHandler,Dummy_Handler

  .weak RTC_Alarm_IRQHandler
  .thumb_set RTC_Alarm_IRQHandler,Dummy_Handler

  .weak USBFS_WKUP_IRQHandler
  .thumb_set USBFS_WKUP_IRQHandler,Dummy_Handler

  .weak TIMER7_BRK_TIMER11_IRQHandler
  .thumb_set TIMER7_BRK_TIMER11_IRQHandler,Dummy_Handler

  .weak TIMER7_UP_TIMER12_IRQHandler
  .thumb_set TIMER7_UP_TIMER12_IRQHandler,Dummy_Handler

  .weak TIMER7_TRG_CMT_TIMER13_IRQHandler
  .thumb_set TIMER7_TRG_CMT_TIMER13_IRQHandler,Dummy_Handler

  .weak TIMER7_CC_IRQHandler
  .thumb_set TIMER7_CC_IRQHandler,Dummy_Handler

  .weak ADC2_IRQHandler
  .thumb_set ADC2_IRQHandler,Dummy_Handler

  .weak EXMC_IRQHandler
  .thumb_set EXMC_IRQHandler,Dummy_Handler

  .weak TIMER4_IRQHandler
  .thumb_set TIMER4_IRQHandler,Dummy_Handler

  .weak SPI2_IRQHandler
  .thumb_set SPI2_IRQHandler,Dummy_Handler

  .weak UART3_IRQHandler
  .thumb_set UART3_IRQHandler,Dummy_Handler

  .weak UART4_IRQHandler
  .thumb_set UART4_IRQHandler,Dummy_Handler

  .weak TIMER5_IRQHandler
  .thumb_set TIMER5_IRQHandler,Dummy_Handler

  .weak TIMER6_IRQHandler
  .thumb_set TIMER6_IRQHandler,Dummy_Handler

  .weak DMA1_Channel0_IRQHandler
  .thumb_set DMA1_Channel0_IRQHandler,Dummy_Handler

  .weak DMA1_Channel1_IRQHandler
  .thumb_set DMA1_Channel1_IRQHandler,Dummy_Handler

  .weak DMA1_Channel2_IRQHandler
  .thumb_set DMA1_Channel2_IRQHandler,Dummy_Handler

  .weak DMA1_Channel3_IRQHandler
  .thumb_set DMA1_Channel3_IRQHandler,Dummy_Handler

  .weak DMA1_Channel4_IRQHandler
  .thumb_set DMA1_Channel4_IRQHandler,Dummy_Handler

  .weak ENET_IRQHandler
  .thumb_set ENET_IRQHandler,Dummy_Handler

  .weak ENET_WKUP_IRQHandler
  .thumb_set ENET_WKUP_IRQHandler,Dummy_Handler

  .weak CAN1_TX_IRQHandler
  .thumb_set CAN1_TX_IRQHandler,Dummy_Handler

  .weak CAN1_RX0_IRQHandler
  .thumb_set CAN1_RX0_IRQHandler,Dummy_Handler

  .weak CAN1_RX1_IRQHandler
  .thumb_set CAN1_RX1_IRQHandler,Dummy_Handler

  .weak CAN1_EWMC_IRQHandler
  .thumb_set CAN1_EWMC_IRQHandler,Dummy_Handler

  .weak USBFS_IRQHandler
  .thumb_set USBFS_IRQHandler,Dummy_Handler

#else

  .thumb_func
  .weak WWDGT_IRQHandler
WWDGT_IRQHandler:
  b .

  .thumb_func
  .weak LVD_IRQHandler
LVD_IRQHandler:
  b .

  .thumb_func
  .weak Tamper_IRQHandler
Tamper_IRQHandler:
  b .

  .thumb_func
  .weak RTC_IRQHandler
RTC_IRQHandler:
  b .

  .thumb_func
  .weak FMC_IRQHandler
FMC_IRQHandler:
  b .

  .thumb_func
  .weak RCU_CTC_IRQHandler
RCU_CTC_IRQHandler:
  b .

  .thumb_func
  .weak EXTI_Line0_IRQHandler
EXTI_Line0_IRQHandler:
  b .

  .thumb_func
  .weak EXTI_Line1_IRQHandler
EXTI_Line1_IRQHandler:
  b .

  .thumb_func
  .weak EXTI_Line2_IRQHandler
EXTI_Line2_IRQHandler:
  b .

  .thumb_func
  .weak EXTI_Line3_IRQHandler
EXTI_Line3_IRQHandler:
  b .

  .thumb_func
  .weak EXTI_Line4_IRQHandler
EXTI_Line4_IRQHandler:
  b .

  .thumb_func
  .weak DMA0_Channel0_IRQHandler
DMA0_Channel0_IRQHandler:
  b .

  .thumb_func
  .weak DMA0_Channel1_IRQHandler
DMA0_Channel1_IRQHandler:
  b .

  .thumb_func
  .weak DMA0_Channel2_IRQHandler
DMA0_Channel2_IRQHandler:
  b .

  .thumb_func
  .weak DMA0_Channel3_IRQHandler
DMA0_Channel3_IRQHandler:
  b .

  .thumb_func
  .weak DMA0_Channel4_IRQHandler
DMA0_Channel4_IRQHandler:
  b .

  .thumb_func
  .weak DMA0_Channel5_IRQHandler
DMA0_Channel5_IRQHandler:
  b .

  .thumb_func
  .weak DMA0_Channel6_IRQHandler
DMA0_Channel6_IRQHandler:
  b .

  .thumb_func
  .weak ADC0_1_IRQHandler
ADC0_1_IRQHandler:
  b .

  .thumb_func
  .weak CAN0_TX_IRQHandler
CAN0_TX_IRQHandler:
  b .

  .thumb_func
  .weak CAN0_RX0_IRQHandler
CAN0_RX0_IRQHandler:
  b .

  .thumb_func
  .weak CAN0_RX1_IRQHandler
CAN0_RX1_IRQHandler:
  b .

  .thumb_func
  .weak CAN0_EWMC_IRQHandler
CAN0_EWMC_IRQHandler:
  b .

  .thumb_func
  .weak EXTI_line9_5_IRQHandler
EXTI_line9_5_IRQHandler:
  b .

  .thumb_func
  .weak TIMER0_BRK_TIMER8_IRQHandler
TIMER0_BRK_TIMER8_IRQHandler:
  b .

  .thumb_func
  .weak TIMER0_UP_TIMER9_IRQHandler
TIMER0_UP_TIMER9_IRQHandler:
  b .

  .thumb_func
  .weak TIMER0_TRG_CMT_TIMER10_IRQHandler
TIMER0_TRG_CMT_TIMER10_IRQHandler:
  b .

  .thumb_func
  .weak TIMER0_CC_IRQHandler
TIMER0_CC_IRQHandler:
  b .

  .thumb_func
  .weak TIMER1_IRQHandler
TIMER1_IRQHandler:
  b .

  .thumb_func
  .weak TIMER2_IRQHandler
TIMER2_IRQHandler:
  b .

  .thumb_func
  .weak TIMER3_IRQHandler
TIMER3_IRQHandler:
  b .

  .thumb_func
  .weak I2C0_EV_IRQHandler
I2C0_EV_IRQHandler:
  b .

  .thumb_func
  .weak I2C0_ER_IRQHandler
I2C0_ER_IRQHandler:
  b .

  .thumb_func
  .weak I2C1_EV_IRQHandler
I2C1_EV_IRQHandler:
  b .

  .thumb_func
  .weak I2C1_ER_IRQHandler
I2C1_ER_IRQHandler:
  b .

  .thumb_func
  .weak SPI0_IRQHandler
SPI0_IRQHandler:
  b .

  .thumb_func
  .weak SPI1_IRQHandler
SPI1_IRQHandler:
  b .

  .thumb_func
  .weak USART0_IRQHandler
USART0_IRQHandler:
  b .

  .thumb_func
  .weak USART1_IRQHandler
USART1_IRQHandler:
  b .

  .thumb_func
  .weak USART2_IRQHandler
USART2_IRQHandler:
  b .

  .thumb_func
  .weak EXTI_line15_10_IRQHandler
EXTI_line15_10_IRQHandler:
  b .

  .thumb_func
  .weak RTC_Alarm_IRQHandler
RTC_Alarm_IRQHandler:
  b .

  .thumb_func
  .weak USBFS_WKUP_IRQHandler
USBFS_WKUP_IRQHandler:
  b .

  .thumb_func
  .weak TIMER7_BRK_TIMER11_IRQHandler
TIMER7_BRK_TIMER11_IRQHandler:
  b .

  .thumb_func
  .weak TIMER7_UP_TIMER12_IRQHandler
TIMER7_UP_TIMER12_IRQHandler:
  b .

  .thumb_func
  .weak TIMER7_TRG_CMT_TIMER13_IRQHandler
TIMER7_TRG_CMT_TIMER13_IRQHandler:
  b .

  .thumb_func
  .weak TIMER7_CC_IRQHandler
TIMER7_CC_IRQHandler:
  b .

  .thumb_func
  .weak ADC2_IRQHandler
ADC2_IRQHandler:
  b .

  .thumb_func
  .weak EXMC_IRQHandler
EXMC_IRQHandler:
  b .

  .thumb_func
  .weak TIMER4_IRQHandler
TIMER4_IRQHandler:
  b .

  .thumb_func
  .weak SPI2_IRQHandler
SPI2_IRQHandler:
  b .

  .thumb_func
  .weak UART3_IRQHandler
UART3_IRQHandler:
  b .

  .thumb_func
  .weak UART4_IRQHandler
UART4_IRQHandler:
  b .

  .thumb_func
  .weak TIMER5_IRQHandler
TIMER5_IRQHandler:
  b .

  .thumb_func
  .weak TIMER6_IRQHandler
TIMER6_IRQHandler:
  b .

  .thumb_func
  .weak DMA1_Channel0_IRQHandler
DMA1_Channel0_IRQHandler:
  b .

  .thumb_func
  .weak DMA1_Channel1_IRQHandler
DMA1_Channel1_IRQHandler:
  b .

  .thumb_func
  .weak DMA1_Channel2_IRQHandler
DMA1_Channel2_IRQHandler:
  b .

  .thumb_func
  .weak DMA1_Channel3_IRQHandler
DMA1_Channel3_IRQHandler:
  b .

  .thumb_func
  .weak DMA1_Channel4_IRQHandler
DMA1_Channel4_IRQHandler:
  b .

  .thumb_func
  .weak ENET_IRQHandler
ENET_IRQHandler:
  b .

  .thumb_func
  .weak ENET_WKUP_IRQHandler
ENET_WKUP_IRQHandler:
  b .

  .thumb_func
  .weak CAN1_TX_IRQHandler
CAN1_TX_IRQHandler:
  b .

  .thumb_func
  .weak CAN1_RX0_IRQHandler
CAN1_RX0_IRQHandler:
  b .

  .thumb_func
  .weak CAN1_RX1_IRQHandler
CAN1_RX1_IRQHandler:
  b .

  .thumb_func
  .weak CAN1_EWMC_IRQHandler
CAN1_EWMC_IRQHandler:
  b .

  .thumb_func
  .weak USBFS_IRQHandler
USBFS_IRQHandler:
  b .

#endif

/*****************************************************************************
 * Vector Table                                                              *
 *****************************************************************************/

  .section .vectors, "ax"
  .balign 512
  .global _vectors
  .extern __stack_end__
  .extern Reset_Handler

_vectors:
  .word __stack_end__
  .word Reset_Handler
  .word NMI_Handler
  .word HardFault_Handler
  .word 0 /* Reserved */
  .word 0 /* Reserved */
  .word 0 /* Reserved */
  .word 0 /* Reserved */
  .word 0 /* Reserved */
  .word 0 /* Reserved */
  .word 0 /* Reserved */
  .word SVC_Handler
  .word 0 /* Reserved */
  .word 0 /* Reserved */
  .word PendSV_Handler
  .word SysTick_Handler
  .word WWDGT_IRQHandler
  .word LVD_IRQHandler
  .word Tamper_IRQHandler
  .word RTC_IRQHandler
  .word FMC_IRQHandler
  .word RCU_CTC_IRQHandler
  .word EXTI_Line0_IRQHandler
  .word EXTI_Line1_IRQHandler
  .word EXTI_Line2_IRQHandler
  .word EXTI_Line3_IRQHandler
  .word EXTI_Line4_IRQHandler
  .word DMA0_Channel0_IRQHandler
  .word DMA0_Channel1_IRQHandler
  .word DMA0_Channel2_IRQHandler
  .word DMA0_Channel3_IRQHandler
  .word DMA0_Channel4_IRQHandler
  .word DMA0_Channel5_IRQHandler
  .word DMA0_Channel6_IRQHandler
  .word ADC0_1_IRQHandler
  .word CAN0_TX_IRQHandler
  .word CAN0_RX0_IRQHandler
  .word CAN0_RX1_IRQHandler
  .word CAN0_EWMC_IRQHandler
  .word EXTI_line9_5_IRQHandler
  .word TIMER0_BRK_TIMER8_IRQHandler
  .word TIMER0_UP_TIMER9_IRQHandler
  .word TIMER0_TRG_CMT_TIMER10_IRQHandler
  .word TIMER0_CC_IRQHandler
  .word TIMER1_IRQHandler
  .word TIMER2_IRQHandler
  .word TIMER3_IRQHandler
  .word I2C0_EV_IRQHandler
  .word I2C0_ER_IRQHandler
  .word I2C1_EV_IRQHandler
  .word I2C1_ER_IRQHandler
  .word SPI0_IRQHandler
  .word SPI1_IRQHandler
  .word USART0_IRQHandler
  .word USART1_IRQHandler
  .word USART2_IRQHandler
  .word EXTI_line15_10_IRQHandler
  .word RTC_Alarm_IRQHandler
  .word USBFS_WKUP_IRQHandler
  .word TIMER7_BRK_TIMER11_IRQHandler
  .word TIMER7_UP_TIMER12_IRQHandler
  .word TIMER7_TRG_CMT_TIMER13_IRQHandler
  .word TIMER7_CC_IRQHandler
  .word ADC2_IRQHandler
  .word EXMC_IRQHandler
  .word Dummy_Handler /* Reserved */
  .word TIMER4_IRQHandler
  .word SPI2_IRQHandler
  .word UART3_IRQHandler
  .word UART4_IRQHandler
  .word TIMER5_IRQHandler
  .word TIMER6_IRQHandler
  .word DMA1_Channel0_IRQHandler
  .word DMA1_Channel1_IRQHandler
  .word DMA1_Channel2_IRQHandler
  .word DMA1_Channel3_IRQHandler
  .word DMA1_Channel4_IRQHandler
  .word ENET_IRQHandler
  .word ENET_WKUP_IRQHandler
  .word CAN1_TX_IRQHandler
  .word CAN1_RX0_IRQHandler
  .word CAN1_RX1_IRQHandler
  .word CAN1_EWMC_IRQHandler
  .word USBFS_IRQHandler
_vectors_end:

#ifdef VECTORS_IN_RAM
  .section .vectors_ram, "ax"
  .balign 512
  .global _vectors_ram

_vectors_ram:
  .space _vectors_end - _vectors, 0
#endif
