/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
Purpose : BSP for GigaDevice GD32307C-Eval
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define LED2_BIT         (0)                                                   // LED2, Port C
#define LED3_BIT         (2)                                                   // LED3, Port C
#define LED4_BIT         (0)                                                   // LED4, Port E
#define LED5_BIT         (1)                                                   // LED5, Port E

#define RCU_BASE_ADDR    (0x40021000u)                                         // Reset and clock unit base address
#define RCU_APB2EN       (*(volatile unsigned int*)(RCU_BASE_ADDR + 0x18u))    // APB2 enable register

#define GPIOC_BASE_ADDR  (0x40011000u)                                         // GPIOC base address
#define GPIOC_CTL0       (*(volatile unsigned int*)(GPIOC_BASE_ADDR + 0x00u))  // Port C Control register 0
#define GPIOC_OCTL       (*(volatile unsigned int*)(GPIOC_BASE_ADDR + 0x0Cu))  // Port C output control register

#define GPIOE_BASE_ADDR  (0x40011800u)                                         // GPIOE base address
#define GPIOE_CTL0       (*(volatile unsigned int*)(GPIOE_BASE_ADDR + 0x00u))  // Port E Control register 0
#define GPIOE_OCTL       (*(volatile unsigned int*)(GPIOE_BASE_ADDR + 0x0Cu))  // Port E output control register

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init() {
  unsigned int v;

  RCU_APB2EN |= (1u << 4)                       // Enable Port C clock
             |  (1u << 6);                      // Enable Port E clock
  //
  // LED0 and LED1
  //
  v           = GPIOC_CTL0;
  v          |=  (1u << (LED2_BIT * 4))         // Set Pins to output
             |   (1u << (LED3_BIT * 4));
  v          &= ~(3u << ((LED2_BIT * 4) + 2))   // Set Pins to GPIO Push-Pull
             &  ~(3u << ((LED3_BIT * 4) + 2));
  GPIOC_CTL0 = v;
  //
  // LED2 and LED3
  //
  v           = GPIOE_CTL0;
  v          |=  (1u << (LED4_BIT * 4))         // Set Pins to output
             |   (1u << (LED5_BIT * 4));
  v          &= ~(3u << ((LED4_BIT * 4) + 2))   // Set Pins to GPIO Push-Pull
             &  ~(3u << ((LED5_BIT * 4) + 2));
  GPIOE_CTL0 = v;
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  switch (Index) {
  case 0:
    GPIOC_OCTL |= (1u << LED2_BIT);
    break;
  case 1:
    GPIOC_OCTL |= (1u << LED3_BIT);
    break;
  case 2:
    GPIOE_OCTL |= (1u << LED4_BIT);
    break;
  case 3:
    GPIOE_OCTL |= (1u << LED5_BIT);
    break;
  default:
    break;
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  switch (Index) {
  case 0:
    GPIOC_OCTL &= ~(1u << LED2_BIT);
    break;
  case 1:
    GPIOC_OCTL &= ~(1u << LED3_BIT);
    break;
  case 2:
    GPIOE_OCTL &= ~(1u << LED4_BIT);
    break;
  case 3:
    GPIOE_OCTL &= ~(1u << LED5_BIT);
    break;
  default:
    break;
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  switch (Index) {
  case 0:
    GPIOC_OCTL ^= (1u << LED2_BIT);
    break;
  case 1:
    GPIOC_OCTL ^= (1u << LED3_BIT);
    break;
  case 2:
    GPIOE_OCTL ^= (1u << LED4_BIT);
    break;
  case 3:
    GPIOE_OCTL ^= (1u << LED5_BIT);
    break;
  default:
    break;
  }
}

/*************************** End of file ****************************/
