
/****************************************************************************************************//**
 * @file     FLASH.h
 *
 *
 * @brief    CMSIS Cortex-M0 Core Peripheral Access Layer Header File for
 *           default ZMDCM0 Device Series
 *
 * @version  V0.1
 * @date     18. May 2012
 *
 * @note     Generated with SVDConv V2.6 Build 5c  on Friday, 18.05.2012 10:41:33
 *
 *           from CMSIS SVD File 'ZMDCM0.xml' Version 0.1,
 *           created on Thursday, 05.04.2012 12:33:42, last modified on Friday, 18.05.2012 07:38:52
 *
 *******************************************************************************************************/


#ifndef __FLASH_H__
#define __FLASH_H__


// ------------------------------------------------------------------------------------------------
// -----                                         FLASH                                        -----
// ------------------------------------------------------------------------------------------------


/**
  * @brief Flash memory controller (FLASH)
  */

typedef struct {                            /*!< FLASH Structure                       */
  
  union {
    __IO uint32_t  FC_RAM_ADDR;             /*!< Flash controller RAM address register.RAM word address where data to be written into flash is located (first address);hardware increments this address when more than one word has to be written Commands requiring this register: - SET_KEY_CMD - SET_BOUNDARY_CMD - WRITE_CMD - UNLOCK_CMD Note: the last two address digits of the RAM are not included as they are always 0. For programming, the RAM address needs to be shifted right by two bits. */
    
    struct {
      uint32_t  addrRam   : 11;             /*!< Source data address in RAM            */
    } FC_RAM_ADDR_b;                        /*!< BitSize                               */
  };
  
  union {
    __IO uint32_t  FC_FLASH_ADDR;           /*!< flash word address (first address) where data shall be written; also used as pointer to page to be erased Commands requiring this register: - WRITE_CMD - ERASE_MAINPAGE_CMD Note: the last two address digits of the flash are not included as they are always 0. For programming, the flash address needs to be shifted right by nine bits. */
    
    struct {
      uint32_t  flashAddr : 15;             /*!< Destination data address in ROM       */
    } FC_FLASH_ADDR_b;                      /*!< BitSize                               */
  };
  
  union {
    __IO uint32_t  FC_CMD_SIZE;             /*!< FLASH Command and Size register       */
    
    struct {
      uint32_t  command   :  4;             /*!< command to be executed by flash controller Valid commands: - 0x0: ERASE_MAIN_CMD - 0x2: ERASE_BOOT_PROG_CMD - 0x3: ERASE_PROG_CMD - 0x4: ERASE_MAINPAGE_CMD - 0x6: ERASE_KEY_CMD - 0x8: UNLOCK_CMD - 0x9: GETENV_CMD - 0xA: WRITE_CMD - 0xC: SET_KEY_CMD - 0xD: SET_BOUNDARY_CMD - 0xE: LOCK_PERM_CMD - 0xF: LOCK_KEY_CMD */
      uint32_t            :  4;
      uint32_t  wrSize    :  5;             /*!< number of words to be written to flash; 0 is interpreted as 32Note: writing is always performed within a row.1 row contains 32 words. While ram address is always incremented, flash address wraps at row boundary to the beginning of the row. It is in the responsibility of the user to take care of this */
    } FC_CMD_SIZE_b;                        /*!< BitSize                               */
  };
  
  union {
    __IO uint32_t  FC_EXE_CMD;              /*!< writing 1 to this bit starts the execution of the configured command; always read as 0 */
    
    struct {
      uint32_t  exeCmd    :  1;             /*!< Execute Flash CMD                     */
    } FC_EXE_CMD_b;                         /*!< BitSize                               */
  };
  
  union {
    __IO uint32_t  FC_IRQ_EN;               /*!< Flash interrupt reasons configure.    */
    
    struct {
      uint32_t  enIrq0    :  1;             /*!< when set to 1, the status signal cmdRdy is allowed to drive the interrupt line */
      uint32_t  enIrq1    :  1;             /*!< when set to 1, the status signal invalidCmd is allowed to drive the interrupt line */
      uint32_t  enIrq2    :  1;             /*!< when set to 1, the status signal invalidArea is allowed to drive the interrupt line */
      uint32_t  enIrq3    :  1;             /*!< when set to 1, the status signal unlockFail is allowed to drive the interrupt line */
      uint32_t  enIrq4    :  1;             /*!< when set to 1, the status signal dataAll1 is allowed to drive the interrupt line */
      uint32_t  enIrq5    :  1;             /*!< when set to 1, the status signal data1Err is allowed to drive the interrupt line */
      uint32_t  enIrq6    :  1;             /*!< when set to 1, the status signal data2Err is allowed to drive the interrupt line */
      uint32_t  enIrq7    :  1;             /*!< when set to 1, the status signal prog1Err is allowed to drive the interrupt line */
    } FC_IRQ_EN_b;                          /*!< BitSize                               */
  };
  
  union {
    __IO uint32_t  FC_STAT_CORE;            /*!< Flash controller status               */
    
    struct {
      uint32_t  cmdRdy    :  1;             /*!< this bit is set when a command execution has finished; it is cleared when this register is read */
      uint32_t  invalidCmd:  1;             /*!< this bit is set when an invalid command was executed;it is cleared when this register is read */
      uint32_t  invalidArea:  1;            /*!< this bit is set when a command is executed targeting a protected area, e.g. performing ERASE_MAINPAGE_CMD to progam space when flash is locked; it is cleared when this register is read */
      uint32_t  unlockFail:  1;             /*!< this bit is set when the UNLOCK_CMD fails; it is cleared when this register is read */
      uint32_t  coreActive:  1;             /*!< this bit reflects the status of the core state machine; when set core is active */
      uint32_t  allowKey  :  1;             /*!< when set but flash is locked, the ERASE_KEY_CMD is allowed to be performed */
      uint32_t  allowBoot :  1;             /*!< when set but flash is locked, the WRITE_CMD is allowed to be performed on boot space */
      uint32_t  allowProg :  1;             /*!< when set but flash is locked, the WRITE_CMD is allowed to be performed on program space */
      uint32_t  clrAllow  :  1;             /*!< writing 1 to this bit clears all 3 allow flags */
    } FC_STAT_CORE_b;                       /*!< BitSize                               */
  };
  
  union {
    __IO uint32_t  FC_STAT_PROG;            /*!< Flash controller prog error status    */
    
    struct {
      uint32_t  addrProg  : 18;             /*!< this register containsthe address of the instruction fetch error which caused the first of the three flags below to be set; the highest bit is used to distinguish between MAIN (0) and INFO (1) area */
      uint32_t            : 11;
      uint32_t  progAll1  :  1;             /*!< this bit is set when an instruction fetch occurs to an erased memory address; it is cleared when this register is read */
      uint32_t  prog1Err  :  1;             /*!< this bit is set when a correctable error occurs during an instruction fetch; it is cleared when this register is read */
      uint32_t  prog2Err  :  1;             /*!< this bit is set when an uncorrectable error occurs during an instruction fetch; it is cleared when this register is read  */
    } FC_STAT_PROG_b;                       /*!< BitSize                               */
  };
  
  union {
    __IO uint32_t  FC_STAT_DATA;            /*!< Flash controller prog error status    */
    
    struct {
      uint32_t  addrProg  : 18;             /*!< this register containsthe address of the instruction fetch error which caused the first of the three flags below to be set; the highest bit is used to distinguish between MAIN (0) and INFO (1) area */
      uint32_t            : 11;
      uint32_t  progAll1  :  1;             /*!< this bit is set when an instruction fetch occurs to an erased memory address; it is cleared when this register is read */
      uint32_t  prog1Err  :  1;             /*!< this bit is set when a correctable error occurs during an instruction fetch; it is cleared when this register is read */
      uint32_t  prog2Err  :  1;             /*!< this bit is set when an uncorrectable error occurs during an instruction fetch; it is cleared when this register is read  */
    } FC_STAT_DATA_b;                       /*!< BitSize                               */
  };
} FLASH_Type;


// ------------------------------------------------------------------------------------------------
// -----                                 Peripheral memory map                                -----
// ------------------------------------------------------------------------------------------------

#define FLASH_BASE                0x40000800


// ------------------------------------------------------------------------------------------------
// -----                                Peripheral declaration                                -----
// ------------------------------------------------------------------------------------------------

#define FLASH                     ((FLASH_Type              *) FLASH_BASE)

#endif
