
/****************************************************************************************************//**
 * @file     SMU.h
 *
 *
 * @brief    CMSIS Cortex-M0 Core Peripheral Access Layer Header File for
 *           default ZMDCM0 Device Series
 *
 * @version  V0.1
 * @date     18. May 2012
 *
 * @note     Generated with SVDConv V2.6 Build 5c  on Friday, 18.05.2012 10:41:33
 *
 *           from CMSIS SVD File 'ZMDCM0.xml' Version 0.1,
 *           created on Thursday, 05.04.2012 12:33:42, last modified on Friday, 18.05.2012 07:38:52
 *
 *******************************************************************************************************/


#ifndef __SMU_H__
#define __SMU_H__


// ------------------------------------------------------------------------------------------------
// -----                                          SMU                                         -----
// ------------------------------------------------------------------------------------------------


/**
  * @brief System Management Module (SMU)
  */

typedef struct {                            /*!< SMU Structure                         */
  
  union {
    __IO uint32_t  SYS_CLKCFG;              /*!< Controls clock divider  */
    
    struct {
      uint32_t  clkDiv    :  2;             /*!< Clock divider value 0: incoming clock is divided by 1 1: incoming clock is divided by 2 2: incoming clock is divided by 4 3: incoming clock is divided by 8 */
      uint32_t            :  5;
      uint32_t  reserved   :  1;             /*!< reserved       */
    } SYS_CLKCFG_b;                         /*!< BitSize                               */
  };
  
  union {
    __IO uint32_t  SYS_MEMPORTCFG;          /*!< Controls open drain for GPIOS */
    
    struct {
      uint32_t  ppNod     : 16;             /*!< Output configuration bits it can be individually selected for each GPIO whether it shall work as open-drain (set to 0) or as push-pull (set to 1) */
      uint32_t  reserved_1  :  2;           /*!< Reserved */
      uint32_t  reserved_2  :  3;           /*!< Reserved */
      uint32_t  reserved_3  :  3;           /*!< Reserved */
      uint32_t            :  6;
      uint32_t  linTest   :  1;             /*!< configuration bit for LIN test. When set, RXD and TXD line are directly connected to GPIO */
      uint32_t  memSwap   :  1;             /*!< memory swap bit it can be selected whether the flash MAIN area (set to 0) or the RAM (set to 1) shall be mirrored to system address 0x0 */
    } SYS_MEMPORTCFG_b;                     /*!< BitSize                               */
  };
  
  union {
    __IO uint32_t  SYS_MEMINF;              /*!< Memory Information register           */
    
    struct {
      uint32_t  progStart :  8;             /*!< This register represents the first page where program section inside flash starts. This value is read from flash during power-up phase and is updated by some flash commands.Be aware: to get the correct flash address offset, nine '0' must be appended. */
      uint32_t  logStart  :  8;             /*!< This register represents the first page where log section inside flash starts. This value is read from flash during power-up phase and is updated by some flash commands. Be aware: to get the correct flash address offset, nine '0' must be appended. */
      uint32_t  ramSplit  : 11;             /*!< This register represents the first RAM word which is accessible by JTAG although the memory is locked. This value is read from flash during power-up phase and is updated by some flash commands. Be aware: to get the correct RAM address offset, two '0' must be appended. */
      uint32_t            :  1;
      uint32_t  protInfo  :  4;             /*!< This register represents the memory protection scheme. This value is read from flash during power-up phase and is updated by some flash commands.[0]: key based lock [1]: permanent lock [3:2]: number of failed unlock attempts */
    } SYS_MEMINF_b;                         /*!< BitSize                               */
  };
  
  union {
    __IO uint32_t  SYS_RSTSTAT;             /*!< System reset statistics               */
    
    struct {
      uint32_t  extRst    :  1;             /*!< This bit reflects if an external reset has occurred. It is cleared when register is read. */
      uint32_t  sysRstReq :  1;             /*!< This bit reflects if a reset forced by a system reset request has occurred.It is cleared when register is read. */
      uint32_t  lockupRst :  1;             /*!< This bit reflects if a reset was forced by a detected lockup when this reset was enabled. It is cleared when register is read. */
      uint32_t  jtagRst   :  1;             /*!< This bit reflects if a reset forced by a JTAG reset request has occurred. It is cleared when register is read. */
      uint32_t            :  3;
      uint32_t  enLockup  :  1;             /*!< This bit reflects whether a lockup from the ARM core is allowed to reset the system (set to 1) or not (set to 0). */
    } SYS_RSTSTAT_b;                        /*!< BitSize                               */
  };
} SMU_Type;


// ------------------------------------------------------------------------------------------------
// -----                                 Peripheral memory map                                -----
// ------------------------------------------------------------------------------------------------

#define SMU_BASE                  0x40000000


// ------------------------------------------------------------------------------------------------
// -----                                Peripheral declaration                                -----
// ------------------------------------------------------------------------------------------------

#define SMU                       ((SMU_Type                *) SMU_BASE)

#endif
