/*!***************************************************************************** 
 * \file     TRIM.h
 * \brief	 Definition of constants and functions for TRIM driver
 *           
 * \version V1.0  
 * \date     19. September 2012
 * \ingroup TRIM
 * \note
 *  Copyright (c) 2000-2012 by Zentrum Mikroelektronik Dresden AG
 * All rights are reserved. Reproduction in whole or in part is
 * prohibited without the written consent of the copyright owner.
 *
 ******************************************************************************/
 /*

ZMDI FIRMWARE LICENSE AGREEMENT
IMPORTANT - READ BEFORE COPYING, INSTALLING OR USING.
LICENSEES:
Do not use or load this software/ firmware until you have carefully read the following terms and conditions. 
By loading or using the Software, you agree to the terms of this Agreement. 
If you do not wish to so agree, do not install or use the Software.

I.	DEFINITIONS: 

Software means the enclosed software / firmware library, examples, project templates and all the related 
documentation and design tools licensed in the form of object and/ or source code as the case may be.
Product means Your or Your end-users product or system, and all the related documentation, that includes
 or incorporates solely and exclusively an executable version (in object and source code) of the Software 
 and provided further that such Software executes soilely and exclusively on ZMDI devices. 
ZMDI Device means an integrated circuit manufactured by or for ZMDI.

II.	LICENSE. 
1.	This Software is licensed for use only in conjunction with ZMDI Devices. Use of the Software in conjunction
 with non-ZMDI Devices is not licensed hereunder. Subject to the terms of this Agreement, ZMDI grants to you a limited, 
 revocable, nonexclusive, nontransferable, worldwide, royalty-free license under ZMDI's copyrights to: 

	(i)	Make copies, prepare derivative works of the copy the source code version of the Software for the sole 
	and exclusive purpose of developing executable versions (in object and source code) of such Software only 
	for use within the Product; 
	(ii)	Make copies, prepare derivative works of the object code versions of the Software for the sole 
	purpose of designing, developing and manufacturing the Products;
	(iii)	Make copies, prepare derivative works of the documentation part of the Software 
	(including non-confidential comments from source code files if applicable), for the sole purpose of 
	providing documentation for the Product and its usage; 
	(iv)	Make, have made, use, sell, offer to sell, import, export or otherwise distribute Products also through 
	multiple tiers.
	
2.	You shall not otherwise sell, assign, sublicense, lease, rent or in any other way distribute the Software for
 commercial purposes, in whole or in part, to any third party. You may not, nor may you assist any other person or
 entity to modify, translate, convert to another programming language, decompile, reverse engineer, or disassemble
 any portion of the Software or otherwise attempt to derive source code from any object code modules of the Software
 or any internal data files generated by the Software. Your rights to redistribute the Software shall be contingent
 upon your installation of this Agreement in its entirety in the same directory as the Software.

3.	You acknowledge and agree that any use, adaptation translation or transcription of the Software or any portion 
or derivative thereof, for use with ZMDI Devices is a material breach of this Agreement and requires a separate license 
from ZMDI. 

4.	You acknowledge and agree that the protection of the source code of the Software requires the imposition of reasonable
 security precautions. In the event ZMDI demonstrates to You a reasonable belief that the source code of the Software has 
 been used or distributed in violation of this Agreement, ZMDI may, by written notification, request certification as to 
 whether such unauthorized use or distribution has occurred. You shall cooperate and assist ZMDI in its determination of 
 whether there has been unauthorized use or distribution of the source code of the Software and will take appropriate steps
 to remedy any unauthorized use or distribution. 

III.	Modifications.   ZMDI may make changes to the Software, or items referenced therein, at any time without notice, 
but is not obligated to support or update the Software. Except as otherwise expressly provided herein, ZMDI grants no express 
or implied right under ZMDI patents, copyrights, trademarks, or other intellectual property rights. You may transfer the 
Software only if a copy of this license accompanies the Software and the recipient agrees to be fully bound by these terms.

IV.	CONFIDENTIALITY. If you wish to have a third party consultant or subcontractor ("Contractor") perform work on your behalf
 which involves access to or use of Software, you shall obtain a written confidentiality agreement from the Contractor which 
 contains provisions with respect to access to or use of the Software no less restrictive than those set forth in this Agreement
 and excluding any distribution rights, and use for any other purpose. Except as expressly provided herein, you shall not disclose
 the terms or existence of this Agreement or use ZMDI's name in any publications, advertisements, or other announcements without 
 ZMDI's prior written consent. You do not have any rights to use any ZMDI trademarks or logos.

V.	OWNERSHIP OF SOFTWARE AND COPYRIGHTS. Software and accompanying materials, if any, are owned by ZMDI or its suppliers and 
licensors and may be protected by copyright, trademark, patent and trade secret law and international treaties. Any rights, express
 or implied, in inteIlectual property embodied in the foregoing, are reserved by ZMDI and its suppliers and licensors or otherwise
 as set forth in any applicable open source license agreement. You will keep the Software free of liens, attachments, and other 
 encumbrances. You agree not to remove any proprietary notices and/or any labels from the Software and accompanying materials 
 without prior written approval by ZMDI.

VI.	EXCLUSION OF WARRANTIES. THE SOFTWARE IS PROVIDED "AS IS" AND POSSIBLY WITH FAULTS. UNLESS EXPRESSLY AGREED OTHERWISE, 
ZMDI AND ITS SUPPLIERS AND LICENSORS DISCLAIM ANY AND ALL WARRANTIES AND GUARANTEES, EXPRESS, IMPLIED OR OTHERWISE, 
INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, NONINFRINGEMENT, OR FITNESS FOR A PARTICULAR PURPOSE. 
ZMDI does not warrant or assume responsibility for the accuracy or completeness of any information, text, graphics, links
 or other items contained within the Software. You are responsible for determining whether the Software will be suitable 
 for Your intended use or application or will achieve your intended results. You assume all liability, financial or otherwise, 
 associated with Your use or disposition of the Software.

VII.	LIMITATION OF LIABILITY.  IN NO EVENT WILL ZMDI OR ITS SUPPLIERS BE LIABLE FOR LOSS OF OR CORRUPTION TO DATA, 
LOST PROFITS OR LOSS OF CONTRACTS, COST OF PROCUREMENT OF SUBSTITUTE PRODUCTS OR OTHER SPECIAL, INCIDENTAL, CONSEQUENTIAL 
OR INDIRECT DAMAGES, LOSSES, COSTS OR EXPENSES OF ANY KIND ARISING FROM THE SUPPLY OR USE OF THE ZMDI SDK, HOWEVER CAUSED
 AND ON ANY THEORY OF LIABILITY (INCLUDING WITHOUT LIMITATION NEGLIGENCE). 
 THIS DOES NOT APPLY IN CASES INVOLVING (I) GROSS NEGLIGENCE OR INTENT, (II) BODILY INJURY OR DEATH, (III) PRODUCT LIABILITY,
 OR (IV) THE BREACH OF MAIN CONTRACTUAL OBLIGATIONS (KARDINALPFLICHTEN). 

VIII.	APPLICABLE LAW. Claims arising under this Agreement shall be governed by the laws of Germany, excluding its principles
of conflict of laws and the United Nations Convention on Contracts for the Sale of Goods.

IX.	WAIVER AND AMENDMENT. No modification, amendment or waiver of any provision of this Agreement shall be effective 
unless in writing and signed by an officer of ZMDI. No failure or delay in exercising any right, power, or remedy under this 
Agreement shall operate as a waiver of any such right, power or remedy. Without limiting the foregoing, terms and conditions 
on any purchase orders or similar materials submitted by you to ZMDI, and any terms contained in ZMDIs standard acknowledgment
 form that are in conflict with these terms, shall be of no force or effect.

X.	SEVERABILITY. If any provision of this Agreement is held by a court of competent jurisdiction to be contrary to law, such 
provision shall be changed and interpreted so as to best accomplish the objectives of the original provision to the fullest 
extent allowed by law and the remaining provisions of this Agreement shall remain in full force and effect.

XI.	EXPORT RESTRICTIONS. Each party acknowledges that the Software is subject to applicable import and export regulations of 
the United States and of the countries in which each party transacts business, specifically including U.S. Export Administration Act
 and Export Administration Regulations. Each party shall comply with such laws and regulations, as well as all other laws and 
 regulations applicable to the Software. Without limiting the generality of the foregoing, each party agrees that it will not export,
 re-export, transfer or divert any of the Software or the direct programs thereof to any restricted place or party in accordance with U.S. 
 export regulations. Note that Software containing encryption may be subject to additional restrictions.

XII.	TERMINATION OF THE AGREEMENT. ZMDI has the right to terminate this Agreement immediately upon receiving notice of any claim, 
suit or proceeding that alleges that the Software or your use or distribution of the Software infringes any third party intellectual 
property rights. Upon termination, you will immediately destroy the Software or return all copies of the Software to ZMDI. 


*/



#ifndef __TRIM_H__
#define __TRIM_H__


#ifdef USE_TRIM_MCU
	void TRIM_vMCU(void);	/*!< If USE_TRIM_MCU is defined, allows use of function TRIM_vMCU() */
#else
	#define	  TRIM_vMCU()
#endif

#endif

