
/****************************************************************************************************//**
 * @file     ZSYSTEM.h
 *
 *
 * @brief    CMSIS Cortex-M0 Core Peripheral Access Layer Header File for
 *           default ZMDCM0 Device Series
 *
 * @version  V0.1
 * @date     18. May 2012
 *
 * @note     Generated with SVDConv V2.6 Build 5c  on Friday, 18.05.2012 10:41:33
 *
 *           from CMSIS SVD File 'ZMDCM0.xml' Version 0.1,
 *           created on Thursday, 05.04.2012 12:33:42, last modified on Friday, 18.05.2012 07:38:52
 *
 *******************************************************************************************************/


#ifndef __ZSYSTEM_H__
#define __ZSYSTEM_H__


// ------------------------------------------------------------------------------------------------
// -----                                        ZSYSTEM                                       -----
// ------------------------------------------------------------------------------------------------


/**
  * @brief SPI and SW-LIN directly connected to the SBC (ZSYSTEM)
  */

typedef struct {                            /*!< ZSYSTEM Structure                     */
  
  union {
    __IO uint32_t  Z1_LINCFG;               /*!< LIN configuration register            */
    
    struct {
      uint32_t  stopRX    :  1;             /*!< This bit is a strobe register to stop the receiver. When writing 1 to this bit the state machine of the data reception unit is placed into its default state (rxEn and rxActive are cleared) and waits for a new sync strobe. This can be used by software to reject incoming data after PID field was evaluated as a non-used PID. */
      uint32_t  disableRX :  1;             /*!< When set to 1, this bit completely disables the breakSyncDetector, the RX data path and the RX filter. It shall be set when system clock shall be switched off, when clock divider shall be changed, when LIN shall go to sleep but MCU shall continue operation or for debugging purposes. */
      uint32_t  fastMode  :  1;             /*!< This bit distinguishes between slow (0) and fast (1) mode in slow mode, the detected baud rate is between 1 kBaud and 30 kBaud. In fast mode, the detected baud rate is up to 200 kBaud for clkDiv values 0, 1 and 2 and up to 100 kBaud for clkDiv value of 3. */
      uint32_t  enToCnt   :  1;             /*!< This bit enables the timeout counter for bus inactivity. The LIN protocol defines that the LIN controller shall go to sleep when either a SLEEP command was received or after more than 4s of inactivity. When the overall system guarantees that LIN communication is always stopped with a SLEEP command, there is no need to activate the timeout counter. */
      uint32_t  rxEn      :  1;             /*!< This bit reflects the status of the receiver. It is set when a break sync field is detected and it is clearedwhen software stops the receiver (stopRX == 1) or when a transmission is started. */
      uint32_t  rxActive  :  1;             /*!< This bit reflects the status of the receiver. It is set when a START condition is detected on the bus (falling edge of rxd line after synchronization) and it is cleared when software stops the receiver (stopRX == 1), a new sync strobe occurs, in the middle of a received STOP bit or when a transmission is started. */
      uint32_t  txActive  :  1;             /*!< This bit reflects the status of the transmitter. It is set when data is present in the TxBuffer to be transmitted and it is cleared when a sync strobe or a bus conflict (sending 1 but receiving 0) is detected, when the transmitter is forced to 1 by protection logic (sending 0 but receiving 1)or when no more data to be transmitted is present in the TX buffer at the end of an active transmission. */
    } Z1_LINCFG_b;                          /*!< BitSize                               */
  };
  
  union {
    __I  uint32_t  Z1_LINSTAT;              /*!< LIN status register                   */
    
    struct {
      uint32_t  syncDet   :  1;             /*!< This bit is set by hardware when a BreakSync-Field was detected by the BreakSyncDetector. It is cleared when software reads this register. */
      uint32_t  rxFull    :  1;             /*!< This bit is set by hardware when a received byte is placed into the RX buffer. It is cleared when software reads the data out of the RX buffer (read from LINDATA). */
      uint32_t  txEmpty   :  1;             /*!< This bit is set when a byte to be transmitted is read out of the TX buffer to be shifted out on the LIN bus. It is cleared when the software puts a new byte into the TX buffer (write to LINDATA). */
      uint32_t  conflict  :  1;             /*!< This bit is set by hardware when it has detected a bus conflict during an active transmission.This can only occur when sending a 1 but receiving a 0. It is cleared when software reads this register. */
      uint32_t  rxOverflow:  1;             /*!< This bit is set by hardware when the receiver wants to place a received byte into the RX buffer while this buffer is already full. The new received byte is rejected and lost. This bit is cleared when software reads this register. */
      uint32_t  wrColl    :  1;             /*!< This bit is set by hardware when software tries to write a byte intoTX buffer while this buffer is already full. The new written byte is rejected. This bit is cleared when software reads this register. */
      uint32_t  txOff     :  1;             /*!< This bit is set by hardware when it is transmitting a 0 but receives a 1. As 0 is the dominant level on the bus, this can only occur due to an hardware error or when the bus protection circuit has disabled the output driver in the LIN PHY. This bit is cleared when software reads this register. */
      uint32_t  inactive  :  1;             /*!< This bit is set when the timeout counter for inactivity has expired. This bit is cleared when software reads this register. */
    } Z1_LINSTAT_b;                         /*!< BitSize                               */
  };
  
  union {
    __IO uint32_t  Z1_LINDATA;              /*!< LIN DataRegister                      */
    
    struct {
      uint32_t  LINDATA   :  8;             /*!< When writing a byte to this register, the value is stored in the TxBuffer. Additionally a write access to this register clears the TxEmpty flag in the status register. When reading this register, the content of the RxBuffer is returned.Additionally a read access to this register clears the RxFull flag in the status register. Note: when writing to this register when TxBuffer is full, the TxBuffer keeps its content and the written byte is rejected. This is signalled by the WrColl flag in the status register */
    } Z1_LINDATA_b;                         /*!< BitSize                               */
  };
  
  union {
    __IO uint32_t  Z1_LINIRQEN;             /*!< LIN IRQ configuration register        */
    
    struct {
      uint32_t  syncDet   :  1;             /*!< When set to 1, the corresponding status bit is allowed to drive the IRQ output. */
      uint32_t  rxFull    :  1;             /*!< When set to 1, the corresponding status bit is allowed to drive the IRQ output. */
      uint32_t  txEmpty   :  1;             /*!< When set to 1, the corresponding status bit is allowed to drive the IRQ output. */
      uint32_t  conflict  :  1;             /*!< When set to 1, the corresponding status bit is allowed to drive the IRQ output. */
      uint32_t  rxOverflow:  1;             /*!< When set to 1, the corresponding status bit is allowed to drive the IRQ output. */
      uint32_t  wrColl    :  1;             /*!< When set to 1, the corresponding status bit is allowed to drive the IRQ output. */
      uint32_t  txOff     :  1;             /*!< When set to 1, the corresponding status bit is allowed to drive the IRQ output. */
      uint32_t  inactive  :  1;             /*!< When hen set to 1, the corresponding status bit is allowed to drive the IRQ output. */
    } Z1_LINIRQEN_b;                        /*!< BitSize                               */
  };
  
  union {
    __IO uint32_t  Z1_LINBAUDLOW;           /*!< Baud rate for LIN interface baud rate = clk / ( {LINBAUDHIGH, LINBAUD LOW} + 1) Note: In normal operating mode, this register shall not be written. It is updated by the break-sync-detector Note: for debugging purposes, the LIN controller can work as a TX UART. For this, the baud rate can be selected by software but shall be at least 0x3 */
    
    struct {
      uint32_t  LINBAUDLOW:  8;             /*!< LOW Value for LIN baudrate            */
    } Z1_LINBAUDLOW_b;                      /*!< BitSize                               */
  };
  
  union {
    __IO uint32_t  Z1_LINBAUDHIGH;          /*!< Baud rate for LIN interface baud rate = clk / ( {LINBAUDHIGH, LINBAUD LOW} + 1) Note: In normal operating mode, this register shall not be written. It is updated by the break-sync-detector Note: for debugging purposes, the LIN controller can work as a TX UART. For this, the baud rate can be selected by software but shall be at least 0x3 */
    
    struct {
      uint32_t  LINBAUDHIGH:  8;            /*!< HIGH Value for LIN baudrate           */
    } Z1_LINBAUDHIGH_b;                     /*!< BitSize                               */
  };
  __I  uint32_t  RESERVED0[2];
  
  union {
    __IO uint32_t  Z1_SPICFG;               /*!< ZSYSTEM SPI configuration register    */
    
    struct {
      uint32_t  RxOf      :  1;             /*!< When set to 1, the corresponding status bit is allowed to drive the IRQ output. */
      uint32_t  RxFull    :  1;             /*!< When set to 1, the corresponding status bit is allowed to drive the IRQ output. */
      uint32_t  TxEmpty   :  1;             /*!< When set to 1, the corresponding status bit is allowed to drive the IRQ output. */
      uint32_t  WrColl    :  1;             /*!< When set to 1, the corresponding status bit is allowed to drive the IRQ output. */
      uint32_t            :  1;
      uint32_t  SamplePos :  1;             /*!< This bit selects whether data on MISO shall be sampled at sampling edge (set to 0) or at shift edge (set to 1).Note: change this bit only when module is disabled (SpiEn == 0) or when no transfer is in progress */
      uint32_t  SSN       :  1;             /*!< This bit directly controls the SSN line. */
      uint32_t  SpiEn     :  1;             /*!< Enable for SPI module                 */
    } Z1_SPICFG_b;                          /*!< BitSize                               */
  };
  
  union {
    __IO uint32_t  Z1_SPIDATA;              /*!< When writing a byte to this register, the value is stored in the TxBuffer. Additonally a write access to this register clears the TxEmpty flag in the status register When reading this register, the content of the RxBuffer is returned. Additonally a read access to this register clears the RxFull flag in the status register Note: when writing to this register when TxBuffer is full, the TxBuffer keeps its content and the written byte is rejected.This is signaled by the WrColl flag in the status register */
    
    struct {
      uint32_t  SpiData   :  8;             /*!< SPI_DATA_REGISTER                     */
    } Z1_SPIDATA_b;                         /*!< BitSize                               */
  };
  
  union {
    __IO uint32_t  Z1_SPICLKCFG;            /*!< SPI clock configuration register      */
    
    struct {
      uint32_t  CPOL      :  1;             /*!< Clock polarity; the content of this bit directly reflects the idle state of the clock Note: change this bit only when module is disabled (SpiEn == 0) */
      uint32_t  CPHA      :  1;             /*!< Clock phase; data is centered to the first (set to 0) or to the second (set to 1) clock edge Note: change this bit only when module is disabled (SpiEn == 0) */
      uint32_t  CDIV      :  6;             /*!< Clock divider value; spi clock period is 2*(CDIV+1) times the system clock Note: change this bit only when module is disabled (SpiEn == 0) or when no transfer is in progress */
    } Z1_SPICLKCFG_b;                       /*!< BitSize                               */
  };
  
  union {
    __IO uint32_t  Z1_SPISTAT;              /*!< SPI Status register                   */
    
    struct {
      uint32_t  RxOf      :  1;             /*!< This bit signals that an Rx overflow occurred. Note: this bit is cleared when status is read Note: the received byte causing the overflow is rejected; the previous received bit is kept in the RxBuffer */
      uint32_t  RxFull    :  1;             /*!< This bit reflects the status of the RxBuffer. It is set when a new byte is transfered into the RxBuffer.Note: this bit is cleared when SpiData is read */
      uint32_t  TxEmpty   :  1;             /*!< This bit reflects the status of the TxBuffer. It is set when a byte is transfered from the TxBuffer into the shift register. Note: this bit is cleared when SpiData is written */
      uint32_t  WrColl    :  1;             /*!< This bit is set when SpiData is written while TxBuffer is already full. Note: this bit is cleared when status is read */
      uint32_t            :  3;
      uint32_t  ClrTxBuf  :  1;             /*!< Writing a 1 to this bit clears the TxBuffer. Note: write only when SPI is disabled; always read as 0 */
    } Z1_SPISTAT_b;                         /*!< BitSize                               */
  };
} ZSYSTEM_Type;


// ------------------------------------------------------------------------------------------------
// -----                                 Peripheral memory map                                -----
// ------------------------------------------------------------------------------------------------

#define ZSYSTEM_BASE              0x40001800


// ------------------------------------------------------------------------------------------------
// -----                                Peripheral declaration                                -----
// ------------------------------------------------------------------------------------------------

#define ZSYSTEM                   ((ZSYSTEM_Type            *) ZSYSTEM_BASE)

#endif
