/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for ZAMC4100 eval board
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define SYS_MEMPORTCFG  (*(volatile unsigned char*)(0x40000004u))
#define GPIO_BASE_ADDR  0x40001400u
#define GPIO_DIR        (*(volatile unsigned char*)(GPIO_BASE_ADDR + 0x00u))
#define GPIO_IN         (*(volatile unsigned char*)(GPIO_BASE_ADDR + 0x04u))
#define GPIO_OUT        (*(volatile unsigned char*)(GPIO_BASE_ADDR + 0x08u))
#define GPIO_SETCLR     (*(volatile unsigned int*) (GPIO_BASE_ADDR + 0x0Cu))
#define NUM_LEDS        8u

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  SYS_MEMPORTCFG |= 0xFFu;  // Set to push/push
  GPIO_DIR        = 0xFFu;  // Output
  GPIO_OUT        = 0x00u;  // Initially clear all Leds
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index < (int)NUM_LEDS) {
    GPIO_OUT |= (1u << Index);
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index < (int)NUM_LEDS) {
   GPIO_OUT &= ~(1u << Index);
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index < (int)NUM_LEDS) {
    if ((GPIO_IN & (1u << Index)) != 0u) {
      GPIO_OUT &= ~(1u << Index);
    } else {
      GPIO_OUT |= (1u << Index);
    }
  }
}

/****** End Of File *************************************************/
