/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for Infineon XMC4300 eval board
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define P4_BASE_ADDR  (0x48028400u)
#define P4_OUT        (*(volatile unsigned int*)(P4_BASE_ADDR + 0x00u))
#define P4_OMR        (*(volatile unsigned int*)(P4_BASE_ADDR + 0x04u))
#define P4_IOCR0      (*(volatile unsigned int*)(P4_BASE_ADDR + 0x10u))

#define LED0          (0)
#define LED1          (1)

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  P4_IOCR0 &= (unsigned int)~0xFFFF0000;
  P4_IOCR0 |= 0x8080;
  P4_OUT   &= ~((1u << LED0) | (1u << LED1));
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    P4_OUT |= (1u << LED0);
  } else if (Index == 1) {
    P4_OUT |= (1u << LED1);
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    P4_OUT &= ~(1u << LED0);
  } else if (Index == 1) {
    P4_OUT &= ~(1u << LED1);
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    P4_OMR |= (1u << LED0) | (1u << (LED0 + 16));
  } else if (Index == 1) {
    P4_OMR |= (1u << LED1) | (1u << (LED1 + 16));
  }
}

/****** End Of File *************************************************/
