/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for Infineon XMC4500 eval board
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define P2_BASE_ADDR  0x48028200
#define P2_OUT        (*(volatile unsigned int*)(P2_BASE_ADDR + 0x00))
#define P2_OMR        (*(volatile unsigned int*)(P2_BASE_ADDR + 0x04))
#define P2_IOCR12     (*(volatile unsigned int*)(P2_BASE_ADDR + 0x1C))

#define LED0          14
#define LED1          15

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  P2_IOCR12 &= (unsigned int)~0xFFFF0000;
  P2_IOCR12 |= 0x80800000;
  P2_OUT    &= ~((1ul << LED0) | (1uL << LED1));
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    P2_OUT |= (1uL << LED0);
  } else if (Index == 1) {
    P2_OUT |= (1uL << LED1);
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    P2_OUT &= ~(1uL << LED0);
  } else if (Index == 1) {
    P2_OUT &= ~(1uL << LED1);
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    P2_OMR |= (1uL << LED0) | (1uL << (LED0 + 16));
  } else if (Index == 1) {
    P2_OMR |= (1uL << LED1) | (1uL << (LED1 + 16));
  }
}

/****** End Of File *************************************************/
