/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for XMC4700 eval board
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define P5_BASE_ADDR  0x48028500u
#define P5_OUT        (*(volatile unsigned int*) (P5_BASE_ADDR + 0x00u))
#define P5_OMR        (*(volatile unsigned int*) (P5_BASE_ADDR + 0x04u))
#define P5_IOCR8      (*(volatile unsigned int*) (P5_BASE_ADDR + 0x18u))

#define LED1  9  // LED1 P5.9 red
#define LED2  8  // LED2 P5.8 red

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  P5_IOCR8 &= 0xFFFF0000u;                        // Reset
  P5_IOCR8 |= 0x00008080u;                        // General-purpose output (push-pull)
  P5_OUT   &= ~( (1u << LED1) | (1u << LED2) );   // Set LED1 and LED2 output to zero
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    P5_OUT |= (1u << LED1);
  } else if (Index == 1) {
    P5_OUT |= (1u << LED2);
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    P5_OUT &= ~(1u << LED1);
  } else if (Index == 1) {
    P5_OUT &= ~(1u << LED2);
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    P5_OMR |= (1u << LED1) | (1u << (LED1 + 16));
  } else if (Index == 1) {
    P5_OMR |= (1u << LED2) | (1u << (LED2 + 16));
  }
}

/****** End Of File *************************************************/
