/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
Purpose : BSP for the Maxim MAX3263X EVK
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define LED0_BIT                    (0)                                       // LED0, low is on
#define LED1_BIT                    (1)                                       // LED1, low is on
#define LED2_BIT                    (2)                                       // LED2, low is on
#define LED3_BIT                    (3)                                       // LED3, low is on

#define CLKMAN_SYS_CLK_CTRL_6_GPIO  (*(volatile unsigned int*)(0x40000458u))  // Control Settings for GPIO Input Clock
#define GPIO_OUT_MODE_P3            (*(volatile unsigned int*)(0x4000A08Cu))  // Port P3 GPIO Output Drive Mode
#define GPIO_OUT_VAL_P3             (*(volatile unsigned int*)(0x4000A0CCu))  // Port P3 GPIO Output Value

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  CLKMAN_SYS_CLK_CTRL_6_GPIO =  (1u << 0);               // Enable Port P3 clock
  GPIO_OUT_VAL_P3           |=  (1u << LED0_BIT)         // Set LEDs to off
                            |   (1u << LED1_BIT)
                            |   (1u << LED2_BIT)
                            |   (1u << LED3_BIT)
                            ;
  GPIO_OUT_MODE_P3          &= ~(15u << (LED0_BIT * 4))  // Clear Mode bit
                            &  ~(15u << (LED1_BIT * 4))
                            &  ~(15u << (LED2_BIT * 4))
                            &  ~(15u << (LED3_BIT * 4))
                            ;
  GPIO_OUT_MODE_P3          |=  (1u << (LED0_BIT * 4))   // Set Mode bit
                            |   (1u << (LED1_BIT * 4))
                            |   (1u << (LED2_BIT * 4))
                            |   (1u << (LED3_BIT * 4))
                            ;
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  switch (Index) {
  case 0:
    GPIO_OUT_VAL_P3 &= ~(1u << LED0_BIT);
    break;
  case 1:
    GPIO_OUT_VAL_P3 &= ~(1u << LED1_BIT);
    break;
  case 2:
    GPIO_OUT_VAL_P3 &= ~(1u << LED2_BIT);
    break;
  case 3:
    GPIO_OUT_VAL_P3 &= ~(1u << LED3_BIT);
    break;
  default:
    break;
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  switch (Index) {
  case 0:
    GPIO_OUT_VAL_P3 |= (1u << LED0_BIT);
    break;
  case 1:
    GPIO_OUT_VAL_P3 |= (1u << LED1_BIT);
    break;
  case 2:
    GPIO_OUT_VAL_P3 |= (1u << LED2_BIT);
    break;
  case 3:
    GPIO_OUT_VAL_P3 |= (1u << LED3_BIT);
    break;
  default:
    break;
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  switch (Index) {
  case 0:
    GPIO_OUT_VAL_P3 ^= (1u << LED0_BIT);
    break;
  case 1:
    GPIO_OUT_VAL_P3 ^= (1u << LED1_BIT);
    break;
  case 2:
    GPIO_OUT_VAL_P3 ^= (1u << LED2_BIT);
    break;
  case 3:
    GPIO_OUT_VAL_P3 ^= (1u << LED3_BIT);
    break;
  default:
    break;
  }
}

/*************************** End of file ****************************/
