/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define PORTB_BASE_ADDR  0x41004480u
#define PORTB_DIRSET     (*(volatile unsigned int*)(PORTB_BASE_ADDR + 0x08))
#define PORTB_OUTCLR     (*(volatile unsigned int*)(PORTB_BASE_ADDR + 0x14))
#define PORTB_OUTSET     (*(volatile unsigned int*)(PORTB_BASE_ADDR + 0x18))
#define PORTB_OUTTGL     (*(volatile unsigned int*)(PORTB_BASE_ADDR + 0x1C))

#define LED0_BIT_MASK    (1u << 30)  // Yellow LED0 connected to PB30, low active

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  PORTB_DIRSET = LED0_BIT_MASK;
  PORTB_OUTSET = LED0_BIT_MASK;
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    PORTB_OUTCLR = LED0_BIT_MASK;  
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    PORTB_OUTSET = LED0_BIT_MASK;
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    PORTB_OUTTGL = LED0_BIT_MASK;
  }
}

/****** End Of File *************************************************/
