/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
Purpose : BSP for Microchip (Atmel) SAMD51 XPlained Pro
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/

#define PORTC_BASE_ADDR  (0x41008100u)
#define PORTC_DIR        (*(volatile unsigned int*)(PORTC_BASE_ADDR + 0x00u))  // Data direction
#define PORTC_OUTCLR     (*(volatile unsigned int*)(PORTC_BASE_ADDR + 0x14u))  // Data output value clear
#define PORTC_OUTSET     (*(volatile unsigned int*)(PORTC_BASE_ADDR + 0x18u))  // Data output value set
#define PORTC_OUTTGL     (*(volatile unsigned int*)(PORTC_BASE_ADDR + 0x1Cu))  // Data output value toggle

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  PORTC_DIR    |= (1u << 18);  // Yellow LED0 connected to PC18
  PORTC_OUTSET |= (1u << 18);  // Active low
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    PORTC_OUTCLR |= (1u << 18);
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    PORTC_OUTSET |= (1u << 18);
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    PORTC_OUTTGL |= (1u << 18);
  }
}

/*************************** End of file ****************************/
