/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for Microchip SAME70 XPlained eval board
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"
#include "same70.h"

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  PMC->PMC_WPMR  = 0x504D4300;            // Disable write protect
  PMC->PMC_PCER0 = (1UL << ID_PIOC);      // enable PIOC clock

  PIOC->PIO_PER  = PIO_PC8;
  PIOC->PIO_OER  = PIO_PC8;
  PIOC->PIO_PUDR = PIO_PC8;
  PIOC->PIO_OWER = PIO_PC8;               // Setup PC9 for LEDs

  PMC->PMC_WPMR = 0x504D4301;             // Enable write protect
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    PIOC->PIO_CODR = PIO_PC8;
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    PIOC->PIO_SODR = PIO_PC8;
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    if (PIOC->PIO_ODSR & PIO_PC8) {
      PIOC->PIO_CODR = PIO_PC8;
    } else {
      PIOC->PIO_SODR = PIO_PC8;
    }
  }
}

/****** End Of File *************************************************/
