/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for Atmel SAMR21 XPlained Ultra eval board
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define PORTA_BASE_ADDR  0x41004400u
#define PORTA_DIRSET     (*(volatile unsigned int*)(PORTA_BASE_ADDR + 0x08))
#define PORTA_OUTCLR     (*(volatile unsigned int*)(PORTA_BASE_ADDR + 0x14))
#define PORTA_OUTSET     (*(volatile unsigned int*)(PORTA_BASE_ADDR + 0x18))
#define PORTA_OUTTGL     (*(volatile unsigned int*)(PORTA_BASE_ADDR + 0x1C))

#define LED0_BIT_MASK    (1u << 19)  // Yellow LED0 connected to PA19, low active

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  //
  // Setup PA19 for LED0 (Yellow LED0)
  //
  PORTA_DIRSET = LED0_BIT_MASK;
  PORTA_OUTSET = LED0_BIT_MASK;
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    PORTA_OUTCLR = LED0_BIT_MASK;  
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    PORTA_OUTSET = LED0_BIT_MASK;
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    PORTA_OUTTGL = LED0_BIT_MASK;
  }
}

/****** End Of File *************************************************/
