/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for Freescale Kinetis K26
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"
#include "MK21FA12.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define LED0_BIT                      (4u)  // PTD4, Green user LED, low active
#define LED1_BIT                      (5u)  // PTD5, Yellow user LED, low active
#define LED2_BIT                      (6u)  // PTD6, Orange user LED, low active
#define LED3_BIT                      (7u)  // PTD7, Blue user LED, low active
#define LED0_MASK                     (1u << LED0_BIT)
#define LED1_MASK                     (1u << LED1_BIT)
#define LED2_MASK                     (1u << LED2_BIT)
#define LED3_MASK                     (1u << LED3_BIT)
#define NUM_LEDS                      (4)

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  unsigned int reg;
  reg           = SIM_SCGC5;
  reg          &= ~SIM_SCGC5_PORTD_MASK;
  reg          |= (1u << SIM_SCGC5_PORTD_SHIFT);
  SIM_SCGC5     = reg;                // Slow slew rate

  reg           = PORTD_PCR4;
  PORTD_PCR4   |= PORT_PCR_SRE_MASK   // Slow slew rate
               |  PORT_PCR_ODE_MASK   // Open Drain Enable
               |  PORT_PCR_DSE_MASK;  // High drive strength
  PORTD_PCR4    = reg;
  PORTD_PCR4    = PORT_PCR_MUX(1);    // Alternative 1 (GPIO)

  reg           = PORTD_PCR5;
  PORTD_PCR5   |= PORT_PCR_SRE_MASK   // Slow slew rate
               |  PORT_PCR_ODE_MASK   // Open Drain Enable
               |  PORT_PCR_DSE_MASK;  // High drive strength
  PORTD_PCR5    = reg;
  PORTD_PCR5    = PORT_PCR_MUX(1);    // Alternative 1 (GPIO)

  reg           = PORTD_PCR6;
  PORTD_PCR6   |= PORT_PCR_SRE_MASK   // Slow slew rate
               |  PORT_PCR_ODE_MASK   // Open Drain Enable
               |  PORT_PCR_DSE_MASK;  // High drive strength
  PORTD_PCR6    = reg;
  PORTD_PCR6    = PORT_PCR_MUX(1);    // Alternative 1 (GPIO)

  reg           = PORTD_PCR7;
  PORTD_PCR7   |= PORT_PCR_SRE_MASK   // Slow slew rate
               |  PORT_PCR_ODE_MASK   // Open Drain Enable
               |  PORT_PCR_DSE_MASK;  // High drive strength
  PORTD_PCR7    = reg;
  PORTD_PCR7    = PORT_PCR_MUX(1);    // Alternative 1 (GPIO)

  GPIOD_PSOR    = LED0_MASK | LED1_MASK | LED2_MASK | LED3_MASK;  // Set output high
  GPIOD_PDDR    = LED0_MASK | LED1_MASK | LED2_MASK | LED3_MASK;  // Output Enable
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index < NUM_LEDS) {
    GPIOD_PCOR = (1u << (LED0_BIT + Index));   // Set output low
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index < NUM_LEDS) {
    GPIOD_PSOR = (1u << (LED0_BIT + Index));   // Set output high
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index < NUM_LEDS) {
    GPIOD_PTOR = (1u << (LED0_BIT + Index));  // Toggle output
  }
}

/****** End Of File *************************************************/
