/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for Freescale Kinetis K22 and FRDM_K22F evalboard
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"
#include "MK22F51212.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define LED0_BIT                      (1u)  // PTA1, Red user LED, low active
#define LED0_MASK                     (1u << LED0_BIT)
#define LED1_BIT                      (2u)  // PTA2, Green user LED, low active
#define LED1_MASK                     (1u << LED1_BIT)

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  unsigned int reg;

  reg         = SIM_SCGC5;
  reg        &= ~SIM_SCGC5_PORTA_MASK;
  reg        |= (1uL << SIM_SCGC5_PORTA_SHIFT);
  SIM_SCGC5   = reg;                // Slow slew rate

  PORTA_PCR1 = PORT_PCR_MUX(1)      // Alternative 1 (GPIO)
             | PORT_PCR_SRE_MASK    // Slow slew rate
             | PORT_PCR_ODE_MASK    // Open Drain Enable
             | PORT_PCR_DSE_MASK;   // High drive strength
  GPIOA_PSOR |= LED0_MASK;          // Set output high
  GPIOA_PDDR |= LED0_MASK;          // Output Enable

  PORTA_PCR2 = PORT_PCR_MUX(1)      // Alternative 1 (GPIO)
             | PORT_PCR_SRE_MASK    // Slow slew rate
             |  PORT_PCR_ODE_MASK   // Open Drain Enable
             |  PORT_PCR_DSE_MASK;  // High drive strength
  GPIOA_PSOR |= LED1_MASK;          // Set output high
  GPIOA_PDDR |= LED1_MASK;          // Output Enable

}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    GPIOA_PCOR = LED0_MASK;   // Set output low
  } else if (Index == 1) {
    GPIOA_PCOR = LED1_MASK;   // Set output low
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    GPIOA_PSOR = LED0_MASK;   // Set output high
  } else if (Index == 1) {
    GPIOA_PSOR = LED1_MASK;   // Set output high
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    GPIOA_PTOR = LED0_MASK;  // Toggle output
  } else if (Index == 1) {
    GPIOA_PTOR = LED1_MASK;  // Toggle output
  }
}

/****** End Of File *************************************************/
