/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for Freescale Kinetis K26
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"
#include "MK26F18.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define LED0_BIT                      (3u)  // PTB3, Green user LED, low active
#define LED0_MASK                     (1u << LED0_BIT)

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  unsigned int reg;
  reg           = SIM_SCGC5;
  reg          &= ~SIM_SCGC5_PORTB_MASK;
  reg          |= (1uL << SIM_SCGC5_PORTB_SHIFT);
  SIM_SCGC5     = reg;                // Slow slew rate

  reg           = PORTB_PCR3;
  PORTA_PCR10  |= PORT_PCR_SRE_MASK   // Slow slew rate
               |  PORT_PCR_ODE_MASK   // Open Drain Enable
               |  PORT_PCR_DSE_MASK;  // High drive strength
  PORTB_PCR3    = reg;

  PORTB_PCR3    = PORT_PCR_MUX(1);    // Alternative 1 (GPIO)

  GPIOB_PSOR    = LED0_MASK;          // Set output high
  GPIOB_PDDR    = LED0_MASK;          // Output Enable
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    GPIOB_PCOR = LED0_MASK;   // Set output low
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    GPIOB_PSOR = LED0_MASK;   // Set output high
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    GPIOB_PTOR = LED0_MASK;  // Toggle output
  }
}

/****** End Of File *************************************************/
