/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for Freescale Kinetis K60
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"
#include "MK60F12.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define SIM_SCGC5_PORTA_SHIFT         9

//
// Assignment of LEDs
//
#define LED0_BIT                      (10)
#define LED1_BIT                      (11)
#define LEDMASK_ALL                   ((1uL << LED0_BIT) | (1uL << LED1_BIT))

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  unsigned int reg;
  reg             = SIM->SCGC5;
  reg            &= ~SIM_SCGC5_PORTA_MASK;
  reg            |= (1uL << SIM_SCGC5_PORTA_SHIFT);
  SIM->SCGC5      = reg;                // Slow slew rate
  reg             = PORTA->PCR[11];
  reg            |= PORT_PCR_SRE_MASK   // Slow slew rate
                 |  PORT_PCR_ODE_MASK   // Open Drain Enable
                 |  PORT_PCR_DSE_MASK;  // High drive strength
  PORTA->PCR[11]  = reg;
  PORTA->PCR[11]  = PORT_PCR_MUX(1);    // Alternative 1 (GPIO)
  reg             = PORTA->PCR[10];
  PORTA->PCR[10] |= PORT_PCR_SRE_MASK   // Slow slew rate
                 |  PORT_PCR_ODE_MASK   // Open Drain Enable
                 |  PORT_PCR_DSE_MASK;  // High drive strength
  PORTA->PCR[10]  = reg;
  PORTA->PCR[10]  = PORT_PCR_MUX(1);    // Alternative 1 (GPIO)
  PTA->PSOR       = LEDMASK_ALL;        // Set output high
  PTA->PDDR       = LEDMASK_ALL;        // Output Enable
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  PTA->PCOR = (1uL << (Index + LED0_BIT));   // Set output low
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  PTA->PSOR = (1uL << (Index + LED0_BIT));   // Set output high
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  PTA->PTOR = (1uL << (Index + LED0_BIT));   // Toggle output
}

/****** End Of File *************************************************/
