/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for NXP (Freescale) TWR-K65F180M
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/

#define SIM_BASE_ADDR    (0x40047000u)
#define SIM_SCGC5        (*(unsigned int*)(SIM_BASE_ADDR + 0x1038u))

#define PORTB_BASE_ADDR  (0x4004A000u)
#define PORTB_PCR4       (*(unsigned int*)(PORTB_BASE_ADDR + 0x10u))
#define PORTB_PCR5       (*(unsigned int*)(PORTB_BASE_ADDR + 0x14u))

#define GPIOB_BASE_ADDR  (0x400FF040u)
#define GPIOB_PSOR       (*(unsigned int*)(GPIOB_BASE_ADDR + 0x04u))
#define GPIOB_PCOR       (*(unsigned int*)(GPIOB_BASE_ADDR + 0x08u))
#define GPIOB_PTOR       (*(unsigned int*)(GPIOB_BASE_ADDR + 0x0Cu))
#define GPIOB_PDDR       (*(unsigned int*)(GPIOB_BASE_ADDR + 0x14u))

#define LED0_BIT         (4)
#define LED1_BIT         (5)
#define LEDMASK_ALL      ((1u << LED0_BIT) | (1u << LED1_BIT))

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  SIM_SCGC5  |= (1u << 10);   // Enable PORTB clock
  PORTB_PCR4  = (1u <<  8);   // Alternative 1 (GPIO) 
  PORTB_PCR5  = (1u <<  8);   // Alternative 1 (GPIO) 
  GPIOB_PSOR  = LEDMASK_ALL;  // Disable all LEDs
  GPIOB_PDDR |= LEDMASK_ALL;  // Set all pins to output
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index < 2) {
    GPIOB_PCOR = (1u << (Index + LED0_BIT));
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index < 2) {
    GPIOB_PSOR = (1u << (Index + LED0_BIT));
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index < 2) {
    GPIOB_PTOR = (1u << (Index + LED0_BIT));
  }
}

/****** End Of File *************************************************/
