/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for LPC1000 evalutaion board
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define GPIO0_BASE_ADDR  0x50000000

#define GPIO0DATA_PIN01  (*(volatile unsigned int*) (GPIO0_BASE_ADDR + 0x008))
#define GPIO0DATA_PIN02  (*(volatile unsigned int*) (GPIO0_BASE_ADDR + 0x010))
#define GPIO0DIR         (*(volatile unsigned int*) (GPIO0_BASE_ADDR + 0x8000))

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  GPIO0DIR        |= 0x06;  // Set Port GPIO01 and GPIO02 as outputs
  GPIO0DATA_PIN01  = 0x00;  // Set Led0 off
  GPIO0DATA_PIN02  = 0x00;  // Set Led1 off
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    GPIO0DATA_PIN01 = 0x02;
  } else if (Index == 1) {
    GPIO0DATA_PIN02 = 0x04;
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    GPIO0DATA_PIN01 = 0x00;
  } else if (Index == 1) {
    GPIO0DATA_PIN02 = 0x00;
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    GPIO0DATA_PIN01 ^= 0x02;
  } else if (Index == 1) {
    GPIO0DATA_PIN02 ^= 0x04;
  }
}

/****** End Of File *************************************************/
