/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for a LPC1833 custom board
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define LED0_MASK      (1uL << 11)
#define LED1_MASK      (1uL << 12)
#define LED2_MASK      (1uL << 13)
#define LED_MASK_ALL   (LED0_MASK | LED1_MASK | LED2_MASK)

#define LPC_SCU_BASE   (0x40086000)
#define SCU_SFSP2_11   (*(volatile unsigned int *)(LPC_SCU_BASE + 0x12C))  //  Pin configuration register for pin P2_11
#define SCU_SFSP2_12   (*(volatile unsigned int *)(LPC_SCU_BASE + 0x130))  //  Pin configuration register for pin P2_12
#define SCU_SFSP2_13   (*(volatile unsigned int *)(LPC_SCU_BASE + 0x134))  //  Pin configuration register for pin P2_13

#define LPC_GPIO_BASE  (0x400F4000)
#define GPIO_DIR1      (*(volatile unsigned int *)(LPC_GPIO_BASE + 0x2004))  //  Pin output register
#define GPIO_SET1      (*(volatile unsigned int *)(LPC_GPIO_BASE + 0x2204))  //  Pin set register
#define GPIO_CLR1      (*(volatile unsigned int *)(LPC_GPIO_BASE + 0x2284))  //  Pin clear register
#define GPIO_NOT1      (*(volatile unsigned int *)(LPC_GPIO_BASE + 0x2304))  //  Pin toggle register

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  //
  // Init LEDs
  //
  SCU_SFSP2_11 = 0x08;
  SCU_SFSP2_12 = 0x08;
  SCU_SFSP2_13 = 0x08;
  GPIO_DIR1 |= LED_MASK_ALL;
  //
  // All LEDs off
  //
  GPIO_CLR1 |= LED_MASK_ALL;
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    GPIO_SET1 |= LED0_MASK;
  } else if (Index == 1) {
    GPIO_SET1 |= LED1_MASK;
  } else if (Index == 2) {
    GPIO_SET1 |= LED2_MASK;
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    GPIO_CLR1 |= LED0_MASK;
  } else if (Index == 1) {
    GPIO_CLR1 |= LED1_MASK;
  } else if (Index == 2) {
    GPIO_CLR1 |= LED2_MASK;
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    GPIO_NOT1 |= LED0_MASK;
  } else if (Index == 1) {
    GPIO_NOT1 |= LED1_MASK;
  } else if (Index == 2) {
    GPIO_NOT1 |= LED2_MASK;
  }
}

/****** End Of File *************************************************/
