/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for LPCXpresso 4367 evalboard
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define LED0_MASK      (1u << 5)  // P6.9 Blue, GPIO3[5]
#define LED1_MASK      (1u << 7)  // P6.11 Red, GPIO3[7] 
#define LED2_MASK      (1u << 7)  // P2.7 Green, GPIO0[7]
#define LED_MASK_ALL   (LED0_MASK | LED1_MASK)
                       
#define LPC_SCU_BASE   0x40086000
#define SCU_SFSP6_9    (*(volatile unsigned int *)(LPC_SCU_BASE + 0x0324u))   // Pin configuration register for pin P6_9
#define SCU_SFSP6_11   (*(volatile unsigned int *)(LPC_SCU_BASE + 0x032Cu))   // Pin configuration register for pin P6_11
#define SCU_SFSP2_7    (*(volatile unsigned int *)(LPC_SCU_BASE + 0x011Cu))   // Pin configuration register for pin P2_7

#define LPC_GPIO_BASE  0x400F4000
#define GPIO_DIR0      (*(volatile unsigned int *)(LPC_GPIO_BASE + 0x2000u))  // Pin output register
#define GPIO_SET0      (*(volatile unsigned int *)(LPC_GPIO_BASE + 0x2200u))  // Pin set register
#define GPIO_CLR0      (*(volatile unsigned int *)(LPC_GPIO_BASE + 0x2280u))  // Pin clear register
#define GPIO_NOT0      (*(volatile unsigned int *)(LPC_GPIO_BASE + 0x2300u))  // Pin toggle register

#define GPIO_DIR3      (*(volatile unsigned int *)(LPC_GPIO_BASE + 0x200Cu))  // Pin output register
#define GPIO_SET3      (*(volatile unsigned int *)(LPC_GPIO_BASE + 0x220Cu))  // Pin set register
#define GPIO_CLR3      (*(volatile unsigned int *)(LPC_GPIO_BASE + 0x228Cu))  // Pin clear register
#define GPIO_NOT3      (*(volatile unsigned int *)(LPC_GPIO_BASE + 0x230Cu))  // Pin toggle register

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  //
  // Init LEDs
  //
  SCU_SFSP6_9  = 0x08;
  SCU_SFSP6_11 = 0x08;
  SCU_SFSP2_7  = 0x08;
  GPIO_DIR3 |= LED_MASK_ALL;
  GPIO_DIR0 |= LED2_MASK;
  //
  // All LEDs off
  //
  GPIO_SET3 |= LED_MASK_ALL;
  GPIO_SET0 |= LED2_MASK;
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    GPIO_CLR3 |= LED0_MASK;
  } else if (Index == 1) {
    GPIO_CLR3 |= LED1_MASK;
  } else if (Index == 2) {
    GPIO_CLR0 |= LED2_MASK;
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    GPIO_SET3 |= LED0_MASK;
  } else if (Index == 1) {
    GPIO_SET3 |= LED1_MASK;
  } else if (Index == 2) {
    GPIO_SET0 |= LED2_MASK;
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    GPIO_NOT3 |= LED0_MASK;
  } else if (Index == 1) {
    GPIO_NOT3 |= LED1_MASK;
  } else if (Index == 2) {
    GPIO_NOT0 |= LED2_MASK;
  }
}

/****** End Of File *************************************************/
