/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for NXP LPCXpresso54608 eval board
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define LED0 (14u)  // P3_14
#define LED1 ( 3u)  // P3_3

#define AHB_CLKCTRL0  (*(volatile unsigned int *)(0x40000000u + 0x200u))

#define IOCON_BASE    (0x40001000u)
#define IOCON3        ((IOCON_BASE + 0x180u))
#define IOCON3_3      (*(volatile unsigned int *)(IOCON3 + (4u * LED1)))
#define IOCON3_14     (*(volatile unsigned int *)(IOCON3 + (4u * LED0)))

#define GPIO3_BASE    (0x4008C000u)
#define GPIO3_DIR3    (*(volatile unsigned int *)(GPIO3_BASE + 0x200Cu))
#define GPIO3_SET3    (*(volatile unsigned int *)(GPIO3_BASE + 0x220Cu))
#define GPIO3_CLR3    (*(volatile unsigned int *)(GPIO3_BASE + 0x228Cu))
#define GPIO3_NOT3    (*(volatile unsigned int *)(GPIO3_BASE + 0x230Cu))

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  AHB_CLKCTRL0 |=  (1u << 13u);  // enables clock for the IOCON block
  IOCON3_3      =   0xA0u;       // reset IO configuration
  IOCON3_14     =   0xA0u;       // reset IO configuration
  AHB_CLKCTRL0 &= ~(1u << 13u);  // disables clock for the IOCON block to save power
  AHB_CLKCTRL0 |=  (1u << 17u);  // enables clock for the GPIO33 port registers
  GPIO3_SET3    = (1u << LED0);  // Clear LED0
  GPIO3_SET3    = (1u << LED1);  // Clear LED1
  GPIO3_DIR3   |= (1u << LED0);  // Set LED0 to output
  GPIO3_DIR3   |= (1u << LED1);  // Set LED1 to output
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    GPIO3_CLR3 = 1u << LED0;
  } else if (Index == 1) {
    GPIO3_CLR3 = 1u << LED1;
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    GPIO3_SET3 = 1u << LED0;
  } else if (Index == 1) {
    GPIO3_SET3 = 1u << LED1;
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    GPIO3_NOT3 = 1u << LED0;
  } else if (Index == 1) {
    GPIO3_NOT3 = 1u << LED1;
  }
}

/****** End Of File *************************************************/
