/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for NXP S32K144EVB-Q100
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define LED0  ( 0u)  // BLUE   PTD0  (04)
#define LED1  (15u)  // RED    PTD15 (22)
#define LED2  (16u)  // GREEN  PTD16 (21)

#define LED0_MASK  (1u << LED0)
#define LED1_MASK  (1u << LED1)
#define LED2_MASK  (1u << LED2)

#define PCC_BASE_ADDR  (0x40065000u)
#define PCC_PORTD      (*(volatile unsigned int*)(PCC_BASE_ADDR + 0x130u))

#define PORTD_BASE_ADDR  (0x4004C000u)
#define PORTD_PCR0       (*(volatile unsigned int*)(PORTD_BASE_ADDR + 0x00u))
#define PORTD_PCR15      (*(volatile unsigned int*)(PORTD_BASE_ADDR + 0x3Cu))
#define PORTD_PCR16      (*(volatile unsigned int*)(PORTD_BASE_ADDR + 0x40u))

#define GPIOD_BASE_ADDR  (0x400FF0C0u)
#define GPIOD_PDOR       (*(volatile unsigned int*)(GPIOD_BASE_ADDR + 0x00u))
#define GPIOD_PSOR       (*(volatile unsigned int*)(GPIOD_BASE_ADDR + 0x04u))
#define GPIOD_PCOR       (*(volatile unsigned int*)(GPIOD_BASE_ADDR + 0x08u))
#define GPIOD_PTOR       (*(volatile unsigned int*)(GPIOD_BASE_ADDR + 0x0Cu))
#define GPIOD_PDIR       (*(volatile unsigned int*)(GPIOD_BASE_ADDR + 0x10u))
#define GPIOD_PDDR       (*(volatile unsigned int*)(GPIOD_BASE_ADDR + 0x14u))
#define GPIOD_PIDR       (*(volatile unsigned int*)(GPIOD_BASE_ADDR + 0x18u))

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  PCC_PORTD   = (1u << 30u);  // Enable clocking for PORTD
  PORTD_PCR0  = (1u <<  8u);  // Select Alt1 (GPIO)
  PORTD_PCR15 = (1u <<  8u);  // Select Alt1 (GPIO)
  PORTD_PCR16 = (1u <<  8u);  // Select Alt1 (GPIO)
  GPIOD_PDDR  = GPIOD_PDDR
              | LED0_MASK     // Set LED0 pin to output
              | LED1_MASK     // Set LED1 pin to output
              | LED2_MASK     // Set LED2 pin to output
              ;
  GPIOD_PSOR  = 0u
              | LED0_MASK     // Disable LED0
              | LED1_MASK     // Disable LED1 
              | LED2_MASK     // Disable LED2
              ;
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    GPIOD_PCOR = LED0_MASK;
  } else if (Index == 1) {
    GPIOD_PCOR = LED1_MASK;
  } else if (Index == 2) {
    GPIOD_PCOR = LED2_MASK;
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    GPIOD_PSOR = LED0_MASK;
  } else if (Index == 1) {
    GPIOD_PSOR = LED1_MASK;
  } else if (Index == 2) {
    GPIOD_PSOR = LED2_MASK;
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    GPIOD_PTOR = LED0_MASK;
  } else if (Index == 1) {
    GPIOD_PTOR = LED1_MASK;
  } else if (Index == 2) {
    GPIOD_PTOR = LED2_MASK;
  }
}

/****** End Of File *************************************************/
