/*
** ###################################################################
**     Processors:          MIMXRT1176AVM8A_cm4
**                          MIMXRT1176CVM8A_cm4
**                          MIMXRT1176DVMAA_cm4
**
**     Compilers:           Freescale C/C++ for Embedded ARM
**                          GNU C Compiler
**                          IAR ANSI C/C++ Compiler for ARM
**                          Keil ARM C/C++ Compiler
**                          MCUXpresso Compiler
**
**     Reference manual:    IMXRT1170RM_initial_draft, 02/2018
**     Version:             rev. 0.1, 2018-03-05
**     Build:               b191113
**
**     Abstract:
**         Provides a system configuration function and a global variable that
**         contains the system frequency. It configures the device and initializes
**         the oscillator (PLL) that is part of the microcontroller device.
**
**     Copyright 2016 Freescale Semiconductor, Inc.
**     Copyright 2016-2019 NXP
**     All rights reserved.
**
**     SPDX-License-Identifier: BSD-3-Clause
**
**     http:                 www.nxp.com
**     mail:                 support@nxp.com
**
**     Revisions:
**     - rev. 0.1 (2018-03-05)
**         Initial version.
**
** ###################################################################
*/

/*!
 * @file MIMXRT1176_cm4
 * @version 0.1
 * @date 2018-03-05
 * @brief Device specific configuration file for MIMXRT1176_cm4 (implementation
 *        file)
 *
 * Provides a system configuration function and a global variable that contains
 * the system frequency. It configures the device and initializes the oscillator
 * (PLL) that is part of the microcontroller device.
 */

#include <stdint.h>
#include "fsl_device_registers.h"

#define CLOCK_DIVIDER                             (0u)  // Configurable to stabilize debug connection, divider value is always CLOCK_DIVIDER + 1

#define OSC_BASE_ADDR                             (0x40C84000u)
#define OSC_24M_CTRL                              (*(volatile unsigned int*)(OSC_BASE_ADDR + 0x20u))

#define PLL_BASE_ADDR                             (0x40C84000u)
#define SYS_PLL3_CTRL                             (*(volatile unsigned int*)(PLL_BASE_ADDR + 0x210u))
#define SYS_PLL2_CTRL                             (*(volatile unsigned int*)(PLL_BASE_ADDR + 0x240u))
#define SYS_PLL2_MFN                              (*(volatile unsigned int*)(PLL_BASE_ADDR + 0x280u))
#define SYS_PLL2_MFI                              (*(volatile unsigned int*)(PLL_BASE_ADDR + 0x290u))
#define SYS_PLL2_MFD                              (*(volatile unsigned int*)(PLL_BASE_ADDR + 0x2A0u))

#define PMU_BASE_ADDR                             (0x40C84000u)
#define PMU_LDO_PLL                               (*(volatile unsigned int*)(PMU_BASE_ADDR + 0x500u))
#define PMU_REF_CTRL                              (*(volatile unsigned int*)(PMU_BASE_ADDR + 0x570u))


#define CLOCK_ROOT1_CONTROL                       (0x40cc0080u)
#define CLOCK_ROOT1_CONTROL_SET                   (*(volatile unsigned int*)(CLOCK_ROOT1_CONTROL + 0x04u))
#define CLOCK_ROOT1_CONTROL_CLR                   (*(volatile unsigned int*)(CLOCK_ROOT1_CONTROL + 0x08u))

#define SYS_PLL2_UPDATE                           (*(volatile unsigned long*)(0x40c84250u))
#define SYS_PLL2_UPDATE_PFDX_UPDATE_MASK(x)       ((1uL << 1) << x)

#define SYS_PLL2_PFD                              (*(volatile unsigned long*)(0x40c84270u))
#define SYS_PLL2_PFD_PFDX_STABLE_MASK(x)          ((1uL << 6) << (8u * x))
#define SYS_PLL2_PFD_PFDX_DIV1_CLKGATE_MASK(x)    ((1uL << 7) << (8u * x))
#define SYS_PLL2_PFD_SET_PFDX_FRAC_MASK(x, Frac)  (SYS_PLL2_PFD = ((SYS_PLL2_PFD & ~(0x3FuL << (8u * x))) | (Frac << (8u * x))))

#define CLOCK_ROOT2_CONTROL                       (*(volatile unsigned long*)(0x40CC0100u))

void SetSysClock (void);

/* ----------------------------------------------------------------------------
   -- Core clock
   ---------------------------------------------------------------------------- */

uint32_t SystemCoreClock = DEFAULT_SYSTEM_CLOCK;

/* ----------------------------------------------------------------------------
   -- SystemInit()
   ---------------------------------------------------------------------------- */

void SystemInit (void) {
#if ((__FPU_PRESENT == 1) && (__FPU_USED == 1))
  SCB->CPACR |= ((3UL << 10*2) | (3UL << 11*2));    /* set CP10, CP11 Full Access */
#endif /* ((__FPU_PRESENT == 1) && (__FPU_USED == 1)) */

#if defined(__MCUXPRESSO)
    extern uint32_t g_pfnVectors[];  // Vector table defined in startup code
    SCB->VTOR = (uint32_t)g_pfnVectors;
#endif

/* Watchdog disable */

#if (DISABLE_WDOG)
    if ((WDOG1->WCR & WDOG_WCR_WDE_MASK) != 0U)
    {
        WDOG1->WCR &= ~WDOG_WCR_WDE_MASK;
    }
    if ((WDOG2->WCR & WDOG_WCR_WDE_MASK) != 0U)
    {
        WDOG2->WCR &= ~WDOG_WCR_WDE_MASK;
    }
    if ((RTWDOG3->CS & RTWDOG_CS_CMD32EN_MASK) != 0U)
    {
        RTWDOG3->CNT = 0xD928C520U; /* 0xD928C520U is the update key */
    }
    else
    {
        RTWDOG3->CNT = 0xC520U;
        RTWDOG3->CNT = 0xD928U;
    }
    RTWDOG3->TOVAL = 0xFFFF;
    RTWDOG3->CS = (uint32_t) ((RTWDOG3->CS) & ~RTWDOG_CS_EN_MASK) | RTWDOG_CS_UPDATE_MASK;
    if ((RTWDOG4->CS & RTWDOG_CS_CMD32EN_MASK) != 0U)
    {
        RTWDOG4->CNT = 0xD928C520U; /* 0xD928C520U is the update key */
    }
    else
    {
        RTWDOG4->CNT = 0xC520U;
        RTWDOG4->CNT = 0xD928U;
    }
    RTWDOG4->TOVAL = 0xFFFF;
    RTWDOG4->CS = (uint32_t) ((RTWDOG4->CS) & ~RTWDOG_CS_EN_MASK) | RTWDOG_CS_UPDATE_MASK;
#endif /* (DISABLE_WDOG) */

    /* Disable Systick which might be enabled by bootrom */
    if ((SysTick->CTRL & SysTick_CTRL_ENABLE_Msk) != 0U)
    {
        SysTick->CTRL &= ~SysTick_CTRL_ENABLE_Msk;
    }

/* Enable instruction and data caches */
#if defined(__ICACHE_PRESENT) && __ICACHE_PRESENT
    if (SCB_CCR_IC_Msk != (SCB_CCR_IC_Msk & SCB->CCR)) {
        SCB_EnableICache();
    }
#endif
#if defined(__DCACHE_PRESENT) && __DCACHE_PRESENT
    if (SCB_CCR_DC_Msk != (SCB_CCR_DC_Msk & SCB->CCR)) {
        SCB_EnableDCache();
    }
#endif
  SystemInitHook();
  SetSysClock();
}

/* ----------------------------------------------------------------------------
   -- SystemCoreClockUpdate()
   ---------------------------------------------------------------------------- */

void SystemCoreClockUpdate (void) {
  SystemCoreClock = (400000000u / (CLOCK_DIVIDER + 1u));
}

/* ----------------------------------------------------------------------------
   -- SetSysClock()
   ---------------------------------------------------------------------------- */

void SetSysClock (void) {
  volatile long i;
  unsigned long Stable0;
  unsigned long Stable;
  //
  // Check if 24Mhz XTAL is already stable and running
  //
  if ((OSC_24M_CTRL & 0x40000090u) != 0x40000010u) {
    OSC_24M_CTRL |=  (1u << 7);                 // Make sure XTAL is gated
    OSC_24M_CTRL |=  (1u << 4);                 // Enable XTAL
    while ((OSC_24M_CTRL & (1u << 30)) == 0) {
      ;  // Wait for XTAL to be stable
    }
    OSC_24M_CTRL &= ~(1u << 7);                 // Set XTAL to be not gated
  }
  //
  // Check if PLL3 is already stable, running and not gated
  //
  if ((SYS_PLL3_CTRL & 0x20202000u) != 0x20202000u) {
    SYS_PLL3_CTRL |= (1u << 30);                            // Make sure PLL is gated
    PMU_REF_CTRL  |= (1u << 3);                             // Enable the reference voltage
    SYS_PLL3_CTRL  = (SYS_PLL3_CTRL & ~(0x7u)) | (3 << 0);  // Set DIV_SELECT to 3
    PMU_LDO_PLL   |= (1u << 0);                             // Enable the internal LDO
    SYS_PLL3_CTRL |= (1u << 21);                            // Power up the PLL
    while ((SYS_PLL3_CTRL & (1u << 29)) == 0) {
      ;  // Wait for PLL to be stable
    }
    for (i = 0; i < 100; i++) {
      ;  // Wait at least 50us for the PLL to be locked
    }
    SYS_PLL3_CTRL |=  (1u << 13);                           // Enable clock output
    SYS_PLL3_CTRL &= ~(1u << 30);                           // Set PLL to be not gated
  }
  //
  // Configure Clock Root 1 (CM4 clock)
  //
  CLOCK_ROOT1_CONTROL_CLR = 0xFFFFFFFFu;
  CLOCK_ROOT1_CONTROL_SET = 0
                          | (CLOCK_DIVIDER << 0)       // DIV = CLOCK_DIVIDER + 1
                          | (5u            << 8)       // MUX = SYS_PLL3 (480Mhz)
                          | (4u            << 16)      // MFD = 5
                          | (1u            << 20)      // MFN = 1
                          ; // SYS_PLL3 / ( DIV + ( MFN / MFD)) = 400Mhz
  //
  // Check if PLL2 is already stable, running and not gated
  //
  if ((SYS_PLL2_CTRL & 0x60802000u) != 0x20802000u) {
    SYS_PLL2_CTRL |= (1u << 30);                              // Make sure PLL is gated
    PMU_REF_CTRL  |= (1u << 3);                               // Enable the reference voltage
    SYS_PLL2_CTRL  = (SYS_PLL2_CTRL & ~(0x7u));               // Clear DIV_SELECT
    SYS_PLL2_MFI   = (SYS_PLL2_MFN  & ~(0x7Fu)) | (22 << 0);  // Set MFI to 22
    SYS_PLL2_MFN   = (SYS_PLL2_MFN  & ~(0x3FFFFFFFu));        // Clear MFN
    PMU_LDO_PLL   |= (1u << 0);                               // Enable the internal LDO
    SYS_PLL2_CTRL |= (1u << 23);                              // Power up the PLL
    while ((SYS_PLL2_CTRL & (1u << 29)) == 0) {
      ;  // Wait for PLL to be stable
    }
    for (i = 0; i < 1000; i++) {
      ;  // Wait at least 450us for the PLL to be locked
    }
    SYS_PLL2_CTRL |=  (1u << 13);                             // Enable clock output
    SYS_PLL2_CTRL &= ~(1u << 30);                             // Set PLL to be not gated
  }
  //
  // Configure SYS_PLL2_PFD3 to "528MHz * 18 / 24 = 396MHz" .
  //
  Stable0          =  SYS_PLL2_PFD & SYS_PLL2_PFD_PFDX_STABLE_MASK(3u);  // Get current PFD3 stable bit. It is toggled for each stable update.
  SYS_PLL2_PFD    |=  SYS_PLL2_PFD_PFDX_DIV1_CLKGATE_MASK(3u);           // Disable the fractional divider clock.
  SYS_PLL2_PFD_SET_PFDX_FRAC_MASK(3u, 24u);                              // Set fractional divider of 24.
  SYS_PLL2_UPDATE ^=  SYS_PLL2_UPDATE_PFDX_UPDATE_MASK(3u);              // Toggle to update.
  SYS_PLL2_PFD    &= ~SYS_PLL2_PFD_PFDX_DIV1_CLKGATE_MASK(3u);           // Enable the fractional divider clock.
  do {
    Stable = SYS_PLL2_PFD & SYS_PLL2_PFD_PFDX_STABLE_MASK(3u);           // Get current PFD3 stable bit.
  } while (Stable == Stable0);                                           // Loop until stable bit gets toggled by hardware.
  //
  // Configure SYS_PLL2_PFD1 to "528MHz * 18 / 19 = 500MHz" .
  //
  Stable0          =  SYS_PLL2_PFD & SYS_PLL2_PFD_PFDX_STABLE_MASK(1u);  // Get current PFD1 stable bit. It is toggled for each stable update.
  SYS_PLL2_PFD    |=  SYS_PLL2_PFD_PFDX_DIV1_CLKGATE_MASK(1u);           // Disable the fractional divider clock.
  SYS_PLL2_PFD_SET_PFDX_FRAC_MASK(1u, 19u);                              // Set fractional divider of 19.
  SYS_PLL2_UPDATE ^=  SYS_PLL2_UPDATE_PFDX_UPDATE_MASK(1u);              // Toggle to update.
  SYS_PLL2_PFD    &= ~SYS_PLL2_PFD_PFDX_DIV1_CLKGATE_MASK(1u);           // Enable the fractional divider clock.
  do {
    Stable = SYS_PLL2_PFD & SYS_PLL2_PFD_PFDX_STABLE_MASK(1u);           // Get current PFD1 stable bit.
  } while (Stable == Stable0);                                           // Loop until stable bit gets toggled by hardware.
  CLOCK_ROOT2_CONTROL = (7u << 8u) | 1u;
}

/* ----------------------------------------------------------------------------
   -- SystemInitHook()
   ---------------------------------------------------------------------------- */

__attribute__ ((weak)) void SystemInitHook (void) {
  /* Void implementation of the weak function. */
}
