/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
File    : BSP.c
Purpose : BSP for Nuvoton NuTiny-SDK-NUC029LAN board
*/
#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/

//
// I/O LED, Red, GPIO 3 Pin 6, low is on
//
#define GPIO_BASE_ADDR  (0x50004000u)
#define GPIO3_PMD       (*(volatile unsigned int*)(GPIO_BASE_ADDR + 0xC0u))  // Pin mode register
#define GPIO3_DOUT      (*(volatile unsigned int*)(GPIO_BASE_ADDR + 0xC8u))  // Data output value register

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  GPIO3_PMD = (GPIO3_PMD & ~(0x3000)) | (1u << 12);  // Set Pin 6 to Push-Pull Output mode
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    GPIO3_DOUT &= ~(1u << 6);
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    GPIO3_DOUT |= (1u << 6);
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    GPIO3_DOUT ^= (1u << 6);
  }
}

/*************************** End of file ****************************/
