/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for STM32F072 Discovery
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define LED0_BIT                  (6u)
#define LED1_BIT                  (7u)
#define LED2_BIT                  (8u)
#define LED3_BIT                  (9u)
#define NUM_LED                   (4u)
#define LED_ALL_BIT_MASK          ((1u << (LED0_BIT << 1u)) | (1u << (LED1_BIT << 1u))| (1u << (LED2_BIT << 1u)) | (1u << (LED3_BIT << 1u)))
#define LED_ALL_OFF_BIT_MASK      ((1u << (LED0_BIT + 16u)) | (1u << (LED1_BIT + 16u))| (1u << (LED2_BIT + 16u)) | (1u << (LED3_BIT + 16u)))

#define GPIOC_BASE_ADDR           (0x48000800)
#define GPIOC_MODER               (*(volatile unsigned int*)(GPIOC_BASE_ADDR + 0x00u))
#define GPIOC_IDR                 (*(volatile unsigned int*)(GPIOC_BASE_ADDR + 0x10u))
#define GPIOC_BSRR                (*(volatile unsigned int*)(GPIOC_BASE_ADDR + 0x18u))

#define RCC_AHBENR                (*(volatile unsigned int*)(0x40021014u))
#define IOPAEN_BIT                (19u)

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  RCC_AHBENR  |= (1u << IOPAEN_BIT);
  GPIOC_MODER |= LED_ALL_BIT_MASK;
  GPIOC_BSRR   = LED_ALL_OFF_BIT_MASK;                      /* Initally switch off all LEDs */
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if ((Index >= 0) || ((unsigned int)Index < NUM_LED)) {
    GPIOC_BSRR |= (1u << (LED0_BIT + Index));              /* Switch LED on  */
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if ((Index >= 0) || ((unsigned int)Index < NUM_LED)) {
    GPIOC_BSRR |= (1u << (LED0_BIT + Index + 16u));        /* Switch LED off */
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if ((Index >= 0) || ((unsigned int)Index < NUM_LED)) {
    if (GPIOC_IDR & (1u << (LED0_BIT + Index))) {
      GPIOC_BSRR |= (1u << (LED0_BIT + Index + 16u));     /* Switch LED off */
    } else {
      GPIOC_BSRR |= (1u << (LED0_BIT + Index));           /* Switch LED on  */
    }
  }
}

/****** End Of File *************************************************/
