/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for STM32F103 (MB525)
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define _LED0_BIT  (6)
#define _LED1_BIT  (7)
#define _LED2_BIT  (8)
#define _LED3_BIT  (9)
#define _LED_MASK_ALL ((1uL << _LED0_BIT) | (1uL << _LED1_BIT) | (1uL << _LED2_BIT) | (1uL << _LED3_BIT) )

#define _GPIOC_BASE_ADDR           (0x40011000)
#define _LED_PORT_BASE_ADDR        (_GPIOC_BASE_ADDR)
#define GPIOC_CRL                  (*(volatile unsigned int*)(_LED_PORT_BASE_ADDR))
#define GPIOC_CRH                  (*(volatile unsigned int*)(_LED_PORT_BASE_ADDR + 0x04))
#define GPIOC_ODR                  (*(volatile unsigned int*)(_LED_PORT_BASE_ADDR + 0x0C))
#define GPIOC_BSRR                 (*(volatile unsigned int*)(_LED_PORT_BASE_ADDR + 0x10))
#define GPIOC_BRR                  (*(volatile unsigned int*)(_LED_PORT_BASE_ADDR + 0x14))
#define _SYSCTRL_RCC_APB2          (*(volatile unsigned int*)(0x40021018))
#define _SYSCTRL_LEDPORT_BIT       (4)

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  _SYSCTRL_RCC_APB2 |= (1uL << _SYSCTRL_LEDPORT_BIT);
  GPIOC_CRL  = (GPIOC_CRL & (0x00FFFFFFuL)) | 0x33000000uL;
  GPIOC_CRH  = (GPIOC_CRH & (0xFFFFFF00uL)) | 0x00000033uL;
  GPIOC_BRR |= _LED_MASK_ALL;   // Initially switch off all LEDS
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  GPIOC_BSRR |= (1uL << (_LED0_BIT + Index));             /* Switch LED on  */
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  GPIOC_BRR  |= (1uL << (_LED0_BIT + Index));             /* Switch LED off */
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if ((GPIOC_ODR & (1uL << (_LED0_BIT + Index))) == 0) {  /* LED is switched off */
    BSP_SetLED(Index);                                    /* Switch LED on  */
  } else {
    BSP_ClrLED(Index);                                    /* Switch LED off */
  }
}

/****** End Of File *************************************************/
