/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for STM32F103 (ST MB672)
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/

//
// GPIO
//
#define GPIO_BASE_ADDR         0x40010800

#define GPIOF_CRL_OFFS         0x1400
#define GPIOF_CRH_OFFS         0x1404
#define GPIOF_ODR_OFFS         0x140C
#define GPIOF_BSRR_OFFS        0x1410
#define GPIOF_BRR_OFFS         0x1414

#define GPIOF_CRL              (*(volatile unsigned int*)(GPIO_BASE_ADDR + GPIOF_CRL_OFFS))
#define GPIOF_CRH              (*(volatile unsigned int*)(GPIO_BASE_ADDR + GPIOF_CRH_OFFS))
#define GPIOF_ODR              (*(volatile unsigned int*)(GPIO_BASE_ADDR + GPIOF_ODR_OFFS))
#define GPIOF_BSRR             (*(volatile unsigned int*)(GPIO_BASE_ADDR + GPIOF_BSRR_OFFS))
#define GPIOF_BRR              (*(volatile unsigned int*)(GPIO_BASE_ADDR + GPIOF_BRR_OFFS))

//
// SYSCTRL
//
#define SYSCTRL_RCC_APB2   (*(volatile unsigned int*)0x40021018)

#define SYSCTRL_GPIOF_BIT  7

//
// LEDs
//
#define NUM_LEDS      4

#define LED0_BIT      6
#define LED1_BIT      7
#define LED2_BIT      8
#define LED3_BIT      9

#define LED_MASK_ALL  ((1uL << LED0_BIT) | (1uL << LED1_BIT) | (1uL << LED2_BIT) | (1uL << LED3_BIT))

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  //
  // Setup LEDs
  //
  SYSCTRL_RCC_APB2 |= (1uL << SYSCTRL_GPIOF_BIT);
  GPIOF_CRL         = ((GPIOF_CRL & 0x00FFFFFFuL) | 0x33000000uL);
  GPIOF_CRH         = ((GPIOF_CRH & 0xFFFFFF00uL) | 0x00000033uL);
  GPIOF_BRR        |= LED_MASK_ALL;  // Disable all LEDs
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index > (NUM_LEDS - 1)) {
    return;
  }
  GPIOF_BSRR |= (1uL << (LED0_BIT + Index));             // Switch on LED
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index > (NUM_LEDS - 1)) {
    return;
  }
  GPIOF_BRR |= (1uL << (LED0_BIT + Index));              // Switch off LED
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index > (NUM_LEDS - 1)) {
    return;
  }
  if ((GPIOF_ODR & (1uL << (LED0_BIT + Index))) == 0) {  // Toggle LED
    BSP_SetLED(Index);
  } else {
    BSP_ClrLED(Index);
  }
}

/****** End Of File *************************************************/
