/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for ST STM32F303_Nucleo board
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define GPIOB_BASE_ADDR           (0x48000400u)
#define GPIOB_MODER               (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x00u))
#define GPIOB_ODR                 (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x14u))

#define RCC_BASE_ADDR             (0x40021000u)
#define RCC_AHBENR                (*(volatile unsigned int*)(RCC_BASE_ADDR + 0x14u))
#define IOPBEN                    (18u)

#define LED0_BIT                  (3u)

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  //
  // Initialize port for LEDs (sample application)
  //
  RCC_AHBENR |= (1u << IOPBEN);                // Enable clock for Port B

  GPIOB_MODER &= ~(3u << (LED0_BIT << 1u));    // Reset mode, sets port to input
  GPIOB_MODER |=  (1u << (LED0_BIT << 1u ));   // Set to output mode
  GPIOB_ODR   |=  1u << LED0_BIT;              // Initially clear LEDs
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    GPIOB_ODR &= ~(1uL << LED0_BIT);           // Switch Led on
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    GPIOB_ODR |= (1uL << LED0_BIT);            // Switch Led off
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    GPIOB_ODR ^= (1uL << LED0_BIT);            // Toggle Led
  }
}

/****** End Of File *************************************************/
