/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
Purpose : BSP for ST STM32F401RE-Nucleo
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define RCC_BASE_ADDR    (0x40023800u)                                         // Reset and clock control base address
#define RCC_AHB1ENR      (*(volatile unsigned int*)(RCC_BASE_ADDR + 0x30u))    // AHB1 enable register

#define GPIOA_BASE_ADDR  (0x40020000u)                                         // GPIOA base address
#define GPIOA_MODER      (*(volatile unsigned int*)(GPIOA_BASE_ADDR + 0x00u))  // GPIOA port mode register
#define GPIOA_ODR        (*(volatile unsigned int*)(GPIOA_BASE_ADDR + 0x14u))  // GPIOA port output data register
#define GPIOA_BSRR       (*(volatile unsigned int*)(GPIOA_BASE_ADDR + 0x18u))  // GPIOA port bit set/reset register

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init() {
  RCC_AHB1ENR |= 0x1u;                // Enable Port A clock
  GPIOA_MODER |= 0x400u;              // Set Pin 5 to output
  GPIOA_BSRR  |= 0x200000u;           // Clear Pin 5
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    GPIOA_BSRR |= 0x20u;              // Set Pin 5
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    GPIOA_BSRR |= 0x200000u;          // Clear Pin 5
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    if ((GPIOA_ODR & 0x20u) != 0u) {  // Check current LED status
      GPIOA_BSRR |= 0x200000u;        // Clear Pin 5
    } else {
      GPIOA_BSRR |= 0x20u;            // Set Pin 5
    }
  }
}

/*************************** End of file ****************************/
