/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for the ST STM32F412G-Discovery eval board
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/

/****** SFRs used for LED-Port **************************************/

#define GPIOE_BASE_ADDR           ((unsigned int)0x40021000)

#define GPIOE_MODER               (*(volatile unsigned int*)(GPIOE_BASE_ADDR + 0x00))
#define GPIOE_ODR                 (*(volatile unsigned int*)(GPIOE_BASE_ADDR + 0x14))
#define GPIOE_BSRR                (*(volatile unsigned int*)(GPIOE_BASE_ADDR + 0x18))

#define RCC_BASE_ADDR             ((unsigned int)(0x40023800))
#define RCC_AHB1RSTR              (*(volatile unsigned int*)(RCC_BASE_ADDR + 0x10))
#define RCC_AHBENR                (*(volatile unsigned int*)(RCC_BASE_ADDR + 0x30))

#define RCC_LEDPORT_RSTR          RCC_AHB1RSTR
#define RCC_LEDPORT_ENR           RCC_AHBENR
#define RCC_LEDPORT_BIT           (4)

/****** Assign LEDs to Ports ****************************************/

#define LED_PORT_MODER            GPIOE_MODER
#define LED_PORT_ODR              GPIOE_ODR
#define LED_PORT_BSRR             GPIOE_BSRR

#define LED0_BIT                  (0)  // PE0
#define LED1_BIT                  (1)  // PE1
#define LED2_BIT                  (2)  // PE2
#define LED3_BIT                  (3)  // PE3

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  //
  // Initialize port for LEDs (sample application)
  //
  RCC_LEDPORT_ENR  &= ~(1uL << RCC_LEDPORT_BIT);
  RCC_LEDPORT_RSTR &= ~(1uL << RCC_LEDPORT_BIT);
  RCC_LEDPORT_ENR  |=  (1uL << RCC_LEDPORT_BIT);

  LED_PORT_MODER &= ~((3uL << (LED0_BIT * 2)) | (3uL << (LED1_BIT * 2)) | (3uL << (LED2_BIT * 2)) | (3uL << (LED3_BIT * 2)));  // Reset mode; sets port to input
  LED_PORT_MODER |=   (1uL << (LED0_BIT * 2)) | (1uL << (LED1_BIT * 2)) | (1uL << (LED2_BIT * 2)) | (1uL << (LED3_BIT * 2));   // Set to output mode
  LED_PORT_BSRR   =   (1uL << LED0_BIT)       | (1uL << LED1_BIT)       | (1uL << LED2_BIT)       | (1uL << LED3_BIT);         // Initially clear LEDs
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    LED_PORT_BSRR = (0x10000uL << LED0_BIT);  // Switch on LED0
  } else if (Index == 1) {
    LED_PORT_BSRR = (0x10000uL << LED1_BIT);  // Switch on LED1
  } else if (Index == 2) {
    LED_PORT_BSRR = (0x10000uL << LED2_BIT);  // Switch on LED2
  } else if (Index == 3) {
    LED_PORT_BSRR = (0x10000uL << LED3_BIT);  // Switch on LED3
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    LED_PORT_BSRR = (1uL << LED0_BIT);  // Switch off LED0
  } else if (Index == 1) {
    LED_PORT_BSRR = (1uL << LED1_BIT);  // Switch off LED1
  } else if (Index == 2) {
    LED_PORT_BSRR = (1uL << LED2_BIT);  // Switch off LED2
  } else if (Index == 3) {
    LED_PORT_BSRR = (1uL << LED3_BIT);  // Switch off LED3
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    if ((LED_PORT_ODR & (1uL << LED0_BIT)) == 0) {  // LED is switched off
      LED_PORT_BSRR = (1uL << LED0_BIT);            // Switch off LED0
    } else {
      LED_PORT_BSRR = (0x10000uL << LED0_BIT);      // Switch on LED0
    }
  } else if (Index == 1) {
    if ((LED_PORT_ODR & (1uL << LED1_BIT)) == 0) {  // LED is switched off
      LED_PORT_BSRR = (1uL << LED1_BIT);            // Switch off LED1
    } else {
      LED_PORT_BSRR = (0x10000uL << LED1_BIT);      // Switch on LED1
    }
  } else if (Index == 2) {
    if ((LED_PORT_ODR & (1uL << LED2_BIT)) == 0) {  // LED is switched off
      LED_PORT_BSRR = (1uL << LED2_BIT);            // Switch off LED2
    } else {
      LED_PORT_BSRR = (0x10000uL << LED2_BIT);      // Switch on LED2
    }
  } else if (Index == 3) {
    if ((LED_PORT_ODR & (1uL << LED3_BIT)) == 0) {  // LED is switched off
      LED_PORT_BSRR = (1uL << LED3_BIT);            // Switch off LED3
    } else {
      LED_PORT_BSRR = (0x10000uL << LED3_BIT);      // Switch on LED3
    }
  }
}

/****** End Of File *************************************************/
