/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
Purpose : BSP for ST STM32F722ZE-Nucleo
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define NUM_LEDS         (3)

#define RCC_BASE_ADDR    (0x40023800u)
#define RCC_AHB1ENR      (*(volatile unsigned int*)(RCC_BASE_ADDR + 0x30u))    // AHB1 peripheral clock register

#define GPIOB_BASE_ADDR  (0x40020400u)
#define GPIOB_MODER      (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x00u))  // GPIOB port mode
#define GPIOB_ODR        (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x14u))  // GPIOB port output data register
#define GPIOB_BSRR       (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x18u))  // GPIOB port bit set/reset


/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init() {
  RCC_AHB1ENR |= (1u <<  1);  // Enable GPIO Port B clock
  GPIOB_MODER |= (1u <<  0)
              |  (1u << 14)
              |  (1u << 28)
              ;               // Set pins 0, 7, 14 to output
  GPIOB_BSRR  |= (1u << 16)
              |  (1u << 23)
              |  (1u << 30)
              ;               // Clear pin bits 0, 7, 14
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index < NUM_LEDS) {
    GPIOB_BSRR = (1u << (Index * 7));
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index < NUM_LEDS) {
    GPIOB_BSRR = (1u << ((Index * 7) + 16));
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index < NUM_LEDS) {
    if ((GPIOB_ODR & (1u << (Index * 7))) != 0u) {
      GPIOB_BSRR = (1u << ((Index * 7) + 16));
    } else {
      GPIOB_BSRR = (1u << (Index * 7));
    }
  }
}

/*************************** End of file ****************************/
