/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
Purpose : BSP for ST STM32F7308 Discovery kit
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define LED0_BIT         (7)  // Led red, SYS LD USER1, PA7, active high
#define LED1_BIT         (1)  // Led green, SYS LD USER2, PB1, active high

#define RCC_BASE_ADDR    (0x40023800u)
#define RCC_AHB1ENR      (*(volatile unsigned int*)(RCC_BASE_ADDR + 0x30u))    // AHB1 peripheral clock register

#define GPIOA_BASE_ADDR  (0x40020000u)
#define GPIOA_MODER      (*(volatile unsigned int*)(GPIOA_BASE_ADDR + 0x00u))  // GPIOB port mode
#define GPIOA_ODR        (*(volatile unsigned int*)(GPIOA_BASE_ADDR + 0x14u))  // GPIOB port output data register
#define GPIOA_BSRR       (*(volatile unsigned int*)(GPIOA_BASE_ADDR + 0x18u))  // GPIOB port bit set/reset

#define GPIOB_BASE_ADDR  (0x40020400u)
#define GPIOB_MODER      (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x00u))  // GPIOB port mode
#define GPIOB_ODR        (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x14u))  // GPIOB port output data register
#define GPIOB_BSRR       (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x18u))  // GPIOB port bit set/reset

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init() {
  RCC_AHB1ENR |=  (1u << 0);               // Enable GPIO Port A clock
  RCC_AHB1ENR |=  (1u << 1);               // Enable GPIO Port B clock

  GPIOA_MODER &= ~(3u << (LED0_BIT * 2));  // Reset mode; sets port to input
  GPIOA_MODER |=  (1u << (LED0_BIT * 2));  // Set to output mode
  GPIOA_ODR   &= ~(1u << LED0_BIT);        // Initially clear LEDs, high active

  GPIOB_MODER &= ~(3u << (LED1_BIT * 2));  // Reset mode; sets port to input
  GPIOB_MODER |=  (1u << (LED1_BIT * 2));  // Set to output mode
  GPIOB_ODR   &= ~(1u << LED1_BIT);        // Initially clear LEDs, high active
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    GPIOA_ODR |= (1u << LED0_BIT);
  } else if (Index == 1) {
    GPIOB_ODR |= (1u << LED1_BIT);
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    GPIOA_ODR &= ~(1u << LED0_BIT);
  } else if (Index == 1) {
    GPIOB_ODR &= ~(1u << LED1_BIT);
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    GPIOA_ODR ^= (1u << LED0_BIT);
  } else if (Index == 1) {
    GPIOB_ODR ^= (1u << LED1_BIT);
  }
}

/*************************** End of file ****************************/
