/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for STM32746G Discovery eval board
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"
#include "stm32f7xx.h"  // Device specific header file, contains CMSIS

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  RCC->AHB1ENR   |= (RCC_AHB1ENR_GPIOIEN);  // GPIOIEN: IO port I clock enable
  GPIOI->MODER    = (GPIOI->MODER & ~(3u << 2)) | (1u << 2);
  GPIOI->OTYPER  &= ~(1u << 1);
  GPIOI->OSPEEDR |=  (3u << 2);
  GPIOI->PUPDR    = (GPIOI->PUPDR & ~(3u << 2)) | (1u << 2);
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    GPIOI->BSRR = (0x00001u << 1);    // Switch on LED
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    GPIOI->BSRR = (0x10000u << 1);    // Switch off LED
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    if (GPIOI->ODR & (1u << 1)) {     // LED is switched off
      GPIOI->BSRR = (0x10000u << 1);  // Switch off LED
    } else {
      GPIOI->BSRR = (0x00001u << 1);  // Switch on LED
    }
  }
}

/****** End Of File *************************************************/
