/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
Purpose : Initialization for external memories.
*/

#include "BSP.h"
#include "stm32746g_discovery_sdram.h"

/*********************************************************************
*
*       Local functions
*
**********************************************************************
*/

/*********************************************************************
*
*       _MPU_Config
*
*  Function description:
*    Re-configure device memory type in MPU in order to avoid
*    Hardfaults caused by unaligned accesses to SDRAM.
*/
static void _MPU_Config(void) {
  MPU_Region_InitTypeDef MPU_InitStruct;

  //
  // Disable the MPU
  //
  HAL_MPU_Disable();
  //
  // Configure the MPU attributes for SDRAM
  //
  MPU_InitStruct.Enable           = MPU_REGION_ENABLE;
  MPU_InitStruct.BaseAddress      = 0xC0000000;
  MPU_InitStruct.Size             = MPU_REGION_SIZE_8MB;
  MPU_InitStruct.AccessPermission = MPU_REGION_FULL_ACCESS;
  MPU_InitStruct.IsBufferable     = MPU_ACCESS_NOT_BUFFERABLE;
  MPU_InitStruct.IsCacheable      = MPU_ACCESS_NOT_CACHEABLE;
  MPU_InitStruct.IsShareable      = MPU_ACCESS_NOT_SHAREABLE;
  MPU_InitStruct.Number           = MPU_REGION_NUMBER0;
  MPU_InitStruct.TypeExtField     = MPU_TEX_LEVEL1;
  MPU_InitStruct.SubRegionDisable = 0x00;
  MPU_InitStruct.DisableExec      = MPU_INSTRUCTION_ACCESS_DISABLE;
  //
  // Tell MPU how it should be configured
  //
  HAL_MPU_ConfigRegion(&MPU_InitStruct);
  //
  // Enable the MPU
  //
  HAL_MPU_Enable(MPU_PRIVILEGED_DEFAULT);
}

/*********************************************************************
*
*       _Init_SDRAM()
*/
static void _Init_SDRAM(void) {
  //
  // calling STs SDRAM init
  //
  BSP_SDRAM_Init();
}

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       HAL_Delay()
*
*  Function description
*    Overwrite HAL_Delay from stm32f7xx_hal.c
*    This function is required by the BSP_SDRAM_Init().
*/
void HAL_Delay(__IO uint32_t Delay) {
  uint32_t Cnt;
  if (Delay < 40000) {
    Cnt = 1000 * 100 * Delay;
  } else {
    Cnt = UINT32_MAX;
  }
  volatile uint32_t i = 0;
  for (;i < Cnt; i++) {
  }
}

/*********************************************************************
*
*       MemoryInit()
*
*  Function description
*    Initializes memories.
*
*  Notes
*    This routine is called before the segment initialization.
*
*    MemoryInit() is called from the Embedded Studio startup code
*    when the define MEMORY_INIT is set.
*    __low_level_init() is called from the IAR startup code.
*/
#if (defined(__ICCARM__))
INTERWORK int __low_level_init(void) {
#else
void MemoryInit(void) {
#endif
  //
  // Set up MPU
  //
  _MPU_Config();
  //
  // Init SDRAM
  //
  _Init_SDRAM();

#if (defined(__ICCARM__))
  return 1;       // Always return 1 to enable segment initilization!
#endif
}

/*************************** End of file ****************************/
