/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for STM32L152C discovery evalboard
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define GPIOB_BASE_ADDR           (0x40020400u)
#define GPIOB_MODER               (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x00u))
#define GPIOB_ODR                 (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x14u))
#define GPIOB_BSRR                (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x18u))

#define RCC_BASE_ADDR             (0x40023800u)
#define RCC_AHBENR                (*(volatile unsigned int*)(RCC_BASE_ADDR + 0x1Cu))
#define RCC_LEDPORT_ENR           RCC_AHBENR
#define RCC_LEDPORT_BIT           (1)

#define LED0_BIT                  (6)  // LD4, blue LED
#define LED1_BIT                  (7)  // LD3, green LED

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  //
  // Initialize port for LEDs (sample application)
  //
  RCC_LEDPORT_ENR &= ~(1u << RCC_LEDPORT_BIT);
  RCC_LEDPORT_ENR |=  (1u << RCC_LEDPORT_BIT);

  GPIOB_MODER &= (3u << (LED0_BIT * 2)) | (3u << (LED1_BIT * 2));  // Reset mode, set to input
  GPIOB_MODER |= (1u << (LED0_BIT * 2)) | (1u << (LED1_BIT * 2));  // Set to output mode
  GPIOB_BSRR   = (0x10000u << LED0_BIT) | (0x10000u << LED1_BIT);  // Initially clear LEDs
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    GPIOB_BSRR = (1u << LED0_BIT);                // Switch on LED0
  } else if (Index == 1) {
    GPIOB_BSRR = (1u << LED1_BIT);                // Switch on LED1
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    GPIOB_BSRR = (0x10000u << LED0_BIT);        // Switch off LED0
  } else if (Index == 1) {
    GPIOB_BSRR = (0x10000u << LED1_BIT);        // Switch off LED1
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    if ((GPIOB_ODR & (1u << LED0_BIT)) == 0) {  // LED is switched off
      GPIOB_BSRR = (1u << LED0_BIT);            // Switch on LED0
    } else {
      GPIOB_BSRR = (0x10000u << LED0_BIT);      // Switch off LED0
    }
  } else if (Index == 1) {
    if ((GPIOB_ODR & (1u << LED1_BIT)) == 0) {  // LED is switched off
      GPIOB_BSRR = (1u << LED1_BIT);            // Switch on LED1
    } else {
      GPIOB_BSRR = (0x10000u << LED1_BIT);      // Switch off LED1
    }
  }
}

/****** End Of File *************************************************/
