/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for the ST STM32L475 Discovery Kit Iot node
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define GPIOA_BASE_ADDR           (0x48000000u)
#define GPIOA_MODER               (*(volatile unsigned int*)(GPIOA_BASE_ADDR + 0x00u))
#define GPIOA_ODR                 (*(volatile unsigned int*)(GPIOA_BASE_ADDR + 0x14u))
#define GPIOA_BSRR                (*(volatile unsigned int*)(GPIOA_BASE_ADDR + 0x18u))

#define GPIOB_BASE_ADDR           (0x48000400u)
#define GPIOB_MODER               (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x00u))
#define GPIOB_ODR                 (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x14u))
#define GPIOB_BSRR                (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x18u))

#define RCC_BASE_ADDR             ((0x40021000u))
#define RCC_AHB2RSTR              (*(volatile unsigned int*)(RCC_BASE_ADDR + 0x2Cu))
#define RCC_AHB2ENR               (*(volatile unsigned int*)(RCC_BASE_ADDR + 0x4Cu))
#define RCC_LEDPORT_BITMASK       ((1u << 1) | (1u << 0))

#define LED0_BIT                  ( 5)  // LED1 green: The LED is a user LED connected to the I/O PA5 of the STM32L475VG.
#define LED1_BIT                  (14)  // LED2 green: The LED is a user LED connected to the I/O PB14 of the STM32L475VG.

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  //
  // Enable clocks and initialize LEDs
  //
  RCC_AHB2ENR |= RCC_LEDPORT_BITMASK;

  GPIOA_MODER &= ~(3u << (LED0_BIT * 2));  // Reset mode; sets port to input
  GPIOA_MODER |=  (1u << (LED0_BIT * 2));  // Set to output mode
  GPIOA_BSRR   =  (16u << LED0_BIT);       // Initially clear LED

  GPIOB_MODER &= ~(3u << (LED1_BIT * 2));  // Reset mode; sets port to input
  GPIOB_MODER |=  (1u << (LED1_BIT * 2));  // Set to output mode
  GPIOB_BSRR   =  (16u << LED1_BIT);       // Initially clear LED
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    GPIOA_BSRR = (1u << LED0_BIT);              // Switch on LED0
  } else if (Index == 1) {
    GPIOB_BSRR = (1u << LED1_BIT);              // Switch on LED1
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    GPIOA_BSRR = (1u << (LED0_BIT + 16));       // Switch off LED0
  } else if (Index == 1) {
    GPIOB_BSRR = (1u << (LED1_BIT + 16));       // Switch off LED1
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    if ((GPIOA_ODR & (1u << LED0_BIT)) == 0) {  // LED is switched on
      GPIOA_BSRR = (1u << LED0_BIT);            // Switch on LED0
    } else {
      GPIOA_BSRR = (1u << (LED0_BIT + 16));     // Switch off LED0
    }
  } else if (Index == 1) {
    if ((GPIOB_ODR & (1u << LED1_BIT)) == 0) {  // LED is switched on
      GPIOB_BSRR = (1u << LED1_BIT);            // Switch on LED1
    } else {
      GPIOB_BSRR = (1u << (LED1_BIT + 16));     // Switch off LED1
    }
  }
}

/****** End Of File *************************************************/
