/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for ST STM32L4R9I-Discovery
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/

// LD1: PB0 (MFX_GPIO0 from MFX) Orange
// LD2: PH4 (from main MCU)      Green

#define LED0_BIT                  (4)

#define GPIOH_BASE_ADDR           (0x48001C00u)
#define GPIOH_MODER               (*(volatile unsigned int*)(GPIOH_BASE_ADDR + 0x00u))
#define GPIOH_IDR                 (*(volatile unsigned int*)(GPIOH_BASE_ADDR + 0x10u))
#define GPIOH_BSRR                (*(volatile unsigned int*)(GPIOH_BASE_ADDR + 0x18u))

#define RCC_BASE_ADDR             (0x40021000u)
#define RCC_AHB2ENR               (*(volatile unsigned int*)(RCC_BASE_ADDR + 0x4Cu))
#define RCC_GPIOHEN_BIT           (7)

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  RCC_AHB2ENR |=  (1u << RCC_GPIOHEN_BIT);    // Enable Clock for port H
  GPIOH_MODER &= ~(3u << (LED0_BIT << 1));    // Reset mode; sets port to input
  GPIOH_MODER |=  (1u << (LED0_BIT << 1));    // Set to output mode
  GPIOH_BSRR   =  (1u << LED0_BIT);           // Switch LED off
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    GPIOH_BSRR |= (1u << (LED0_BIT + 16));    // Switch LED on
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    GPIOH_BSRR |= (1u << LED0_BIT);            // Switch LED off
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    if (GPIOH_IDR & (1u << LED0_BIT)) {
      GPIOH_BSRR |= (1u << (LED0_BIT + 16));  // Switch LED on
    } else {
      GPIOH_BSRR |= (1u << LED0_BIT);         // Switch LED off
    }
  }
}

/****** End Of File *************************************************/
