/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
Purpose : BSP for ST STM32L552ZE Eval
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/

#define LED_BIT                   (3)  // PA5 Green


#define RCC_BASE_ADDR             (0x40021000u)
#define RCC_AHB2ENR               (*(volatile unsigned int*)(RCC_BASE_ADDR + 0x4Cu))

#define GPIOD_BASE_ADDR           (0x42020C00u)
#define GPIOD_MODER               (*(volatile unsigned int*)(GPIOD_BASE_ADDR + 0x00u))
#define GPIOD_PUPDR               (*(volatile unsigned int*)(GPIOD_BASE_ADDR + 0x0Cu))
#define GPIOD_ODR                 (*(volatile unsigned int*)(GPIOD_BASE_ADDR + 0x14u))
#define GPIOD_BSRR                (*(volatile unsigned int*)(GPIOD_BASE_ADDR + 0x18u))


/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  RCC_AHB2ENR |=  (1u << 3);               // Enable GPIOD clock
  GPIOD_MODER &= ~(3u << (LED_BIT * 2));   // Clear GPIOD pin 3 direction
  GPIOD_BSRR  |=  (1u << LED_BIT);         // Switch LED off
  GPIOD_MODER |=  (1u << (LED_BIT * 2));   // Set GPIOD pin 3 to output
  GPIOD_PUPDR |=  (1u << (LED_BIT * 2));   // Set GPIOD pin 3 to pull-up
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    GPIOD_BSRR |= (1u << (LED_BIT + 16));    // Switch LED on
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    GPIOD_BSRR |= (1u << (LED_BIT));         // Switch LED off
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    if (GPIOD_ODR & (1u << LED_BIT)) {
      GPIOD_BSRR |= (1u << (LED_BIT + 16));  // Switch LED on
    } else {
      GPIOD_BSRR |= (1u << LED_BIT);         // Switch LED off
    }
  }
}

/*************************** End of file ****************************/
