/*****************************************************************************
 *                   SEGGER Microcontroller GmbH & Co. KG                    *
 *            Solutions for real time microcontroller applications           *
 *****************************************************************************
 *                                                                           *
 *               (c) 2015 SEGGER Microcontroller GmbH & Co. KG               *
 *                                                                           *
 *           Internet: www.segger.com   Support: support@segger.com          *
 *                                                                           *
 *****************************************************************************/

/*****************************************************************************
 *                         Preprocessor Definitions                          *
 *                         ------------------------                          *
 * VECTORS_IN_RAM                                                            *
 *                                                                           *
 *   If defined, an area of RAM will large enough to store the vector table  *
 *   will be reserved.                                                       *
 *                                                                           *
 *****************************************************************************/

  .syntax unified
  .code 16

  .section .init, "ax"
  .align 0

/*****************************************************************************
 * Default Exception Handlers                                                *
 *****************************************************************************/

  .thumb_func
  .weak NMI_Handler
NMI_Handler:
  b .

  .thumb_func
  .weak HardFault_Handler
HardFault_Handler:
  b .

  .thumb_func
  .weak SVC_Handler
SVC_Handler:
  b .

  .thumb_func
  .weak PendSV_Handler
PendSV_Handler:
  b .

  .thumb_func
  .weak SysTick_Handler
SysTick_Handler:
  b .

  .thumb_func
Dummy_Handler:
  b .

#if defined(__OPTIMIZATION_SMALL)

  .weak TIM1_IRQHandler
  .thumb_set TIM1_IRQHandler,Dummy_Handler

  .weak TIM2_IRQHandler
  .thumb_set TIM2_IRQHandler,Dummy_Handler

  .weak SLPTIM_IRQHandler
  .thumb_set SLPTIM_IRQHandler,Dummy_Handler

  .weak SC1_IRQHandler
  .thumb_set SC1_IRQHandler,Dummy_Handler

  .weak SC2_IRQHandler
  .thumb_set SC2_IRQHandler,Dummy_Handler

  .weak MAC_TIM_IRQHandler
  .thumb_set MAC_TIM_IRQHandler,Dummy_Handler

  .weak ADC_IRQHandler
  .thumb_set ADC_IRQHandler,Dummy_Handler

  .weak EXTIA_IRQHandler
  .thumb_set EXTIA_IRQHandler,Dummy_Handler

  .weak EXTIB_IRQHandler
  .thumb_set EXTIB_IRQHandler,Dummy_Handler

  .weak EXTIC_IRQHandler
  .thumb_set EXTIC_IRQHandler,Dummy_Handler

  .weak EXTID_IRQHandler
  .thumb_set EXTID_IRQHandler,Dummy_Handler

#else

  .thumb_func
  .weak TIM1_IRQHandler
TIM1_IRQHandler:
  b .

  .thumb_func
  .weak TIM2_IRQHandler
TIM2_IRQHandler:
  b .

  .thumb_func
  .weak SLPTIM_IRQHandler
SLPTIM_IRQHandler:
  b .

  .thumb_func
  .weak SC1_IRQHandler
SC1_IRQHandler:
  b .

  .thumb_func
  .weak SC2_IRQHandler
SC2_IRQHandler:
  b .

  .thumb_func
  .weak MAC_TIM_IRQHandler
MAC_TIM_IRQHandler:
  b .

  .thumb_func
  .weak ADC_IRQHandler
ADC_IRQHandler:
  b .

  .thumb_func
  .weak EXTIA_IRQHandler
EXTIA_IRQHandler:
  b .

  .thumb_func
  .weak EXTIB_IRQHandler
EXTIB_IRQHandler:
  b .

  .thumb_func
  .weak EXTIC_IRQHandler
EXTIC_IRQHandler:
  b .

  .thumb_func
  .weak EXTID_IRQHandler
EXTID_IRQHandler:
  b .

#endif

/*****************************************************************************
 * Vector Table                                                              *
 *****************************************************************************/

  .section .vectors, "ax"
  .align 0
  .global _vectors
  .extern __stack_end__
  .extern Reset_Handler

_vectors:
  .word __stack_end__
  .word Reset_Handler
  .word NMI_Handler
  .word HardFault_Handler
  .word 0 /* Reserved */
  .word 0 /* Reserved */
  .word 0 /* Reserved */
  .word 0 /* Reserved */
  .word 0 /* Reserved */
  .word 0 /* Reserved */
  .word 0 /* Reserved */
  .word SVC_Handler
  .word 0 /* Reserved */
  .word 0 /* Reserved */
  .word PendSV_Handler
  .word SysTick_Handler
  .word TIM1_IRQHandler
  .word TIM2_IRQHandler
  .word Dummy_Handler /* Reserved */
  .word Dummy_Handler /* Reserved */
  .word SLPTIM_IRQHandler
  .word SC1_IRQHandler
  .word SC2_IRQHandler
  .word Dummy_Handler /* Reserved */
  .word MAC_TIM_IRQHandler
  .word Dummy_Handler /* Reserved */
  .word Dummy_Handler /* Reserved */
  .word ADC_IRQHandler
  .word EXTIA_IRQHandler
  .word EXTIB_IRQHandler
  .word EXTIC_IRQHandler
  .word EXTID_IRQHandler
_vectors_end:

#ifdef VECTORS_IN_RAM
  .section .vectors_ram, "ax"
  .align 0
  .global _vectors_ram

_vectors_ram:
  .space _vectors_end - _vectors, 0
#endif
