/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for STM32W103 (MB851)
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/

/****** LED port assignement ****************************************/
#define GPIOB_BASE_ADDR (0x4000B400u)
#define GPIOB_CFGL      (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x00u))
#define GPIOB_CFGH      (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x04u))
#define GPIOB_IN        (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x08u))
#define GPIOB_OUT       (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x0cu))
#define GPIOB_SET       (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x10u))
#define GPIOB_CLR       (*(volatile unsigned int*)(GPIOB_BASE_ADDR + 0x14u))

/****** Assign LEDs to Ports ****************************************/
#define LED0_BIT        (6)  // D1
#define LED1_BIT        (5)  // D2
#define LED_MASK_ALL    ((1u << LED0_BIT) | (1u << LED1_BIT))
#define NUM_LEDS        (2)

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  GPIOB_CFGH = (0x5u << 8) | (0x5u << 4);
  GPIOB_CLR  = LED_MASK_ALL;
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index < NUM_LEDS) {
    GPIOB_SET |= (1u << (5 + Index));
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index < NUM_LEDS) {
    GPIOB_CLR |= (1u << (5 + Index));
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index < NUM_LEDS) {
    GPIOB_OUT ^= (1u << (5 + Index));
  }
}

/****** End Of File *************************************************/
