/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for SEGGER Dongle
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define LED0_MASK     (1uL << 4)
#define LED1_MASK     (1uL << 8)
#define LED_MASK_ALL  (LED0_MASK | LED1_MASK)

#define SCU_BASE_ADDR  (0x40086000u)
#define SCU_SFSP1_0    (*(volatile unsigned int *)(SCU_BASE_ADDR + 0x0080))  //  Pin configuration register for pin P1_0
#define SCU_SFSP1_1    (*(volatile unsigned int *)(SCU_BASE_ADDR + 0x0084))  //  Pin configuration register for pin P1_1

#define GPIO_BASE_ADDR (0x400F4000u)
#define GPIO_DIR0      (*(volatile unsigned int *)(GPIO_BASE_ADDR + 0x2000))  //  Pin output register
#define GPIO_SET0      (*(volatile unsigned int *)(GPIO_BASE_ADDR + 0x2200))  //  Pin set register
#define GPIO_CLR0      (*(volatile unsigned int *)(GPIO_BASE_ADDR + 0x2280))  //  Pin clear register
#define GPIO_NOT0      (*(volatile unsigned int *)(GPIO_BASE_ADDR + 0x2300))  //  Pin toggle register

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  SCU_SFSP1_0 = 0x00;
  SCU_SFSP1_1 = 0x00;
  GPIO_DIR0 |= LED_MASK_ALL;
  GPIO_CLR0 |= LED_MASK_ALL;
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    GPIO_SET0 |= LED0_MASK;
  } else if (Index == 1) {
    GPIO_SET0 |= LED1_MASK;
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    GPIO_CLR0 |= LED0_MASK;
  } else if (Index == 1) {
    GPIO_CLR0 |= LED1_MASK;
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    GPIO_NOT0 |= LED0_MASK;
  } else if (Index == 1) {
    GPIO_NOT0 |= LED1_MASK;
  }
}

/****** End Of File *************************************************/
