/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for Segger emControl I/O
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define LED0_MASK     (1uL << 3)
#define LED1_MASK     (1uL << 4)
#define LED_MASK_ALL  (LED0_MASK | LED1_MASK)

#define LPC_SCU_BASE  0x40086000
#define SCU_SFSP2_3   (*(volatile unsigned int *)(LPC_SCU_BASE + 0x010C))  //  Pin configuration register for pin P2_3
#define SCU_SFSP2_4   (*(volatile unsigned int *)(LPC_SCU_BASE + 0x0110))  //  Pin configuration register for pin P2_4

#define LPC_GPIO_BASE 0x400F4000
#define GPIO_DIR5     (*(volatile unsigned int *)(LPC_GPIO_BASE + 0x2014))  //  Pin output register
#define GPIO_SET5     (*(volatile unsigned int *)(LPC_GPIO_BASE + 0x2214))  //  Pin set register
#define GPIO_CLR5     (*(volatile unsigned int *)(LPC_GPIO_BASE + 0x2294))  //  Pin clear register
#define GPIO_NOT5     (*(volatile unsigned int *)(LPC_GPIO_BASE + 0x2314))  //  Pin toggle register

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  SCU_SFSP2_3 = 0x0C;
  SCU_SFSP2_4 = 0x0C;
  GPIO_DIR5 |= LED_MASK_ALL;
  GPIO_CLR5 |= LED_MASK_ALL;
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    GPIO_SET5 |= LED0_MASK;
  } else if (Index == 1) {
    GPIO_SET5 |= LED1_MASK;
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    GPIO_CLR5 |= LED0_MASK;
  } else if (Index == 1) {
    GPIO_CLR5 |= LED1_MASK;
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    GPIO_NOT5 |= LED0_MASK;
  } else if (Index == 1) {
    GPIO_NOT5 |= LED1_MASK;
  }
}

/****** End Of File *************************************************/
