/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
File    : BSP.c
Purpose : BSP for Segger NAND-Flash Eval
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define LED0_BIT            0     // Red LED
#define LED1_BIT            1     // Green LED
//
// PIOA
//
#define PIOA_BASE_ADDR  (0x400E0C00)
#define PIOA_PER        (*(volatile unsigned int*)(PIOA_BASE_ADDR + 0x00u))
#define PIOA_OER        (*(volatile unsigned int*)(PIOA_BASE_ADDR + 0x10u))
#define PIOA_SODR       (*(volatile unsigned int*)(PIOA_BASE_ADDR + 0x30u))  // Set output data
#define PIOA_CODR       (*(volatile unsigned int*)(PIOA_BASE_ADDR + 0x34u))  // Clear output data register
#define PIOA_ODSR       (*(volatile unsigned int*)(PIOA_BASE_ADDR + 0x38u))  // Output data status register

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  PIOA_PER  = ((1 << LED0_BIT) | (1 << LED1_BIT));  // Enable Port
  PIOA_OER  = ((1 << LED0_BIT) | (1 << LED1_BIT));  // Switch to output mode
  PIOA_SODR = ((1 << LED0_BIT) | (1 << LED1_BIT));  // Initially clear LEDs
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0 || Index == 1) {
    PIOA_CODR = (1 << Index);    // Switch on LED
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0 || Index == 1) {
    PIOA_SODR = (1 << Index);    // Switch off LED
  }
}
/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0 || Index == 1) {
    if (PIOA_ODSR & (1 << Index)) {  // LED is switched off
      PIOA_CODR = (1 << Index);      // Switch on LED
    } else {
      PIOA_SODR = (1 << Index);      // Switch off LED
    }
  }
}

/*************************** End of file ****************************/
