/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for SEGGER MIMXRT1050 Trace Reference Board
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/

#define LED0                              (0)
#define LED1                              (1)
#define LED2                              (2)

#define CCM_BASE_ADDR                     (0x400FC000u)
#define CCM_CCGR0                         (*(volatile unsigned int*)(CCM_BASE_ADDR + 0x68u))
#define CCM_CCGR4                         (*(volatile unsigned int*)(CCM_BASE_ADDR + 0x78u))

#define IOMUXC_BASE_ADDR                  (0x401F8000u)
#define IOMUXC_SW_MUX_CTL_PAD_GPIO_B0_00  (*(volatile unsigned int*)(IOMUXC_BASE_ADDR + 0x13Cu))
#define IOMUXC_SW_PAD_CTL_PAD_GPIO_B0_00  (*(volatile unsigned int*)(IOMUXC_BASE_ADDR + 0x32Cu))
#define IOMUXC_SW_MUX_CTL_PAD_GPIO_B0_01  (*(volatile unsigned int*)(IOMUXC_BASE_ADDR + 0x140u))
#define IOMUXC_SW_PAD_CTL_PAD_GPIO_B0_01  (*(volatile unsigned int*)(IOMUXC_BASE_ADDR + 0x330u))
#define IOMUXC_SW_MUX_CTL_PAD_GPIO_B0_02  (*(volatile unsigned int*)(IOMUXC_BASE_ADDR + 0x144u))
#define IOMUXC_SW_PAD_CTL_PAD_GPIO_B0_02  (*(volatile unsigned int*)(IOMUXC_BASE_ADDR + 0x334u))

#define GPIO_BASE_ADDR                    (0x401BC000u)
#define GPIO_DR                           (*(volatile unsigned int*)(GPIO_BASE_ADDR + 0x0u))
#define GPIO_DIR                          (*(volatile unsigned int*)(GPIO_BASE_ADDR + 0x4u))

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  CCM_CCGR4                        |=  (0x3u << 2);     // Enable IOMUX clock
  CCM_CCGR0                        &= ~(0x3u << 30);    // Disable GPIO2 clock
  IOMUXC_SW_MUX_CTL_PAD_GPIO_B0_00  =   0x5;            // Set mux to ALT5 GPIO2_IO00
  IOMUXC_SW_PAD_CTL_PAD_GPIO_B0_00  =   0x10B0;         // Functional properties
  IOMUXC_SW_MUX_CTL_PAD_GPIO_B0_01  =   0x5;            // Set mux to ALT5 GPIO2_IO01
  IOMUXC_SW_PAD_CTL_PAD_GPIO_B0_01  =   0x10B0;         // Functional properties
  IOMUXC_SW_MUX_CTL_PAD_GPIO_B0_02  =   0x5;            // Set mux to ALT5 GPIO2_IO02
  IOMUXC_SW_PAD_CTL_PAD_GPIO_B0_02  =   0x10B0;         // Functional properties
  CCM_CCGR0                        |=  (0x3u << 30);    // Enable GPIO2 clock
  GPIO_DR                          |=  (0x1u << LED0);  // Disable LED0
  GPIO_DIR                         |=  (0x1u << LED0);  // Set GPIO pin 0 to output
  GPIO_DR                          |=  (0x1u << LED1);  // Disable LED1
  GPIO_DIR                         |=  (0x1u << LED1);  // Set GPIO pin 1 to output
  GPIO_DR                          |=  (0x1u << LED2);  // Disable LED2
  GPIO_DIR                         |=  (0x1u << LED2);  // Set GPIO pin 2 to output
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index >= 0 && Index < 3) {
    GPIO_DR &= ~(0x1u << Index);
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index >= 0 && Index < 3) {
    GPIO_DR |= (0x1u << Index);
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index >= 0 && Index < 3) {
    GPIO_DR ^= (0x1u << Index);
  }
}

/****** End Of File *************************************************/
