/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for Bosch XDK110
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define CMU_BASE_ADDR      (0x400C8000u)
#define CMU_HFPERCLKEN0    (*(volatile unsigned int*)(CMU_BASE_ADDR + 0x044u))   // High Frequency Peripheral Clock Enable Register 0

#define GPIO_BASE_ADDR     (0x40006000u)
#define GPIO_PA_MODEL      (*(volatile unsigned int*)(GPIO_BASE_ADDR + 0x004u))  // Port Pin Mode Low Register
#define GPIO_PA_MODEH      (*(volatile unsigned int*)(GPIO_BASE_ADDR + 0x008u))  // Port Pin Mode High Register
#define GPIO_PB_MODEL      (*(volatile unsigned int*)(GPIO_BASE_ADDR + 0x028u))  // Port Pin Mode Low Register
#define GPIO_PB_MODEH      (*(volatile unsigned int*)(GPIO_BASE_ADDR + 0x02Cu))  // Port Pin Mode High Register


#define GPIO_PA_DOUT       (*(volatile unsigned int*)(GPIO_BASE_ADDR + 0x00C))   // Port Data Out Register
#define GPIO_PA_DOUTSET    (*(volatile unsigned int*)(GPIO_BASE_ADDR + 0x010))   // Port Data Out Set Register
#define GPIO_PA_DOUTCLR    (*(volatile unsigned int*)(GPIO_BASE_ADDR + 0x014))   // Port Data Out Clear Register
#define GPIO_PA_DOUTTGL    (*(volatile unsigned int*)(GPIO_BASE_ADDR + 0x018))   // Port Data Out Toggle Register

#define GPIO_PB_DOUT       (*(volatile unsigned int*)(GPIO_BASE_ADDR + 0x030))   // Port Data Out Register
#define GPIO_PB_DOUTSET    (*(volatile unsigned int*)(GPIO_BASE_ADDR + 0x034))   // Port Data Out Set Register
#define GPIO_PB_DOUTCLR    (*(volatile unsigned int*)(GPIO_BASE_ADDR + 0x038))   // Port Data Out Clear Register
#define GPIO_PB_DOUTTGL    (*(volatile unsigned int*)(GPIO_BASE_ADDR + 0x03C))   // Port Data Out Toggle Register

#define GPIO_CLOCK_ENABLE  (1u << 13)                                            // General purpose Input/Output Clock Enable
#define GPIO_MODE_PUSHPULL (5u)

#define LED0_BIT           (12u)                                                 // User LED GPIO A.12, red
#define LED1_BIT           (1u)                                                  // User LED GPIO B.1, orange
#define LED2_BIT           (0u)                                                  // User LED GPIO B.0, yellow

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  //
  // Enable GPIO
  //
  CMU_HFPERCLKEN0 |= GPIO_CLOCK_ENABLE;
  //
  // Configure GPIO port as LED control outputs
  //
  GPIO_PA_MODEH &= ~(0xF << 16);
  GPIO_PA_MODEH |= (GPIO_MODE_PUSHPULL << 16);
  GPIO_PB_MODEL &= ~(0xF << 0);
  GPIO_PB_MODEL |= (GPIO_MODE_PUSHPULL << 0);
  GPIO_PB_MODEL &= ~(0xF << 4);
  GPIO_PB_MODEL |= (GPIO_MODE_PUSHPULL << 4);
  //
  // Initially all LEDS off
  //
  GPIO_PA_DOUTCLR = (1u << LED0_BIT);
  GPIO_PB_DOUTCLR = (1u << LED1_BIT);
  GPIO_PB_DOUTCLR = (1u << LED2_BIT);
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    GPIO_PA_DOUTSET = (1u << LED0_BIT);
  } else if (Index == 1) {
    GPIO_PB_DOUTSET = (1u << LED1_BIT);
  } else if (Index == 2) {
    GPIO_PB_DOUTSET = (1u << LED2_BIT);
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    GPIO_PA_DOUTCLR = (1u << LED0_BIT);
  } else if (Index == 1) {
    GPIO_PB_DOUTCLR = (1u << LED1_BIT);
  } else if (Index == 2) {
    GPIO_PB_DOUTCLR = (1u << LED2_BIT);
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    GPIO_PA_DOUTTGL = (1u << LED0_BIT);
  } else  if (Index == 1) {
    GPIO_PB_DOUTTGL = (1u << LED1_BIT);
  } else if (Index == 2) {
    GPIO_PB_DOUTTGL = (1u << LED2_BIT);
  }
}

/****** End Of File *************************************************/
