/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for EFM32 Happy Gecko eval board
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"
#include "em_device.h"  // Device specific header file, contains CMSIS

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define LED0_BIT      (4)
#define LED1_BIT      (5)
#define LEDMASK_ALL   ((1uL << LED0_BIT) | (1uL << LED1_BIT))

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  GPIO_TypeDef *gpio = GPIO;
  uint32_t     gpiomode;
  unsigned int Data;

  /* Enable GPIO */
  CMU->HFPERCLKEN0 |= CMU_HFPERCLKEN0_GPIO;

  /* Configure GPIO port C 4-5 as LED control outputs */
  gpiomode  = GPIO->P[5].MODEL;
  gpiomode &= ~(_GPIO_P_MODEL_MODE4_MASK |
                _GPIO_P_MODEL_MODE5_MASK
               );
  gpiomode |= GPIO_P_MODEL_MODE4_PUSHPULL;
  gpiomode |= GPIO_P_MODEL_MODE5_PUSHPULL;
  gpio->P[5].MODEL = gpiomode;

  /* All LEDS off */
  Data  = GPIO->P[5].DOUT;
  Data &= ~(LEDMASK_ALL);
  GPIO->P[5].DOUT = Data;
}


/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  GPIO->P[5].DOUT |= (1uL << Index);
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  GPIO->P[5].DOUT &= ~(1uL << Index);
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (GPIO->P[5].DOUT & (1uL << (Index + 4))) {
    GPIO->P[5].DOUT &= ~(1uL << (Index + 4));
  } else {
    GPIO->P[5].DOUT |=  (1uL << (Index + 4));
  }
}

/****** End Of File *************************************************/
