/*****************************************************************************
 *                   SEGGER Microcontroller GmbH & Co. KG                    *
 *            Solutions for real time microcontroller applications           *
 *****************************************************************************
 *                                                                           *
 *               (c) 2018 SEGGER Microcontroller GmbH & Co. KG               *
 *                                                                           *
 *           Internet: www.segger.com   Support: support@segger.com          *
 *                                                                           *
 *****************************************************************************/

/*****************************************************************************
 *                         Preprocessor Definitions                          *
 *                         ------------------------                          *
 * VECTORS_IN_RAM                                                            *
 *                                                                           *
 *   If defined, an area of RAM will large enough to store the vector table  *
 *   will be reserved.                                                       *
 *                                                                           *
 *****************************************************************************/

  .syntax unified
  .code 16

  .section .init, "ax"
  .align 0

/*****************************************************************************
 * Default Exception Handlers                                                *
 *****************************************************************************/

  .thumb_func
  .weak NMI_Handler
NMI_Handler:
  b .

  .thumb_func
  .weak HardFault_Handler
HardFault_Handler:
  b .

  .thumb_func
  .weak SVC_Handler
SVC_Handler:
  b .

  .thumb_func
  .weak PendSV_Handler
PendSV_Handler:
  b .

  .thumb_func
  .weak SysTick_Handler
SysTick_Handler:
  b .

  .thumb_func
Dummy_Handler:
  b .

#if defined(__OPTIMIZATION_SMALL)

  .weak EMU_IRQHandler
  .thumb_set EMU_IRQHandler,Dummy_Handler

  .weak WDOG0_IRQHandler
  .thumb_set WDOG0_IRQHandler,Dummy_Handler

  .weak LDMA_IRQHandler
  .thumb_set LDMA_IRQHandler,Dummy_Handler

  .weak GPIO_EVEN_IRQHandler
  .thumb_set GPIO_EVEN_IRQHandler,Dummy_Handler

  .weak TIMER0_IRQHandler
  .thumb_set TIMER0_IRQHandler,Dummy_Handler

  .weak USART0_RX_IRQHandler
  .thumb_set USART0_RX_IRQHandler,Dummy_Handler

  .weak USART0_TX_IRQHandler
  .thumb_set USART0_TX_IRQHandler,Dummy_Handler

  .weak ACMP0_IRQHandler
  .thumb_set ACMP0_IRQHandler,Dummy_Handler

  .weak ADC0_IRQHandler
  .thumb_set ADC0_IRQHandler,Dummy_Handler

  .weak IDAC0_IRQHandler
  .thumb_set IDAC0_IRQHandler,Dummy_Handler

  .weak I2C0_IRQHandler
  .thumb_set I2C0_IRQHandler,Dummy_Handler

  .weak GPIO_ODD_IRQHandler
  .thumb_set GPIO_ODD_IRQHandler,Dummy_Handler

  .weak TIMER1_IRQHandler
  .thumb_set TIMER1_IRQHandler,Dummy_Handler

  .weak USART1_RX_IRQHandler
  .thumb_set USART1_RX_IRQHandler,Dummy_Handler

  .weak USART1_TX_IRQHandler
  .thumb_set USART1_TX_IRQHandler,Dummy_Handler

  .weak LEUART0_IRQHandler
  .thumb_set LEUART0_IRQHandler,Dummy_Handler

  .weak PCNT0_IRQHandler
  .thumb_set PCNT0_IRQHandler,Dummy_Handler

  .weak CMU_IRQHandler
  .thumb_set CMU_IRQHandler,Dummy_Handler

  .weak MSC_IRQHandler
  .thumb_set MSC_IRQHandler,Dummy_Handler

  .weak CRYPTO_IRQHandler
  .thumb_set CRYPTO_IRQHandler,Dummy_Handler

  .weak LETIMER0_IRQHandler
  .thumb_set LETIMER0_IRQHandler,Dummy_Handler

  .weak RTCC_IRQHandler
  .thumb_set RTCC_IRQHandler,Dummy_Handler

  .weak CRYOTIMER_IRQHandler
  .thumb_set CRYOTIMER_IRQHandler,Dummy_Handler

  .weak FPUEH_IRQHandler
  .thumb_set FPUEH_IRQHandler,Dummy_Handler

#else

  .thumb_func
  .weak EMU_IRQHandler
EMU_IRQHandler:
  b .

  .thumb_func
  .weak WDOG0_IRQHandler
WDOG0_IRQHandler:
  b .

  .thumb_func
  .weak LDMA_IRQHandler
LDMA_IRQHandler:
  b .

  .thumb_func
  .weak GPIO_EVEN_IRQHandler
GPIO_EVEN_IRQHandler:
  b .

  .thumb_func
  .weak TIMER0_IRQHandler
TIMER0_IRQHandler:
  b .

  .thumb_func
  .weak USART0_RX_IRQHandler
USART0_RX_IRQHandler:
  b .

  .thumb_func
  .weak USART0_TX_IRQHandler
USART0_TX_IRQHandler:
  b .

  .thumb_func
  .weak ACMP0_IRQHandler
ACMP0_IRQHandler:
  b .

  .thumb_func
  .weak ADC0_IRQHandler
ADC0_IRQHandler:
  b .

  .thumb_func
  .weak IDAC0_IRQHandler
IDAC0_IRQHandler:
  b .

  .thumb_func
  .weak I2C0_IRQHandler
I2C0_IRQHandler:
  b .

  .thumb_func
  .weak GPIO_ODD_IRQHandler
GPIO_ODD_IRQHandler:
  b .

  .thumb_func
  .weak TIMER1_IRQHandler
TIMER1_IRQHandler:
  b .

  .thumb_func
  .weak USART1_RX_IRQHandler
USART1_RX_IRQHandler:
  b .

  .thumb_func
  .weak USART1_TX_IRQHandler
USART1_TX_IRQHandler:
  b .

  .thumb_func
  .weak LEUART0_IRQHandler
LEUART0_IRQHandler:
  b .

  .thumb_func
  .weak PCNT0_IRQHandler
PCNT0_IRQHandler:
  b .

  .thumb_func
  .weak CMU_IRQHandler
CMU_IRQHandler:
  b .

  .thumb_func
  .weak MSC_IRQHandler
MSC_IRQHandler:
  b .

  .thumb_func
  .weak CRYPTO_IRQHandler
CRYPTO_IRQHandler:
  b .

  .thumb_func
  .weak LETIMER0_IRQHandler
LETIMER0_IRQHandler:
  b .

  .thumb_func
  .weak RTCC_IRQHandler
RTCC_IRQHandler:
  b .

  .thumb_func
  .weak CRYOTIMER_IRQHandler
CRYOTIMER_IRQHandler:
  b .

  .thumb_func
  .weak FPUEH_IRQHandler
FPUEH_IRQHandler:
  b .

#endif

/*****************************************************************************
 * Vector Table                                                              *
 *****************************************************************************/

  .section .vectors, "ax"
  .align 0
  .global _vectors
  .extern __stack_end__
  .extern Reset_Handler

_vectors:
  .word __stack_end__
  .word Reset_Handler
  .word NMI_Handler
  .word HardFault_Handler
  .word 0 /* Reserved */
  .word 0 /* Reserved */
  .word 0 /* Reserved */
  .word 0 /* Reserved */
  .word 0 /* Reserved */
  .word 0 /* Reserved */
  .word 0 /* Reserved */
  .word SVC_Handler
  .word 0 /* Reserved */
  .word 0 /* Reserved */
  .word PendSV_Handler
  .word SysTick_Handler
  .word EMU_IRQHandler
  .word Dummy_Handler /* Reserved */
  .word WDOG0_IRQHandler
  .word Dummy_Handler /* Reserved */
  .word Dummy_Handler /* Reserved */
  .word Dummy_Handler /* Reserved */
  .word Dummy_Handler /* Reserved */
  .word Dummy_Handler /* Reserved */
  .word LDMA_IRQHandler
  .word GPIO_EVEN_IRQHandler
  .word TIMER0_IRQHandler
  .word USART0_RX_IRQHandler
  .word USART0_TX_IRQHandler
  .word ACMP0_IRQHandler
  .word ADC0_IRQHandler
  .word IDAC0_IRQHandler
  .word I2C0_IRQHandler
  .word GPIO_ODD_IRQHandler
  .word TIMER1_IRQHandler
  .word USART1_RX_IRQHandler
  .word USART1_TX_IRQHandler
  .word LEUART0_IRQHandler
  .word PCNT0_IRQHandler
  .word CMU_IRQHandler
  .word MSC_IRQHandler
  .word CRYPTO_IRQHandler
  .word LETIMER0_IRQHandler
  .word Dummy_Handler /* Reserved */
  .word Dummy_Handler /* Reserved */
  .word RTCC_IRQHandler
  .word Dummy_Handler /* Reserved */
  .word CRYOTIMER_IRQHandler
  .word Dummy_Handler /* Reserved */
  .word FPUEH_IRQHandler
_vectors_end:

#ifdef VECTORS_IN_RAM
  .section .vectors_ram, "ax"
  .align 0
  .global _vectors_ram

_vectors_ram:
  .space _vectors_end - _vectors, 0
#endif
