/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
Purpose : BSP for TI MSP432E411Y_BGAEVM
*/

#include "BSP.h"
#include "RTOS.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define LED0_BIT          (0)
#define LED1_BIT          (1)

#define LED0_MASK         (1u << LED0_BIT)
#define LED1_MASK         (1u << LED1_BIT)

#define SYSCTL_BASE_ADDR  (0x400FE000u)                                           // System Control Base
#define RCGCGPIO          (*(volatile unsigned int*)(SYSCTL_BASE_ADDR + 0x608u))  // GPIO Clock Gating Module
#define GPIONEN_BIT       (12)

#define GPION_BASE_ADDR   (0x40064000u)                                           // GPIO N Base address
#define GPION_DATA        (*(volatile unsigned int*)(GPION_BASE_ADDR + 0x3FCu))   // GPIO N Data register
#define GPION_DIR         (*(volatile unsigned int*)(GPION_BASE_ADDR + 0x400u))   // GPIO N Direction register
#define GPION_DEN         (*(volatile unsigned int*)(GPION_BASE_ADDR + 0x51Cu))   // GPIO N Digital Enable register

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  RCGCGPIO  |= (1u << GPIONEN_BIT);
  OS_TASK_Delayus(100);           // Wait 100 us for GPION to become clocked
  GPION_DEN |= (1u << LED0_BIT)
            |  (1u << LED1_BIT);  // Enable Digital Mode
  GPION_DIR |= (1u << LED0_BIT)
            |  (1u << LED1_BIT);  // Set Output Direction
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if        (Index == 0) {
    GPION_DATA |= LED0_MASK;
  } else if (Index == 1) {
    GPION_DATA |= LED1_MASK;
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if        (Index == 0) {
    GPION_DATA &= ~LED0_MASK;
  } else if (Index == 1) {
    GPION_DATA &= ~LED1_MASK;
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if        (Index == 0) {
    GPION_DATA ^= LED0_MASK;
  } else if (Index == 1) {
    GPION_DATA ^= LED1_MASK;
  }
}

/*************************** End of file ****************************/
