/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
Purpose: BSP for TI TM4C123 LaunchPad
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define RCGCGPIO            (*(volatile unsigned int*)(0x400FE608u))
#define RCGCGPIO_GPIOF_BIT  (5)

#define GPIOF_BASE_ADDR     (0x40025000u)
#define GPIOF_GPIODEN       (*(volatile unsigned int*)(GPIOF_BASE_ADDR + 0x51Cu))
#define GPIOF_GPIODIR       (*(volatile unsigned int*)(GPIOF_BASE_ADDR + 0x400u))
#define GPIOF2_GPIODATA     (*(volatile unsigned int*)(GPIOF_BASE_ADDR + 0x010u))
#define GPIOF3_GPIODATA     (*(volatile unsigned int*)(GPIOF_BASE_ADDR + 0x020u))

#define LED0_BIT_MASK       (1u << 2)  // PF2, blue
#define LED1_BIT_MASK       (1u << 3)  // PF3, green

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  RCGCGPIO |= (1u << RCGCGPIO_GPIOF_BIT);  // Enable power for port F

  GPIOF_GPIODEN   |=  LED0_BIT_MASK;       // Enable pad
  GPIOF_GPIODIR   |=  LED0_BIT_MASK;       // Set to output
  GPIOF2_GPIODATA &= ~LED0_BIT_MASK;       // Initially clear LED

  GPIOF_GPIODEN   |=  LED1_BIT_MASK;       // Enable pad
  GPIOF_GPIODIR   |=  LED1_BIT_MASK;       // Set to output
  GPIOF3_GPIODATA &= ~LED1_BIT_MASK;       // Initially clear LED
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    GPIOF2_GPIODATA |= LED0_BIT_MASK;
  } else if (Index == 1) {
    GPIOF3_GPIODATA |= LED1_BIT_MASK;
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    GPIOF2_GPIODATA &= ~LED0_BIT_MASK;
  } else if (Index == 1) {
    GPIOF3_GPIODATA &= ~LED1_BIT_MASK;
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    if (GPIOF2_GPIODATA != 0) {
      GPIOF2_GPIODATA &= ~LED0_BIT_MASK;
    } else {
      GPIOF2_GPIODATA |= LED0_BIT_MASK;
    }
  } else if (Index == 1) {
    if (GPIOF3_GPIODATA != 0) {
      GPIOF3_GPIODATA &= ~LED1_BIT_MASK;
    } else {
      GPIOF3_GPIODATA |= LED1_BIT_MASK;
    }
  }
}

/*************************** End of file ****************************/
