/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

----------------------------------------------------------------------
File    : BSP.c
Purpose : BSP for EK-TM4C1294XL eval board
--------  END-OF-HEADER  ---------------------------------------------
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define LED0               (0)
#define LED1               (4)
#define LED2               (0)
#define LED3               (1)

#define SYSCTRL_BASE_ADDR  (0x400FE000u)
#define SYSCTRL_RCGCGPIO   (*(volatile unsigned int*)(SYSCTRL_BASE_ADDR + 0x608u))

#define GPIOF_BASE_ADDR    (0x4005D000u)
#define GPIOF_DATA         (*(volatile unsigned int*)(GPIOF_BASE_ADDR + 0x3FCu))
#define GPIOF_DIR          (*(volatile unsigned int*)(GPIOF_BASE_ADDR + 0x400u))
#define GPIOF_DEN          (*(volatile unsigned int*)(GPIOF_BASE_ADDR + 0x51Cu))

#define GPION_BASE_ADDR    (0x40064000u)
#define GPION_DATA         (*(volatile unsigned int*)(GPION_BASE_ADDR + 0x3FCu))
#define GPION_DIR          (*(volatile unsigned int*)(GPION_BASE_ADDR + 0x400u))
#define GPION_DEN          (*(volatile unsigned int*)(GPION_BASE_ADDR + 0x51Cu))

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  volatile unsigned int delay;

  SYSCTRL_RCGCGPIO |= (1u <<  5) // Enable GPIOF clock
                   |  (1u << 12) // Enable GPION clock
                   ;
  delay = 20u;
  while (--delay);           // Min. 3 system clocks delay
  GPIOF_DIR |= (1u << LED0)  // Set PF4 to output
            |  (1u << LED1)  // Set PF0 to output
            ;
  GPIOF_DEN |= (1u << LED0)  // Enable PF4 digital mode
            |  (1u << LED1)  // Enable PF0 digital mode
            ;
  GPION_DIR |= (1u << LED2)  // Set PN1 to output
            |  (1u << LED3)  // Set PN0 to output
            ;
  GPION_DEN |= (1u << LED2)  // Enable PN1 digital mode
            |  (1u << LED3)  // Enable PN0 digital mode
            ;

}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index == 0) {
    GPIOF_DATA |= (1u << LED0);
  } else if (Index == 1) {
    GPIOF_DATA |= (1u << LED1);
  } else if (Index == 2) {
    GPION_DATA |= (1u << LED2);
  } else if (Index == 3) {
    GPION_DATA |= (1u << LED3);
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index == 0) {
    GPIOF_DATA &= ~(1u << LED0);
  } else if (Index == 1) {
    GPIOF_DATA &= ~(1u << LED1);
  } else if (Index == 2) {
    GPION_DATA &= ~(1u << LED2);
  } else if (Index == 3) {
    GPION_DATA &= ~(1u << LED3);
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index == 0) {
    GPIOF_DATA ^= (1u << LED0);
  } else if (Index == 1) {
    GPIOF_DATA ^= (1u << LED1);
  } else if (Index == 2) {
    GPION_DATA ^= (1u << LED2);
  } else if (Index == 3) {
    GPION_DATA ^= (1u << LED3);
  }
}

/****** End Of File *************************************************/
