/** @file system.c
*   @brief System Driver Source File
*   @date 28.Aug.2015
*   @version 04.05.01
*
*   This file contains:
*   - API Functions
*   .
*   which are relevant for the System driver.
*/

/*
* Copyright (C) 2009-2015 Texas Instruments Incorporated - www.ti.com
*
*
*  Redistribution and use in source and binary forms, with or without
*  modification, are permitted provided that the following conditions
*  are met:
*
*    Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
*
*    Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in the
*    documentation and/or other materials provided with the
*    distribution.
*
*    Neither the name of Texas Instruments Incorporated nor the names of
*    its contributors may be used to endorse or promote products derived
*    from this software without specific prior written permission.
*
*  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
*  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
*  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
*  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
*  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
*  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
*  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
*  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
*  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
*  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
*/


/* USER CODE BEGIN (0) */
/* USER CODE END */


/* Include Files */

#include "system.h"

/* USER CODE BEGIN (1) */
/* USER CODE END */

/** @fn void systemInit(void)
*   @brief Initializes System Driver
*
*   This function initializes the System driver.
*
*/
void _systemInit(void);
void _systemInit(void)
{
/* USER CODE BEGIN (2) */
/* USER CODE END */

    /** @b Initialize @b Flash @b Wrapper: */

    /** - Setup flash read mode, address wait states and data wait states */
    flashWREG->FRDCNTL =  0x01000000U
                       | (2U << 8U)
                       | (0U << 4U)
                       |  1U;

    /** - Setup flash bank power modes */
    flashWREG->FBFALLBACK = 0x05050000
                          | (SYS_SLEEP << 14U)
                          | (SYS_SLEEP << 12U)
                          | (SYS_SLEEP << 10U)
                          | (SYS_SLEEP << 8U)
                          | (SYS_SLEEP << 6U)
                          | (SYS_SLEEP << 4U)
                          | (SYS_ACTIVE << 2U)
                          |  SYS_ACTIVE;

    /** @b Initialize @b Pll: */

    /** - Setup pll control register 1:
    *     - Setup reset on oscillator slip
    *     - Setup bypass on pll slip
    *     - Setup Pll output clock divider
    *     - Setup reset on oscillator fail
    *     - Setup reference clock divider
    *     - Setup Pll multiplier
    */
    systemREG->PLLCTL1  =  0x00000000U
                        |  0x20000000U
                        | ((1U - 1U) << 24U)
                        |  0x00000000U
                        | ((4U - 1U) << 16U)
                        | ((100U  - 1U) << 8U);

    /** - Setup pll control register 1
    *     - Enable/Disable frequency modulation
    *     - Setup spreading rate
    *     - Setup bandwidth adjustment
    *     - Setup internal Pll output divider
    *     - Setup spreading amount
    */
    systemREG->PLLCTL2  = 0x00000000U
                        | (255U << 22U)
                        | (0U << 12U)
                        | ((5U - 1U) << 9U)
                        |  61U;


    /** @b Initialize @b Clock @b Tree: */

    /** - Start clock source lock */
    systemREG->CSDIS =	0x00000000U
						| 0x00000000U
						| 0x00000008U
						| 0x00000004U
						| 0x00000000U;

    /** - Wait for until clocks are locked */
    while ((systemREG->CSVSTAT & ((systemREG->CSDIS ^ 0xFF) & 0xFF)) != ((systemREG->CSDIS ^ 0xFF) & 0xFF));

    /** - Setup GCLK, HCLK and VCLK clock source for normal operation, power down mode and after wakeup */
    systemREG->GHVSRC = (SYS_OSC << 24U)
                       | (SYS_OSC << 16U)
                       |  SYS_PLL;

    /** - Power-up all peripherals */
    pcrREG->PSPWRDWNCLR0 = 0xFFFFFFFFU;
    pcrREG->PSPWRDWNCLR1 = 0xFFFFFFFFU;
    pcrREG->PSPWRDWNCLR2 = 0xFFFFFFFFU;
    pcrREG->PSPWRDWNCLR3 = 0xFFFFFFFFU;

    /** - Setup synchronous peripheral clock dividers for VCLK1 and VCLK2 */
    systemREG->CLKCNTL  = (systemREG->CLKCNTL & 0xFFF0FFFFU)
                         | (15U << 16U);

    systemREG->CLKCNTL  = (systemREG->CLKCNTL & 0xF0F0FFFFU)
						 | ((1U -1U) << 24U)
	                     | ((1U - 1U) << 16U);

    /** - Setup RTICLK1 clock */
    systemREG->RCLKSRC  = (1U << 8U)
                        |  SYS_VCLK;

    /** - Setup asynchronous peripheral clock sources for AVCLK1 and AVCLK2 */
    systemREG->VCLKASRC  = SYS_VCLK;

    /** - Enable Peripherals */
    systemREG->CLKCNTL |= 1U << 8U;

    /** @note: HCLK >= VCLK2 >= VCLK_sys */

/* USER CODE BEGIN (3) */
/* USER CODE END */
}

/** @fn void _memoryInit()
*   @brief Memory Initialization Driver
*
*   This function is called to perform Memory initialization of selected RAM's.
*/
void _memoryInit()
{
/* USER CODE BEGIN (4) */
/* USER CODE END */

	/* Enable Memory Hardware Initialization */
	systemREG->MINITGCR = 0xAU;

    /* Enable Memory Hardware Initialization for selected RAM's */
	systemREG->MSINENA  = 0x0039;

	/* Wait until Memory Hardware Initialization complete */
	while((systemREG->MSTCGSTAT & 0x00000100U) != 0x00000100U)
	{
	}/* Wait */

	/* Disable Memory Hardware Initialization */
	systemREG->MINITGCR = 0x5U;

/* USER CODE BEGIN (5) */
/* USER CODE END */
}

void systemPowerDown(uint32 mode)
{
    /* Disable clock sources */
    systemREG->CSDISSET = mode & 0x000000FFU;

    /* Disable clock domains */
    systemREG->CDDIS = (mode >> 8U) & 0x000000FFU;

    /* Idle CPU */
    asm volatile(" wfi");
}

/* USER CODE BEGIN (6) */
/* USER CODE END */

void _mpuInit(void)
{
    /* Setting Region 0 */
    M3CORE->MPURNR = REGION0;
    /* Setting the base address for region */
    M3CORE->MPURBAR0 = 0x08000000U;
    /* load MPU region attribute register, MPU region size, enable/Disable the region */
    M3CORE->MPURASR0 = AP_EXE_NOACCESS | Size_32B | 0U;

    /* Setting Region 1 */
    M3CORE->MPURNR = REGION1;
    /* Setting the base address for region */
    M3CORE->MPURBAR0 = 0x08000000U;
    /* load MPU region attribute register, MPU region size, enable/Disable the region */
    M3CORE->MPURASR0 = AP_EXE_NOACCESS | Size_32B | 0U;

    /* Setting Region 2 */
    M3CORE->MPURNR = REGION2;
    /* Setting the base address for region */
    M3CORE->MPURBAR0 = 0x08000000U;
    /* load MPU region attribute register, MPU region size, enable/Disable the region */
    M3CORE->MPURASR0 = AP_EXE_NOACCESS | Size_32B | 0U;

    /* Setting Region 3 */
    M3CORE->MPURNR = REGION3;
    /* Setting the base address for region */
    M3CORE->MPURBAR0 = 0x08000000U;
    /* load MPU region attribute register, MPU region size, enable/Disable the region */
    M3CORE->MPURASR0 = AP_EXE_NOACCESS | Size_32B | 0U;

    /* Setting Region 4 */
    M3CORE->MPURNR = REGION4;
    /* Setting the base address for region */
    M3CORE->MPURBAR0 = 0x08000000U;
    /* load MPU region attribute register, MPU region size, enable/Disable the region */
    M3CORE->MPURASR0 = AP_EXE_NOACCESS | Size_32B | 0U;

    /* Setting Region 5 */
    M3CORE->MPURNR = REGION5;
    /* Setting the base address for region */
    M3CORE->MPURBAR0 = 0x08000000U;
    /* load MPU region attribute register, MPU region size, enable/Disable the region */
    M3CORE->MPURASR0 = AP_EXE_NOACCESS | Size_32B | 0U;

    /* Setting Region 6 */
    M3CORE->MPURNR = REGION6;
    /* Setting the base address for region */
    M3CORE->MPURBAR0 = 0x08000000U;
    /* load MPU region attribute register, MPU region size, enable/Disable the region */
    M3CORE->MPURASR0 = AP_EXE_NOACCESS | Size_32B | 0U;

    /* Setting Region 7 */
    M3CORE->MPURNR = REGION7;
    /* Setting the base address for region */
    M3CORE->MPURBAR0 = 0x08000000U;
    /* load MPU region attribute register, MPU region size, enable/Disable the region */
    M3CORE->MPURASR0 = AP_EXE_NOACCESS | Size_32B | 0U;

    /* Enable MPU */
    M3CORE->MPUCR = 0;
}

void mpuEnable(void)
{
    /* Enable MPU */
    M3CORE->MPUCR = 1U;
}

void mpuDisable(void)
{
    /* Enable MPU */
    M3CORE->MPUCR = 0U;
}

void mpuSetRegion(uint32 region, uint32 base_addr, uint32 size, uint32 access)
{
    /* Setting Region */
    M3CORE->MPURNR = region;
    /* Setting the base address for region */
    M3CORE->MPURBAR0 = base_addr;
    /* load MPU region attribute register, MPU region size, enable the region */
    M3CORE->MPURASR0 = access | size | 0x1U;
}
void mpuDisableRegion(uint32 region)
{
    /* Setting Region */
    M3CORE->MPURNR = region;
    /* Disable the region */
    M3CORE->MPURASR0 = 0U;
}

void _switch_to_usermode()
{

	asm volatile("  subs sp,sp,#4");
	asm volatile("  str r0,[sp]");

	asm volatile(" mov  r0,#0x01");
	asm volatile(" msr  CONTROL,r0");

	asm volatile(" ldr r0,[sp]");
	asm volatile(" add sp,#4");
}

/* USER CODE BEGIN (7) */
/* USER CODE END */
