/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
Purpose : BSP for Thundersoft TT_M3HQ eval board
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define NUM_LEDS         (4)
#define LED0_POS         (4)

#define CG_BASE_ADDR     (0x400F3000u)
#define CG_FSYSENA       (*(volatile unsigned long*)(CG_BASE_ADDR + 0x50))  // Clock supply and stop register A for fsys

#define PORTK_BASE_ADDR  (0x400C0900u)
#define PORTK_DATA       (*(volatile unsigned long*)(PORTK_BASE_ADDR + 0x00))
#define PORTK_CR         (*(volatile unsigned long*)(PORTK_BASE_ADDR + 0x04))

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  CG_FSYSENA |= (1u << 9);  // Enable Port K clock
  PORTK_CR   |= (1u << 4)   // Enable output LED0
             |  (1u << 5)   // Enable output LED1
             |  (1u << 6)   // Enable output LED2
             |  (1u << 7);  // Enable output LED3
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index < NUM_LEDS) {
    PORTK_DATA |= (1u << (Index + LED0_POS));
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index < NUM_LEDS) {
    PORTK_DATA &= ~(1u << (Index + LED0_POS));
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index < NUM_LEDS) {
    PORTK_DATA ^= (1u << (Index + LED0_POS));
  }
}

/*************************** End of file ****************************/
