/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
Purpose : BSP for Thundersoft TT_M4G9 eval board
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define NUM_LEDS         (4)
#define LED0_POS         (4)

#define CG_BASE_ADDR     (0x40083000u)
#define CG_FSYSMENB      (*(volatile unsigned long*)(CG_BASE_ADDR + 0x4C))  // Middle speed clock supply and stop register B for fsys

#define PORTE_BASE_ADDR  (0x400E0400u)
#define PORTE_DATA       (*(volatile unsigned long*)(PORTE_BASE_ADDR + 0x00))
#define PORTE_CR         (*(volatile unsigned long*)(PORTE_BASE_ADDR + 0x04))

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  CG_FSYSMENB |= (1u << 6);  // Enable Port E clock
  PORTE_CR    |= (1u << 4)   // Enable output LED0
              |  (1u << 5)   // Enable output LED1
              |  (1u << 6)   // Enable output LED2
              |  (1u << 7);  // Enable output LED3
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  if (Index < NUM_LEDS) {
    PORTE_DATA |= (1u << (Index + LED0_POS));
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  if (Index < NUM_LEDS) {
    PORTE_DATA &= ~(1u << (Index + LED0_POS));
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  if (Index < NUM_LEDS) {
    PORTE_DATA ^= (1u << (Index + LED0_POS));
  }
}

/*************************** End of file ****************************/
