/**
 * @file system_TZ12xx.c
 * @brief CMSIS Device System Source File for TZ12xx Device Series
 * @date $Date:: 2016-05-27 10:37:14 +0900 #$
 * @note
 */

/*
 * COPYRIGHT (C) 2015
 * TOSHIBA CORPORATION STORAGE & ELECTRONIC DEVICES SOLUTIONS COMPANY
 * ALL RIGHTS RESERVED
 *
 * THE SOURCE CODE AND ITS RELATED DOCUMENTATION IS PROVIDED "AS IS". TOSHIBA
 * CORPORATION MAKES NO OTHER WARRANTY OF ANY KIND, WHETHER EXPRESS, IMPLIED OR,
 * STATUTORY AND DISCLAIMS ANY AND ALL IMPLIED WARRANTIES OF MERCHANTABILITY,
 * SATISFACTORY QUALITY, NON INFRINGEMENT AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 * THE SOURCE CODE AND DOCUMENTATION MAY INCLUDE ERRORS. TOSHIBA CORPORATION
 * RESERVES THE RIGHT TO INCORPORATE MODIFICATIONS TO THE SOURCE CODE IN LATER
 * REVISIONS OF IT, AND TO MAKE IMPROVEMENTS OR CHANGES IN THE DOCUMENTATION OR
 * THE PRODUCTS OR TECHNOLOGIES DESCRIBED THEREIN AT ANY TIME.
 *
 * TOSHIBA CORPORATION SHALL NOT BE LIABLE FOR ANY DIRECT, INDIRECT OR
 * CONSEQUENTIAL DAMAGE OR LIABILITY ARISING FROM YOUR USE OF THE SOURCE CODE OR
 * ANY DOCUMENTATION, INCLUDING BUT NOT LIMITED TO, LOST REVENUES, DATA OR
 * PROFITS, DAMAGES OF ANY SPECIAL, INCIDENTAL OR CONSEQUENTIAL NATURE, PUNITIVE
 * DAMAGES, LOSS OF PROPERTY OR LOSS OF PROFITS ARISING OUT OF OR IN CONNECTION
 * WITH THIS AGREEMENT, OR BEING UNUSABLE, EVEN IF ADVISED OF THE POSSIBILITY OR
 * PROBABILITY OF SUCH DAMAGES AND WHETHER A CLAIM FOR SUCH DAMAGE IS BASED UPON
 * WARRANTY, CONTRACT, TORT, NEGLIGENCE OR OTHERWISE.
 */

#include "TZ12xx.h"

#define __SYSTEM_CLOCK 12000000

#define OVERRAP_TIME_Msk    (0xff<<8)
#define OVERRAP_TIME_Sft    (8)
#define TDE_TIME_Msk        (0x3f)
#define TDE_TIME_Sft        (0)
#define TIMER_COUNT_BST_Sft (20)
#define TIMER_COUNT_EN_Sft  (16)
#define TIMER_COUNT_BP_Msk  (0x3f<<16)
#define DCDC_TRIMMING0_MODE_Sft (12UL)
#define DCDC_TRIMMING0_MODE_Msk (0x1000UL)
#define OSC12M_TIMER_COUNT_Sft    (16UL)
#define VOLTAGEMODE_CTRL_SETTING1_FMODE0_Sft (0UL)
#define VOLTAGEMODE_CTRL_SETTING1_FMODE0_Msk (0x1UL)
#define VOLTAGEMODE_CTRL_SETTING1_FMODE1_Sft (1UL)
#define VOLTAGEMODE_CTRL_SETTING1_FMODE1_Msk (0x2UL)

#define RESET_RTC          (1<<7)
#define RESET_LOCKUP       (1<<6)
#define RESET_SYSRESETREQ  (1<<5)
#define RESET_WDT          (1<<4)
#define RESET_BORHW        (1<<3)
#define RESET_BORSW        (1<<2)
#define RESET_SYSRESET     (1<<1)
#define RESET_POR          (1<<0)

#define PMU_CS_MAIN_MSK       (7<<24)
#define PMU_CS_MAIN_PLL       (4<<24)
#define PMU_CS_MAIN_ADPLL     (5<<24)
#define PMU_CS_MAIN_OSC32K      (6<<24)

#define PMU_PD_PDISP        (1<<6)
#define PMU_PD_PSRAM4       (1<<14)
#define PMU_PD_PSRAM5       (1<<15)
#define PMU_PD_PSRAM6       (1<<16)
#define PMU_PD_PSRAM7       (1<<17)
#define PMU_PD_PSRAM8       (1<<18)

#define PMU_SRST_EBIF_Msk     ((0x10UL)|(0x20UL)|(0x40UL))
#define PMU_SRST_GPIER_DISP_Msk   (0x2UL)
#define PMU_SRST_GPIER_MAIN_Msk   (0x1UL)
#define PMU_SRST_SRAMCG0_Msk    (0x1000UL)
#define PMU_SRST_SRAMCG1_Msk    (0x2000UL)
#define PMU_SRST_SRAMCG2_Msk    (0x4000UL)
#define PMU_SRST_SRAMCG3_Msk    (0x8000UL)
#define PMU_SRST_SRAMCS_Msk     (0x4UL)

#define CUR_PSCAL_ADPLL_Msk       (0x001F0000)
#define CUR_PSCAL_ADPLL_Sft       (16)
#define CUR_PSCAL_PLL_Msk       (0x00001F00)
#define CUR_PSCAL_PLL_Sft       (8)
#define CUR_PSCAL_Msk         (0x0000001F)
#define CUR_PSCAL_Sft         (0x00000000)
#define PLL_ND_Msk            (0x0000000F)
#define ADPLL_SELCP_Msk         (0x03800000)
#define ADPLL_FCW_Msk         (0x03FF0000)
#define ADPLL_FCW_Sft         (16)
#define ADPLL_SELFREQR_Msk        (0x00001F00)
#define ADPLL_SELFREQR_Sft        (8)
#define ADPLL_SELFREQ_Msk       (0x000000F0)
#define ADPLL_SELFREQ_Sft       (4)

#define SET_SIOSC12M_CLK   (1<<8)
#define SET_OSC32K         (1<<9)

#define SRST_OFF_PMAIN_0  0x1290UL
#define BOOTCONFIG          0x6c70UL

#define PMU_CLK_SRC_OSC12M  (2<<16)
#define SET_SIOSC12M_CLK  (1<<8)
#define OSC12M_POS      (1)
#define PLL_POS       (2)


uint32_t SystemCoreClock = __SYSTEM_CLOCK;/*!< System Clock Frequency (Core Clock)*/


//-------- <<< Use Configuration Wizard in Context Menu >>> --------------------

// <e> EBIF
// <i> Enable EBIF
//  <o1> Drive strength. <0=>2mA (for 24/30MHz) <1=>4mA <2=>6mA <3=>8mA
//  <i> It must be set to 4mA and up when EBIF runs at 48 or 60 MHz.
// </e>
#define USE_EBIF 0
#if USE_EBIF
# define RTE_EBIF_DRIVE_STRENGTH 3
#endif

// <q0> Enabled SRAMCS
// <q1> Enabled SRAMCG0
// <q2> Enabled SRAMCG1
// <q3> Enabled SRAMCG2
// <q4> Enabled SRAMCG3
#define USE_SRAMCS    1
#define USE_SRAMCG0   1
#define USE_SRAMCG1   0
#define USE_SRAMCG2   0
#define USE_SRAMCG3   0

// <q0> Force SPINOFC to use quad access.
#define USE_QUAD_ACCESS 0

// <<< end of configuration section >>>

#if defined( __ICCARM__ ) && defined( TZ12XX_BOOT_XIP )
# pragma default_function_attributes = @ ".intvec"
#endif

#if ((1==USE_EBIF) || (1==USE_SRAMCG0) || (1==USE_SRAMCG1) || (1==USE_SRAMCG2) || (1==USE_SRAMCG3) || (1==USE_SRAMCS))
static void PowerOnModules(void)
{
        PMU_Type *pm = TZ1K_PMU;
        uint32_t val;

        /* power on */
        val = 0;
#if ((1==USE_EBIF) || (1==USE_SRAMCG0) || (1==USE_SRAMCG1) || (1==USE_SRAMCG2) || (1==USE_SRAMCG3))
        val |= PMU_PD_PDISP;
#endif
#if (1==USE_SRAMCG0)
        val |= PMU_PD_PSRAM5;
#endif
#if (1==USE_SRAMCG1)
        val |= PMU_PD_PSRAM6;
#endif
#if (1==USE_SRAMCG2)
        val |= PMU_PD_PSRAM7;
#endif
#if (1==USE_SRAMCG3)
        val |= PMU_PD_PSRAM8;
#endif
#if (1==USE_SRAMCS)
        val |= PMU_PD_PSRAM4;
#endif
        pm->POWERDOMAIN_CTRL = val;
        do {
                val = pm->POWERDOMAIN_CTRL;
        } while (val);
#if ((1==USE_EBIF) || (1==USE_SRAMCG0) || (1==USE_SRAMCG1) || (1==USE_SRAMCG2) || (1==USE_SRAMCG3))
        pm->POWERDOMAIN_CTRL_LATI_SETTING &= ~PMU_PD_PDISP;
#endif

#if ((1==USE_EBIF) || (1==USE_SRAMCG0) || (1==USE_SRAMCG1) || (1==USE_SRAMCG2) || (1==USE_SRAMCG3))
        /* deassert reset signal of PDISP */
        pm->SRST_OFF_PDISP = PMU_SRST_GPIER_DISP_Msk;
        val = pm->SRST_OFF_PDISP;
        pm->SRST_OFF_PDISP = PMU_SRST_GPIER_MAIN_Msk;
        val = pm->SRST_OFF_PDISP;
        val = 0;
#if (1==USE_EBIF)
        val |= PMU_SRST_EBIF_Msk;
#endif
#if (1==USE_SRAMCG0)
        val |= PMU_SRST_SRAMCG0_Msk;
#endif
#if (1==USE_SRAMCG1)
        val |= PMU_SRST_SRAMCG1_Msk;
#endif
#if (1==USE_SRAMCG2)
        val |= PMU_SRST_SRAMCG2_Msk;
#endif
#if (1==USE_SRAMCG3)
        val |= PMU_SRST_SRAMCG3_Msk;
#endif
        pm->SRST_OFF_PDISP = val;
        val = pm->SRST_OFF_PDISP;
#endif
#if (1==USE_SRAMCS)
        /* deassert reset signal of PSUB */
        pm->SRST_OFF_PSUB_0 = PMU_SRST_SRAMCS_Msk;
        val = pm->SRST_OFF_PSUB_0;
#endif
}
#else
# define PowerOnModules()
#endif


#if (1==USE_EBIF)
# include "RTE_Device.h"
# define CFG_PU    (((uint32_t)RTE_EBIF_DRIVE_STRENGTH<<2)|2)
# define CFG_PD    (((uint32_t)RTE_EBIF_DRIVE_STRENGTH<<2)|0)
# define CFG_HZ    (((uint32_t)RTE_EBIF_DRIVE_STRENGTH<<2)|1)
static void EnablePinFunction(void)
{
        PMU_Type *pm   = TZ1K_PMU;
        GCONF_Type *cf = TZ1K_GCONF;

        cf->IO_CFG_PE0 = (RTE_PE00==2?CFG_PD    :1)    |(RTE_PE01==2?CFG_PD<<4 :1<<4) |(RTE_PE02==2?CFG_PD<<8 :1<<8) |(RTE_PE03==2?CFG_PD<<12:1<<12)|
                         (RTE_PE04==2?CFG_PD<<16:1<<16)|(RTE_PE05==2?CFG_PD<<20:1<<20)|(RTE_PE06==2?CFG_PD<<24:1<<24)|(RTE_PE07==2?CFG_PD<<28:1<<28);
        cf->IO_CFG_PE1 = (RTE_PE08==2?CFG_PD    :1)    |(RTE_PE09==2?CFG_PD<<4 :1<<4) |(RTE_PE10==2?CFG_PD<<8 :1<<8) |(RTE_PE11==2?CFG_PD<<12:1<<12)|
                         (RTE_PE12==2?CFG_PD<<16:1<<16)|(RTE_PE13==2?CFG_PD<<20:1<<20)|(RTE_PE14==2?CFG_PD<<24:1<<24)|(RTE_PE15==2?CFG_PD<<28:1<<28);
        cf->IO_CFG_PF0 = (RTE_PF00==2?CFG_HZ    :1)    |(RTE_PF01==2?CFG_HZ<<4 :1<<4) |(RTE_PF02==2?CFG_HZ<<8 :1<<8) |(RTE_PF03==2?CFG_HZ<<12:1<<12)|
                         (RTE_PF04==2?CFG_HZ<<16:1<<16)|(RTE_PF05==2?CFG_HZ<<20:1<<20)|(RTE_PF06==2?CFG_HZ<<24:1<<24)|(RTE_PF07==2?CFG_HZ<<28:1<<28);
        cf->IO_CFG_PF1 = (RTE_PF08==2?CFG_HZ    :1)    |(RTE_PF09==2?CFG_HZ<<4 :1<<4) |(RTE_PF10==2?CFG_HZ<<8 :1<<8) |(RTE_PF11==2?CFG_HZ<<12:1<<12)|
                         (RTE_PF12==2?CFG_HZ<<16:1<<16)|(RTE_PF13==2?CFG_HZ<<20:1<<20)|(RTE_PF14==2?CFG_PD<<24:1<<24)|(RTE_PF15==2?CFG_PU<<28:1<<28);
        cf->IO_CFG_PF2 = (RTE_PF16==2?CFG_HZ    :1);

        cf->FMODE_CFG_PE0 = (RTE_PE00==2?2:0)|(RTE_PE01==2?2<<4:0)|(RTE_PE02==2?2<<8:0)|(RTE_PE03==2?2<<12:0)|(RTE_PE04==2?2<<16:0)|(RTE_PE05==2?2<<20:0)|(RTE_PE06==2?2<<24:0)|(RTE_PE07==2?2<<28:0);
        cf->FMODE_CFG_PE1 = (RTE_PE08==2?2:0)|(RTE_PE09==2?2<<4:0)|(RTE_PE10==2?2<<8:0)|(RTE_PE11==2?2<<12:0)|(RTE_PE12==2?2<<16:0)|(RTE_PE13==2?2<<20:0)|(RTE_PE14==2?2<<24:0)|(RTE_PE15==2?2<<28:0);
        cf->FMODE_CFG_PF0 = (RTE_PF00==2?2:0)|(RTE_PF01==2?2<<4:0)|(RTE_PF02==2?2<<8:0)|(RTE_PF03==2?2<<12:0)|(RTE_PF04==2?2<<16:0)|(RTE_PF05==2?2<<20:0)|(RTE_PF06==2?2<<24:0)|(RTE_PF07==2?2<<28:0);
        cf->FMODE_CFG_PF1 = (RTE_PF08==2?2:0)|(RTE_PF09==2?2<<4:0)|(RTE_PF10==2?2<<8:0)|(RTE_PF11==2?2<<12:0)|(RTE_PF12==2?2<<16:0)|(RTE_PF13==2?2<<20:0)|(RTE_PF14==2?2<<24:0)|(RTE_PF15==2?2<<28:0);
        cf->FMODE_CFG_PF2 = (RTE_PF16==2?2:0);

        pm->IO_CTRL_STBX_SETTING4 = (RTE_PE00==2?1:0)    |(RTE_PE01==2?1<<1:0) |(RTE_PE02==2?1<<2:0) |(RTE_PE03==2?1<<3:0) |
                                    (RTE_PE04==2?1<<4:0) |(RTE_PE05==2?1<<5:0) |(RTE_PE06==2?1<<6:0) |(RTE_PE07==2?1<<7:0) |
                                    (RTE_PE08==2?1<<8:0) |(RTE_PE09==2?1<<9:0) |(RTE_PE10==2?1<<10:0)|(RTE_PE11==2?1<<11:0)|
                                    (RTE_PE12==2?1<<12:0)|(RTE_PE13==2?1<<13:0)|(RTE_PE14==2?1<<14:0)|(RTE_PE15==2?1<<15:0);
        pm->IO_CTRL_STBX_SETTING5 = (RTE_PE00==2?1:0)    |(RTE_PE01==2?1<<1:0) |(RTE_PE02==2?1<<2:0) |(RTE_PE03==2?1<<3:0) |
                                    (RTE_PE04==2?1<<4:0) |(RTE_PE05==2?1<<5:0) |(RTE_PE06==2?1<<6:0) |(RTE_PE07==2?1<<7:0) |
                                    (RTE_PE08==2?1<<8:0) |(RTE_PE09==2?1<<9:0) |(RTE_PE10==2?1<<10:0)|(RTE_PE11==2?1<<11:0)|
                                    (RTE_PE12==2?1<<12:0)|(RTE_PE13==2?1<<13:0)|(RTE_PE14==2?1<<14:0)|(RTE_PE15==2?1<<15:0)|
                                    (RTE_PF16==2?1<<16:0);
}
#else
static void EnablePinFunction(void)
{
}
#endif

#if (1==USE_EBIF)

#define NUM_EVA_EBIF_PSCALE     5
#define PDISP_CLK_FIELD 0x0000f7d3
#define PDISP_RST_FIELD 0x0000f1f3
#define PEBIF_CLK_FIELD 0x00000050
#define PEBIF_RST_FIELD 0x00000070

#define CPU_EBIF_MEM_BASE      0x60000000
#define CPU_EBIF_MEM_SIZE      0x01000000

#define EBIF_U0CH0_BASE_DEFAULT (CPU_EBIF_MEM_BASE + 0x00000000)
#define EBIF_U0CH1_BASE_DEFAULT (CPU_EBIF_MEM_BASE + CPU_EBIF_MEM_SIZE/2)

/* Variable Latency */
#define CSRAM_LATENCY_BIT14TO11_DEFAULT 0x2

/* Drive Strangth (@Device) */
/* 00: Full, 01: 1/2(default), 10:1/4, 11:Reserved */
#define CSRAM_DEVSTR_BIT5TO4    0x1

/* Wait until BLOCK_STATUS_PDISP.ACTIVE_EBIF is 0 */
static void ebifWaitIdle(void)
{
  uint32_t field_ebif_active = 0x1 << 3;
  volatile uint32_t dat0 = ~0x0;

  while ((field_ebif_active & dat0) != 0x0){
    dat0 = TZ1K_PMU->BLOCK_STATUS_PDISP;
  }
}

static void ebifCsramAcDly(void)
{
  volatile uint32_t dat;

  dat = TZ1K_EBIF_CONF->EBIF_CONF_MODE;
  dat = 0xfffdffff & dat; /* Set CLKISEL => 0 */

  TZ1K_EBIF_CONF->EBIF_CONF_MODE = dat;
}

static void ebifSetupAdmCore(void)
{
  volatile uint32_t dat0 = 0x0;

  ebifWaitIdle();

  /* Step  9 is static configuration */
  TZ1K_EBIF_CONF->EBIF_CONF_IWTMCTRL = 0x1;

  dat0 = TZ1K_EBIF_CONF->EBIF_CONF_MODE;
  TZ1K_EBIF_CONF->EBIF_CONF_MODE = dat0 | 0x1; /* Set ADM */

  TZ1K_EBIF_CONF->EBIF_CONF_MODE &= ~(0x3 << 10);
  ebifCsramAcDly ();

  /* Step 10 is to enable OE. */
  TZ1K_EBIF_CONF->EBIF_CONF_IOCTRL = 0x1;
}

static uint32_t
ebif_format_data_cycles(
  uint32_t tWTIME,uint32_t tTR,uint32_t tPC,uint32_t tWP,uint32_t tCEOE,uint32_t tWC,uint32_t tRC)
{
  uint32_t data;
  data = 0x00000000
    | ( (0x00000001 & tWTIME ) << 20 )
    | ( (0x00000007 & tTR    ) << 17 )
    | ( (0x00000007 & tPC    ) << 14 )
    | ( (0x00000007 & tWP    ) << 11 )
    | ( (0x00000007 & tCEOE  ) <<  8 )
    | ( (0x0000000f & tWC    ) <<  4 )
    | ( (0x0000000f & tRC    ) <<  0 );
  return data;
}

static uint32_t
ebif_format_data_opmode(
  uint32_t bls,uint32_t avd,uint32_t wdbl,uint32_t wdsync,uint32_t rdbl,uint32_t rdsync,uint32_t mw)
{
  uint32_t        data;
  data = 0x00000000
    | ( (0x00000001 & bls    ) << 12 )
    | ( (0x00000001 & avd    ) << 11 )
    | ( (0x00000007 & wdbl   ) <<  7 )
    | ( (0x00000001 & wdsync ) <<  6 )
    | ( (0x00000007 & rdbl   ) <<  3 )
    | ( (0x00000001 & rdsync ) <<  2 )
    | ( (0x00000003 & mw     ) <<  0 );
  return data;
}

static void ebifSetFormatPatToReg(uint32_t sync_mode,uint32_t sel)
{
  uint32_t format_cycles[NUM_EVA_EBIF_PSCALE];
  uint32_t format_opmode[NUM_EVA_EBIF_PSCALE];
  if (sync_mode == 0x0) {
    /* WTIME, tTR,  tPC, tWP, tCEOE, tWC, tRC */
    format_cycles[0] = ebif_format_data_cycles(0x0, 0x1, 0x0, 0x2, 0x3, 0x5, 0x5);
    format_cycles[1] = ebif_format_data_cycles(0x0, 0x1, 0x0, 0x2, 0x3, 0x5, 0x5);
    format_cycles[2] = ebif_format_data_cycles(0x0, 0x1, 0x0, 0x2, 0x2, 0x5, 0x3);
    format_cycles[3] = ebif_format_data_cycles(0x0, 0x1, 0x0, 0x1, 0x1, 0x4, 0x3);
    format_cycles[4] = ebif_format_data_cycles(0x0, 0x1, 0x0, 0x1, 0x1, 0x4, 0x3);

    /* BLS, AVD, WDBL, WDSYNC, RDBL, RDSYNC, MV */
    format_opmode[0] = ebif_format_data_opmode(0x0, 0x1, 0x0, 0x0, 0x0, 0x0, 0x1);
    format_opmode[1] = ebif_format_data_opmode(0x0, 0x1, 0x0, 0x0, 0x0, 0x0, 0x1);
    format_opmode[2] = ebif_format_data_opmode(0x0, 0x1, 0x0, 0x0, 0x0, 0x0, 0x1);
    format_opmode[3] = ebif_format_data_opmode(0x0, 0x1, 0x0, 0x0, 0x0, 0x0, 0x1);
    format_opmode[4] = ebif_format_data_opmode(0x0, 0x1, 0x0, 0x0, 0x0, 0x0, 0x1);
  } else {
    /* WTIME, tTR,  tPC, tWP, tCEOE, tWC, tRC */
    format_cycles[0] = ebif_format_data_cycles(0x0, 0x1, 0x0, 0x1, 0x2, 0x4, 0x4);
    format_cycles[1] = ebif_format_data_cycles(0x0, 0x1, 0x0, 0x1, 0x2, 0x4, 0x4);
    format_cycles[2] = ebif_format_data_cycles(0x0, 0x1, 0x0, 0x1, 0x2, 0x4, 0x4);
    format_cycles[3] = ebif_format_data_cycles(0x0, 0x1, 0x0, 0x1, 0x2, 0x4, 0x4);
    format_cycles[4] = ebif_format_data_cycles(0x0, 0x1, 0x0, 0x1, 0x2, 0x4, 0x4);

    /* BLS, AVD, WDBL, WDSYNC, RDBL, RDSYNC, MV */
    format_opmode[0] = ebif_format_data_opmode(0x0, 0x1, 0x4, 0x1, 0x3, 0x1, 0x1);
    format_opmode[1] = ebif_format_data_opmode(0x0, 0x1, 0x4, 0x1, 0x3, 0x1, 0x1);
    format_opmode[2] = ebif_format_data_opmode(0x0, 0x1, 0x4, 0x1, 0x3, 0x1, 0x1);
    format_opmode[3] = ebif_format_data_opmode(0x0, 0x1, 0x4, 0x1, 0x3, 0x1, 0x1);
    format_opmode[4] = ebif_format_data_opmode(0x0, 0x1, 0x1, 0x1, 0x1, 0x1, 0x1);
  }
  TZ1K_EBIF->EBIF_SETCYCLES = format_cycles[sel];
  TZ1K_EBIF->EBIF_SETOPMODE = format_opmode[sel];
}

static void ebif_update_settings(uint32_t smcCh,uint32_t extCh,uint32_t cmdtype,uint32_t addr)
{
  uint32_t l_ch_sel_raddr = 0;
  volatile uint32_t       data;

  data = 0x00000000
    | ( (0x00000003 & extCh  ) << 23 )
    | ( (0x00000003 & cmdtype) << 21 )
    | ( (0x00000001 & cmdtype) << 20 )
    | ( (0x000fffff & addr   ) << 0 );

  TZ1K_EBIF->EBIF_DIRECTCMD = data;

  /* - Dummy read (Moving to an idle state in EBIF) */
  l_ch_sel_raddr = (extCh)? EBIF_U0CH1_BASE_DEFAULT : EBIF_U0CH0_BASE_DEFAULT;

  data = *( (volatile uint16_t*)l_ch_sel_raddr);
}

static void ebifUpdateTimingByFormattedParameters(uint32_t ch,uint32_t sync_mode)
{
  ebifSetFormatPatToReg(sync_mode, 0);
  ebif_update_settings(0x0, ch, 0x2, 0x0);
}

static void
ebif_control_dircmd(uint32_t smcCh,uint32_t extCh,uint32_t cmdtype,uint32_t addr,uint32_t cycles,uint32_t opmode)
{
  volatile uint32_t       l_addr;
  volatile uint32_t       l_cycles;
  volatile uint32_t       l_opmode;
  volatile uint32_t       data;
  uint32_t l_ch_sel_raddr = 0;

  if (cmdtype != 0x1) {
    if (cycles == 0x0) {
      l_cycles = *((volatile uint32_t*)((uint8_t*)TZ1K_EBIF->EBIF_CYCLES0 + 0x20 * extCh));
    } else {
      l_cycles = cycles;
    }
    if (opmode == 0x0) {
      l_opmode = *((volatile uint32_t*)((uint8_t*)TZ1K_EBIF->EBIF_OPMODE0 + 0x20 * extCh));
    } else {
      l_opmode = opmode;
    }

    TZ1K_EBIF->EBIF_SETCYCLES = l_cycles;
    TZ1K_EBIF->EBIF_SETOPMODE = l_opmode;
  }

  if (cmdtype == 0x2) {
    l_addr = 0x0;
  } else {
    l_addr = addr;
  }

  data = 0x00000000
    | ( (0x00000003 & extCh  ) << 23 )
    | ( (0x00000003 & cmdtype) << 21 )
    | ( (0x00000001 & cmdtype) << 20 )
    | ( (0x000fffff & addr   ) << 0 );

  TZ1K_EBIF->EBIF_DIRECTCMD = data;

  /* - Dummy read (Moving to an idle state in EBIF) */
  l_ch_sel_raddr = (extCh)? EBIF_U0CH1_BASE_DEFAULT : EBIF_U0CH0_BASE_DEFAULT;
  data = *((volatile uint16_t*)l_ch_sel_raddr);
}

static void
ebifCsramSwaccWrite(
  uint32_t smc_ch,uint32_t ext_ch,uint32_t regsel,uint32_t cycles,uint32_t opmode,uint32_t wdata)
{
  uint32_t l_ch_sel_raddr = 0;
  uint32_t l_ch_sel_waddr = 0;
  uint32_t l_cycles = 0;
  uint32_t l_opmode = 0;
  volatile uint32_t l_dat = 0;

  l_ch_sel_raddr = (ext_ch)? EBIF_U0CH1_BASE_DEFAULT : EBIF_U0CH0_BASE_DEFAULT;
  l_ch_sel_waddr = l_ch_sel_raddr;

  /* Step 1: Wait for an idle state */
  ebifWaitIdle();

  /* Step 2: Enable Address Overwrite Mode */
  /* - Set CRE Control ([2] ADR_OW_EN, [1] ADV PULSE, [0] High) */
  TZ1K_EBIF_CONF->EBIF_CONF_CRECTRL = 0x4;
  TZ1K_EBIF_CONF->EBIF_CONF_OW_ADR = 0xffffffff;

  /* Step 3: Enable Asynchronous Mode */
  if (cycles != 0x0 && opmode != 0x0) {
    l_cycles = TZ1K_EBIF->EBIF_CYCLES0;
    l_opmode = TZ1K_EBIF->EBIF_OPMODE0;
    ebif_control_dircmd(smc_ch, ext_ch, 0x2, 0x0, cycles, opmode & 0xffffff83);
  } else {
    ebifWaitIdle();
  }

  /* Step 4-7: SW Acc */
  /* 00: RCR, 01:BCR, 10:DIDR */
  l_dat = *( (volatile uint16_t*) l_ch_sel_raddr);
  l_dat = *( (volatile uint16_t*) l_ch_sel_raddr);

  *( (volatile uint16_t*)l_ch_sel_waddr) = 0x00000003 & regsel;
  *( (volatile uint16_t*)l_ch_sel_waddr) = wdata;

  /* Step 8: Wait for an idle state */
  ebifWaitIdle();

  /* Step 9: Reset CRECTRL */
  TZ1K_EBIF_CONF->EBIF_CONF_CRECTRL = 0;
  TZ1K_EBIF_CONF->EBIF_CONF_OW_ADR = 0;

  /* Step 10: Restore CYCLES/OPMODE */
  /* - Update: smc_ch, ce_ch, cmd_type, fixed_to_0 */
  if (cycles != 0x0 && opmode != 0x0) {
    TZ1K_EBIF->EBIF_SETCYCLES = l_cycles;
    TZ1K_EBIF->EBIF_SETOPMODE = l_opmode;
    ebif_control_dircmd(smc_ch, ext_ch, 0x2, 0x0, l_cycles, l_opmode);
  }
}

static uint32_t ebifCsramSwaccRead(uint32_t smc_ch,uint32_t ext_ch,uint32_t regsel,uint32_t cycles,uint32_t opmode)
{
  uint32_t l_ch_sel_raddr = 0;
  uint32_t l_ch_sel_waddr = 0;
  uint32_t l_cycles = 0;
  uint32_t l_opmode = 0;
  volatile uint32_t l_rdata = 0;
  volatile uint32_t l_dat = 0;

  l_ch_sel_raddr = (ext_ch)? EBIF_U0CH1_BASE_DEFAULT : EBIF_U0CH0_BASE_DEFAULT;
  l_ch_sel_waddr = l_ch_sel_raddr;

  /* Step 1: Wait for an idle state */
  ebifWaitIdle();

  /* Step 2: Enable Address Overwrite Mode */
  /* - Set CRE Control ([2] ADR_OW_EN, [1] ADV PULSE, [0] High) */
  TZ1K_EBIF_CONF->EBIF_CONF_CRECTRL = 0x4;
  TZ1K_EBIF_CONF->EBIF_CONF_OW_ADR = 0xffffffff;

  /* Step 3: Enable Asynchronous Mode */
  if (cycles != 0x0 && opmode != 0x0) {
    l_cycles = TZ1K_EBIF->EBIF_CYCLES0;
    l_opmode = TZ1K_EBIF->EBIF_OPMODE0;
    ebif_control_dircmd(smc_ch, ext_ch, 0x2, 0x0, cycles, opmode & 0xffffff83);
  } else {
    ebifWaitIdle();
  }

  /* Step 4-7: SW Acc */
  /* 00: RCR, 01:BCR, 10:DIDR */
  l_dat = *((volatile uint16_t*)l_ch_sel_raddr);
  l_dat = *((volatile uint16_t*)l_ch_sel_raddr);

  *((volatile uint16_t*)l_ch_sel_waddr) = (uint16_t)(0x00000003 & regsel);
  l_rdata = *((volatile uint16_t*)l_ch_sel_raddr);

  /* Step 8: Wait for an idle state */
  ebifWaitIdle();

  /* Step 9: Reset CRECTRL */
  TZ1K_EBIF_CONF->EBIF_CONF_CRECTRL = 0;
  TZ1K_EBIF_CONF->EBIF_CONF_OW_ADR = 0;

  /* Step 10: Restore CYCLES/OPMODE */
  /* - Update: smc_ch, ce_ch, cmd_type, fixed_to_0 */
  if (cycles != 0x0 && opmode != 0x0) {
    TZ1K_EBIF->EBIF_SETCYCLES = l_cycles;
    TZ1K_EBIF->EBIF_SETOPMODE = l_opmode;
    ebif_control_dircmd(smc_ch, ext_ch, 0x2, 0x0, l_cycles, l_opmode);
  }

  return l_rdata;
}

static void ebifCsramSetupConfReg(uint32_t ext_ch,uint32_t sync_mode,uint32_t latency)
{
  volatile uint32_t dat0, dat1;

  /* Set up Configuration Register BCR */
  /* BCR */
  /* SEL=0b01, BCR data (default: 0x9D1F) */
  /*     [15] Mode; 0: Sync, 1: Async (default) */
  /*     [14] Initial access latency; 0: variable, 1:fixed */
  /*     [13:11] Variable Latency; 010: 3cycle, 011: 4ccle, .. */
  /*     [10] Wait polarity; 0: low, 1:high */
  /*     [ 8] Wait configuration; 0: during delay, 1:before delay */
  dat1 = 0x0000010f | (0x00007800 & (latency << 11)) | (CSRAM_DEVSTR_BIT5TO4 << 4);

  if (sync_mode == 0)
    dat1 |= 0x8000;
  else
    dat1 &= 0x7fff;

  /* smc_ch ,ext_ch ,regsel ,cycles ,opmode */
  ebifCsramSwaccWrite(0x0, ext_ch, 0x1, 0x0, 0x0, dat1);
}

static void initialize_ebif(void)
{
  uint32_t ch = 0x0;

  ebifSetupAdmCore();

  /* Adjustment of the Timing Parameters for Asyn. Transfer */
  ebifUpdateTimingByFormattedParameters(ch, 0x0);

  /* Configuration Access */
  ebifCsramSetupConfReg (ch, 0x1, CSRAM_LATENCY_BIT14TO11_DEFAULT);

  /* Adjustment of the Timing Parameters for Syn. Transfer */
  ebifUpdateTimingByFormattedParameters(ch, 0x1);
}
#endif /* #if (1==USE_EBIF) */

#if (1==USE_QUAD_ACCESS)
static void SystemForceQuad(void)
{
  PMU_Type *pm = TZ1K_PMU;
  SPINOFC_Type *fl = TZ1K_SPINOFC;

  if (pm->BOOTCONFIG & 0x6) {
    /* bootmode is not spi nor flash. */
    return;
  }
  if (pm->EFUSE_BOOTSEQ & (1<<9)) {
    /* already enabled */
    return;
  }
  fl->DirCmdCtrl = 0xeb00300e;
}
#else
# define SystemForceQuad()
#endif

static void setup_clock(void)
{
  int32_t val;

  val = *(uint32_t*)(0x40006e14);   /* CAUSE_OF_RESET */
  *(uint32_t*)(0x40006900) |= 1;    /* OVERRIDE_EFUSE_OSC12M_TRIMMING */
  if (val & 1) {
    *(uint32_t*)(0x40006800)  = 1<<9; /* EFUSE_LOAD_TRIMMING.OSC32K */
  }

  /* start OSC12M */
  TZ1K_PMU->CS_START = OSC12M_POS;
  /* poweron PLL */
  TZ1K_PMU->POWERDOMAIN_CTRL = (1<<19);

  TZ1K_PMU->CLK_SETTING0_MAIN   = (4<<16);   // PLL
  TZ1K_PMU->CLK_SETTING_SUB     = 0x10; // 1/2
  TZ1K_PMU->CLK_SETTING_PERI0   = 0x18; // 1/4
  TZ1K_PMU->CLK_SETTING_PERI1   = 0x1c; // 1/8
  TZ1K_PMU->CLK_SETTING_PERI2   = 0x1c; // 1/8
  TZ1K_PMU->CLK_SETTING_DISP    = 0x10; // 1/2
  TZ1K_PMU->CLK_SETTING_EBIF    = 0x10; // 1/2
  TZ1K_PMU->CLK_SETTING_SPINOFC = 0x10; // 1/2
  TZ1K_PMU->CLK_SETTING_SPIFC   = 0x10; // 1/2

  do {
    val = TZ1K_PMU->PPLL_CTRL_STATUS;
  } while (val);
  // start PLL
  TZ1K_PMU->CS_START = PLL_POS;
  do {
    val = TZ1K_PMU->CS_START;
  } while (val);

  // clear interrupt status
  val = TZ1K_PMU->STARTUP_OSC12M;
  TZ1K_PMU->STARTUP_OSC12M = val;
  val = TZ1K_PMU->STARTUP_PLL;
  TZ1K_PMU->STARTUP_PLL = val;

  // apply prescaler settings
  TZ1K_PMU->CLK_CTRL_SEL0 = 0x1FF;
  do {
    val = TZ1K_PMU->CLK_CTRL_SEL0;
  } while (val);
}

static void sys_init(void)
{
  int i;

  TZ1K_PMU->CONFIG_SIOSC12M0    = 1;
  TZ1K_PMU->EFUSE_LOAD_TRIMMING = SET_SIOSC12M_CLK;
  i = 16;
  while (--i) {
    __NOP();
  }
  TZ1K_PMU->CONFIG_SIOSC12M0 = 0;

  TZ1K_PMU->CG_OFF_POWERDOMAIN = 0xFFFFFFFF;
  setup_clock();
}
/*----------------------------------------------------------------------------
  Clock functions
 *----------------------------------------------------------------------------*/
void SystemCoreClockUpdate(void)            /* Get Core Clock Frequency      */
{
  PMU_Type *pm = TZ1K_PMU;
  uint32_t val, cs;
  uint32_t mult1;
  uint32_t mult, div, selr, sel, adpll;
  uint32_t freq;

  val = pm->CLK_STATUS_MAIN;
  mult1 = 32 - ((val & CUR_PSCAL_Msk) >> CUR_PSCAL_Sft);
  cs = PMU_CS_MAIN_MSK & val;
  switch (cs) {
  case PMU_CS_MAIN_ADPLL:
    adpll =  pm->CONFIG_ADPLL0;
    selr  = (adpll & ADPLL_SELFREQR_Msk) >> ADPLL_SELFREQR_Sft;
    mult  = (selr >> 3) + 1;
    if (1 == mult) {
      sel = (adpll & ADPLL_SELFREQ_Msk) >> ADPLL_SELFREQ_Sft;
      if (sel > 5) {
        div = 1;
      } else if (sel > 3) {
        div = 4 >> (sel - 4);
      } else {
        div = 48 >> sel;
      }
    } else  {
      div = (selr & 3) + 1;
    }
    freq  = 4 * 32768 * ((adpll & ADPLL_FCW_Msk) >> ADPLL_FCW_Sft) * mult / div;
    freq /= 32;
    mult1 *= 32 - ((val & CUR_PSCAL_ADPLL_Msk) >> CUR_PSCAL_ADPLL_Sft);
    break;
  case PMU_CS_MAIN_PLL:
    mult   = (pm->CONFIG_PLL1 & PLL_ND_Msk) + 1;
    freq   = 12000000 * mult;
    freq  /= 32;
    mult1 *= 32 - ((val & CUR_PSCAL_PLL_Msk) >> CUR_PSCAL_PLL_Sft);
    break;
  case PMU_CS_MAIN_OSC32K:
    freq = 32768;
    break;
  default:
    freq = 12000000;
    break;
  }
  SystemCoreClock = freq * mult1 / 32;
}

/**
 * Initialize the system
 *
 * @param  none
 * @return none
 *
 * @brief  Setup the microcontroller system.
 *         Initialize the System.
 * @note   This function is called before startup routine.
 *         Do not call functions or read/write SRAM in this function
           because SRAM is not initialized yet.
 */
void SystemInit (void)
{
  PMU_Type *pm = TZ1K_PMU;
  volatile uint32_t *r;
  uint32_t v;
  uint32_t cause;
  int32_t i;

#if (__FPU_USED == 1)
  SCB->CPACR |= ((3UL << 10*2) |                 /* set CP10 Full Access */
           (3UL << 11*2)  );               /* set CP11 Full Access */
#endif


#ifdef UNALIGNED_SUPPORT_DISABLE
  SCB->CCR |= SCB_CCR_UNALIGN_TRP_Msk;
#endif

  cause = pm->CAUSE_OF_RESET;
  if (0 != (cause & (RESET_BORSW | RESET_BORHW | RESET_SYSRESETREQ |
             RESET_LOCKUP | RESET_WDT | RESET_SYSRESET | RESET_POR))) {
    /* 1) load trimming data */
    pm->CONFIG_SIOSC12M0    = 1;
    pm->EFUSE_LOAD_TRIMMING = SET_SIOSC12M_CLK;
    i = 16;
    while (--i) {
      __NOP();
    }
    pm->CONFIG_SIOSC12M0    = 0;
  }
  /* 4) set CONFIG_DCDC_HVREG0.EN_QUICKSTART */
  pm->CONFIG_DCDC_HVREG0 = 1;
  if (0 != (cause & (RESET_BORSW | RESET_BORHW | RESET_SYSRESET | RESET_POR | RESET_RTC))) {
    /* 5) set OVERRIDE_EFUSE_DCDC_TRIMMING0 */
    pm->OVERRIDE_EFUSE_DCDC_TRIMMING0 = 1 << DCDC_TRIMMING0_MODE_Sft;
  }
  /* 6) set VOLTAGEMODE_CTRL_SETTING1 FMODE0 and FMODE1 */
  pm->VOLTAGEMODE_CTRL_SETTING1 = (1<<VOLTAGEMODE_CTRL_SETTING1_FMODE0_Sft)|(1<<VOLTAGEMODE_CTRL_SETTING1_FMODE1_Sft);
  if (0 != (cause & RESET_POR)) {
    /* 8) load OSC32K trimming data */
    pm->EFUSE_LOAD_TRIMMING = SET_OSC32K;
  }
  /* 11) set OSC12M TIMER_COUNT */
  pm->STARTUP_OSC12M = 0x21 << OSC12M_TIMER_COUNT_Sft;
  pm->OVERRIDE_EFUSE_OSC12M_TRIMMING_b.MAIN_GM = 1;
  /* 12) clear PLL TIMER_COUNT.TIMER_COUNT_BP */
  v = pm->STARTUP_PLL & ~TIMER_COUNT_BP_Msk;
  pm->STARTUP_PLL = v;
  /* 13) set DCG_POWERDOMAIN */
  pm->DCG_POWERDOMAIN    = 0xFFFFFFFF;
  /* 14) set BLOCK_EN_???? */
  for (r = &pm->BLOCK_EN_PMAIN; r != &pm->BLOCK_EN_PAONLVC; ++r) {
    *r = 0xFFFFFFFF;
  }
  if (0 != (cause & (RESET_WDT | RESET_LOCKUP | RESET_SYSRESETREQ))) {
    /* 15) clear performance monitor */
    pm->POWERUP_PERIOD_CTRL   = 0x80000000UL;
    pm->POWERUP_PERIOD_CTRL_COUNT0 = 0;
    pm->POWERUP_PERIOD_CTRL_COUNT1 = 0;
    pm->POWERUP_PERIOD_CTRL_COUNT2 = 0;
    pm->POWERUP_EVENT_CTRL   = 0x80000000UL;
    pm->POWERUP_EVENT_CTRL_COUNT0 = 0;
    pm->POWERUP_EVENT_CTRL_COUNT1 = 0;
    pm->POWERUP_EVENT_CTRL_COUNT2 = 0;
  }

  /* 16) set SIOSC12M_DIV2_EN */
  pm->SIOSC12M_DIV2_EN = 2;

  pm->CG_OFF_POWERDOMAIN = 0xFFFFFFFF;
  pm->CG_OFF_PUSB        = 0xFFFFFFFF;
  //
  // This has been added by SEGGER in order to have a proper clock and PLL initialization.
  // Both Main clock and CPU clock are clocked with 96 MHz after sys_init().
  //
  sys_init();
  PowerOnModules();
  EnablePinFunction();

  SystemForceQuad();
#if (USE_EBIF == 1)
  initialize_ebif();
#endif
}
