/*********************************************************************
*                     SEGGER Microcontroller GmbH                    *
*                        The Embedded Experts                        *
**********************************************************************
*                                                                    *
*       (c) 1995 - 2020 SEGGER Microcontroller GmbH                  *
*                                                                    *
*       Internet: segger.com  Support: support_embos@segger.com      *
*                                                                    *
**********************************************************************
*                                                                    *
*       embOS * Real time operating system for microcontrollers      *
*                                                                    *
*       Please note:                                                 *
*                                                                    *
*       Knowledge of this file may under no circumstances            *
*       be used to write a similar product or a real-time            *
*       operating system for in-house use.                           *
*                                                                    *
*       Thank you for your fairness !                                *
*                                                                    *
**********************************************************************
*                                                                    *
*       OS version: V5.10.1.0                                        *
*                                                                    *
**********************************************************************

-------------------------- END-OF-HEADER -----------------------------
Purpose : BSP for Toshiba EBTZ1200-1MA-A1 eval board
*/

#include "BSP.h"

/*********************************************************************
*
*       Defines
*
**********************************************************************
*/
#define LED0_BIT                  (0)   // LED2 on board: DSW37 on, SW21 on
#define LED1_BIT                  (1)   // LED3 on board: DSW37 on, SW22 on
#define LED2_BIT                  (2)   // LED4 on board: DSW37 on, SW23 on
#define LED3_BIT                  (3)   // LED5 on board: DSW37 on, SW24 on

#define PMU_BASE_ADDR             (0x40000000u)
#define PMU_PSUB_CTRL_STATUS      (*(volatile unsigned int*)(PMU_BASE_ADDR + 0x1330u))
#define PMU_CG_OFF_PSUB_1         (*(volatile unsigned int*)(PMU_BASE_ADDR + 0x1354u))
#define PMU_SRST_OFF_PSUB_1       (*(volatile unsigned int*)(PMU_BASE_ADDR + 0x1394u))

#define GCONF_FMODE_CFG_PA1       (*(volatile unsigned int*)(0x4000D204u))

#define GPIO0_BASE_ADDR           (0x4004A000u)
#define GPIO0_ODATA               (*(volatile unsigned int*)(GPIO0_BASE_ADDR + 0x04u))
#define GPIO0_DIROUT              (*(volatile unsigned int*)(GPIO0_BASE_ADDR + 0x14u))

/*********************************************************************
*
*       Global functions
*
**********************************************************************
*/

/*********************************************************************
*
*       BSP_Init()
*/
void BSP_Init(void) {
  PMU_SRST_OFF_PSUB_1       |= (1u << 10)              // Deassert PPIER1 reset
                            |  (1u << 24)              // Deassert GPIO0  reset
                            ;
  PMU_CG_OFF_PSUB_1         |= (1u << 10)              // Supply clock to PPIER1
                            |  (1u << 24)              // Supply clock to GPIO0
                            ;

  GCONF_FMODE_CFG_PA1       |= (1u << (LED0_BIT * 4))  // Set GPIO0 Pins to FMOD1
                            |  (1u << (LED1_BIT * 4))
                            |  (1u << (LED2_BIT * 4))
                            |  (1u << (LED3_BIT * 4))
                            ;
  GPIO0_DIROUT              |= (1u << (LED0_BIT + 8))  // Set GPIO Pins to output
                            |  (1u << (LED1_BIT + 8))
                            |  (1u << (LED2_BIT + 8))
                            |  (1u << (LED3_BIT + 8))
                            ;
}

/*********************************************************************
*
*       BSP_SetLED()
*/
void BSP_SetLED(int Index) {
  switch(Index){
  case 0:
    GPIO0_ODATA |= (1u << (LED0_BIT + 8));
    break;
  case 1:
    GPIO0_ODATA |= (1u << (LED1_BIT + 8));
    break;
  case 2:
    GPIO0_ODATA |= (1u << (LED2_BIT + 8));
    break;
  case 3:
    GPIO0_ODATA |= (1u << (LED3_BIT + 8));
    break;
  }
}

/*********************************************************************
*
*       BSP_ClrLED()
*/
void BSP_ClrLED(int Index) {
  switch(Index){
  case 0:
    GPIO0_ODATA &= ~(1u << (LED0_BIT + 8));
    break;
  case 1:
    GPIO0_ODATA &= ~(1u << (LED1_BIT + 8));
    break;
  case 2:
    GPIO0_ODATA &= ~(1u << (LED2_BIT + 8));
    break;
  case 3:
    GPIO0_ODATA &= ~(1u << (LED3_BIT + 8));
    break;
  }
}

/*********************************************************************
*
*       BSP_ToggleLED()
*/
void BSP_ToggleLED(int Index) {
  switch(Index){
  case 0:
    GPIO0_ODATA ^= (1u << (LED0_BIT + 8));
    break;
  case 1:
    GPIO0_ODATA ^= (1u << (LED1_BIT + 8));
    break;
  case 2:
    GPIO0_ODATA ^= (1u << (LED2_BIT + 8));
    break;
  case 3:
    GPIO0_ODATA ^= (1u << (LED3_BIT + 8));
    break;
  }
}

/*************************** End of file ****************************/
